from pwnlib.constants.constant import Constant
ITIMER_REAL = Constant('ITIMER_REAL',0)
ITIMER_VIRTUAL = Constant('ITIMER_VIRTUAL',1)
ITIMER_PROF = Constant('ITIMER_PROF',2)
DST_NONE = Constant('DST_NONE',0)
DST_USA = Constant('DST_USA',1)
DST_AUST = Constant('DST_AUST',2)
DST_WET = Constant('DST_WET',3)
DST_MET = Constant('DST_MET',4)
DST_EET = Constant('DST_EET',5)
DST_CAN = Constant('DST_CAN',6)
CHILD_MAX = Constant('CHILD_MAX',266)
LINK_MAX = Constant('LINK_MAX',32767)
MAX_CANON = Constant('MAX_CANON',1024)
MAX_INPUT = Constant('MAX_INPUT',1024)
NAME_MAX = Constant('NAME_MAX',255)
NGROUPS_MAX = Constant('NGROUPS_MAX',16)
OPEN_MAX = Constant('OPEN_MAX',10240)
PATH_MAX = Constant('PATH_MAX',1024)
PIPE_BUF = Constant('PIPE_BUF',512)
BC_BASE_MAX = Constant('BC_BASE_MAX',99)
BC_DIM_MAX = Constant('BC_DIM_MAX',2048)
BC_SCALE_MAX = Constant('BC_SCALE_MAX',99)
BC_STRING_MAX = Constant('BC_STRING_MAX',1000)
CHARCLASS_NAME_MAX = Constant('CHARCLASS_NAME_MAX',14)
COLL_WEIGHTS_MAX = Constant('COLL_WEIGHTS_MAX',2)
EQUIV_CLASS_MAX = Constant('EQUIV_CLASS_MAX',2)
EXPR_NEST_MAX = Constant('EXPR_NEST_MAX',32)
LINE_MAX = Constant('LINE_MAX',2048)
RE_DUP_MAX = Constant('RE_DUP_MAX',255)
NZERO = Constant('NZERO',0)
GETNCNT = Constant('GETNCNT',3)
GETPID = Constant('GETPID',4)
GETVAL = Constant('GETVAL',5)
GETALL = Constant('GETALL',6)
GETZCNT = Constant('GETZCNT',7)
SETVAL = Constant('SETVAL',8)
SETALL = Constant('SETALL',9)
SEM_UNDO = Constant('SEM_UNDO',0o010000)
SEM_A = Constant('SEM_A',0o0200)
SEM_R = Constant('SEM_R',0o0400)
PSEMNAMLEN = Constant('PSEMNAMLEN',31)
PSEM_NONE = Constant('PSEM_NONE',1)
PSEM_DEFINED = Constant('PSEM_DEFINED',2)
PSEM_ALLOCATED = Constant('PSEM_ALLOCATED',4)
PSEM_MAPPED = Constant('PSEM_MAPPED',8)
PSEM_INUSE = Constant('PSEM_INUSE',0x10)
PSEM_REMOVED = Constant('PSEM_REMOVED',0x20)
PSEM_INCREATE = Constant('PSEM_INCREATE',0x40)
PSEM_INDELETE = Constant('PSEM_INDELETE',0x80)
FSOPT_NOFOLLOW = Constant('FSOPT_NOFOLLOW',0x00000001)
FSOPT_NOINMEMUPDATE = Constant('FSOPT_NOINMEMUPDATE',0x00000002)
FSOPT_REPORT_FULLSIZE = Constant('FSOPT_REPORT_FULLSIZE',0x00000004)
FSOPT_PACK_INVAL_ATTRS = Constant('FSOPT_PACK_INVAL_ATTRS',0x00000008)
FSOPT_ATTR_CMN_EXTENDED = Constant('FSOPT_ATTR_CMN_EXTENDED',0x00000020)
FSOPT_RETURN_REALDEV = Constant('FSOPT_RETURN_REALDEV',0x00000200)
FSOPT_NOFOLLOW_ANY = Constant('FSOPT_NOFOLLOW_ANY',0x00000800)
SEARCHFS_MAX_SEARCHPARMS = Constant('SEARCHFS_MAX_SEARCHPARMS',4096)
ATTR_BIT_MAP_COUNT = Constant('ATTR_BIT_MAP_COUNT',5)
VOL_CAPABILITIES_FORMAT = Constant('VOL_CAPABILITIES_FORMAT',0)
VOL_CAPABILITIES_INTERFACES = Constant('VOL_CAPABILITIES_INTERFACES',1)
VOL_CAPABILITIES_RESERVED1 = Constant('VOL_CAPABILITIES_RESERVED1',2)
VOL_CAPABILITIES_RESERVED2 = Constant('VOL_CAPABILITIES_RESERVED2',3)
ATTR_MAX_BUFFER = Constant('ATTR_MAX_BUFFER',8192)
VOL_CAP_FMT_PERSISTENTOBJECTIDS = Constant('VOL_CAP_FMT_PERSISTENTOBJECTIDS',0x00000001)
VOL_CAP_FMT_SYMBOLICLINKS = Constant('VOL_CAP_FMT_SYMBOLICLINKS',0x00000002)
VOL_CAP_FMT_HARDLINKS = Constant('VOL_CAP_FMT_HARDLINKS',0x00000004)
VOL_CAP_FMT_JOURNAL = Constant('VOL_CAP_FMT_JOURNAL',0x00000008)
VOL_CAP_FMT_JOURNAL_ACTIVE = Constant('VOL_CAP_FMT_JOURNAL_ACTIVE',0x00000010)
VOL_CAP_FMT_NO_ROOT_TIMES = Constant('VOL_CAP_FMT_NO_ROOT_TIMES',0x00000020)
VOL_CAP_FMT_SPARSE_FILES = Constant('VOL_CAP_FMT_SPARSE_FILES',0x00000040)
VOL_CAP_FMT_ZERO_RUNS = Constant('VOL_CAP_FMT_ZERO_RUNS',0x00000080)
VOL_CAP_FMT_CASE_SENSITIVE = Constant('VOL_CAP_FMT_CASE_SENSITIVE',0x00000100)
VOL_CAP_FMT_CASE_PRESERVING = Constant('VOL_CAP_FMT_CASE_PRESERVING',0x00000200)
VOL_CAP_FMT_FAST_STATFS = Constant('VOL_CAP_FMT_FAST_STATFS',0x00000400)
VOL_CAP_FMT_2TB_FILESIZE = Constant('VOL_CAP_FMT_2TB_FILESIZE',0x00000800)
VOL_CAP_FMT_OPENDENYMODES = Constant('VOL_CAP_FMT_OPENDENYMODES',0x00001000)
VOL_CAP_FMT_HIDDEN_FILES = Constant('VOL_CAP_FMT_HIDDEN_FILES',0x00002000)
VOL_CAP_FMT_PATH_FROM_ID = Constant('VOL_CAP_FMT_PATH_FROM_ID',0x00004000)
VOL_CAP_FMT_NO_VOLUME_SIZES = Constant('VOL_CAP_FMT_NO_VOLUME_SIZES',0x00008000)
VOL_CAP_FMT_DECMPFS_COMPRESSION = Constant('VOL_CAP_FMT_DECMPFS_COMPRESSION',0x00010000)
VOL_CAP_FMT_64BIT_OBJECT_IDS = Constant('VOL_CAP_FMT_64BIT_OBJECT_IDS',0x00020000)
VOL_CAP_FMT_DIR_HARDLINKS = Constant('VOL_CAP_FMT_DIR_HARDLINKS',0x00040000)
VOL_CAP_FMT_DOCUMENT_ID = Constant('VOL_CAP_FMT_DOCUMENT_ID',0x00080000)
VOL_CAP_FMT_WRITE_GENERATION_COUNT = Constant('VOL_CAP_FMT_WRITE_GENERATION_COUNT',0x00100000)
VOL_CAP_FMT_NO_IMMUTABLE_FILES = Constant('VOL_CAP_FMT_NO_IMMUTABLE_FILES',0x00200000)
VOL_CAP_FMT_NO_PERMISSIONS = Constant('VOL_CAP_FMT_NO_PERMISSIONS',0x00400000)
VOL_CAP_FMT_SHARED_SPACE = Constant('VOL_CAP_FMT_SHARED_SPACE',0x00800000)
VOL_CAP_FMT_VOL_GROUPS = Constant('VOL_CAP_FMT_VOL_GROUPS',0x01000000)
VOL_CAP_FMT_SEALED = Constant('VOL_CAP_FMT_SEALED',0x02000000)
VOL_CAP_FMT_CLONE_MAPPING = Constant('VOL_CAP_FMT_CLONE_MAPPING',0x04000000)
VOL_CAP_INT_SEARCHFS = Constant('VOL_CAP_INT_SEARCHFS',0x00000001)
VOL_CAP_INT_ATTRLIST = Constant('VOL_CAP_INT_ATTRLIST',0x00000002)
VOL_CAP_INT_NFSEXPORT = Constant('VOL_CAP_INT_NFSEXPORT',0x00000004)
VOL_CAP_INT_READDIRATTR = Constant('VOL_CAP_INT_READDIRATTR',0x00000008)
VOL_CAP_INT_EXCHANGEDATA = Constant('VOL_CAP_INT_EXCHANGEDATA',0x00000010)
VOL_CAP_INT_COPYFILE = Constant('VOL_CAP_INT_COPYFILE',0x00000020)
VOL_CAP_INT_ALLOCATE = Constant('VOL_CAP_INT_ALLOCATE',0x00000040)
VOL_CAP_INT_VOL_RENAME = Constant('VOL_CAP_INT_VOL_RENAME',0x00000080)
VOL_CAP_INT_ADVLOCK = Constant('VOL_CAP_INT_ADVLOCK',0x00000100)
VOL_CAP_INT_FLOCK = Constant('VOL_CAP_INT_FLOCK',0x00000200)
VOL_CAP_INT_EXTENDED_SECURITY = Constant('VOL_CAP_INT_EXTENDED_SECURITY',0x00000400)
VOL_CAP_INT_USERACCESS = Constant('VOL_CAP_INT_USERACCESS',0x00000800)
VOL_CAP_INT_MANLOCK = Constant('VOL_CAP_INT_MANLOCK',0x00001000)
VOL_CAP_INT_NAMEDSTREAMS = Constant('VOL_CAP_INT_NAMEDSTREAMS',0x00002000)
VOL_CAP_INT_EXTENDED_ATTR = Constant('VOL_CAP_INT_EXTENDED_ATTR',0x00004000)
VOL_CAP_INT_CLONE = Constant('VOL_CAP_INT_CLONE',0x00010000)
VOL_CAP_INT_SNAPSHOT = Constant('VOL_CAP_INT_SNAPSHOT',0x00020000)
VOL_CAP_INT_RENAME_SWAP = Constant('VOL_CAP_INT_RENAME_SWAP',0x00040000)
VOL_CAP_INT_RENAME_EXCL = Constant('VOL_CAP_INT_RENAME_EXCL',0x00080000)
VOL_CAP_INT_RENAME_OPENFAIL = Constant('VOL_CAP_INT_RENAME_OPENFAIL',0x00100000)
VOL_CAP_INT_RENAME_SECLUDE = Constant('VOL_CAP_INT_RENAME_SECLUDE',0x00200000)
VOL_CAP_INT_ATTRIBUTION_TAG = Constant('VOL_CAP_INT_ATTRIBUTION_TAG',0x00400000)
VOL_CAP_INT_PUNCHHOLE = Constant('VOL_CAP_INT_PUNCHHOLE',0x00800000)
ATTR_CMN_NAME = Constant('ATTR_CMN_NAME',0x00000001)
ATTR_CMN_DEVID = Constant('ATTR_CMN_DEVID',0x00000002)
ATTR_CMN_FSID = Constant('ATTR_CMN_FSID',0x00000004)
ATTR_CMN_OBJTYPE = Constant('ATTR_CMN_OBJTYPE',0x00000008)
ATTR_CMN_OBJTAG = Constant('ATTR_CMN_OBJTAG',0x00000010)
ATTR_CMN_OBJID = Constant('ATTR_CMN_OBJID',0x00000020)
ATTR_CMN_OBJPERMANENTID = Constant('ATTR_CMN_OBJPERMANENTID',0x00000040)
ATTR_CMN_PAROBJID = Constant('ATTR_CMN_PAROBJID',0x00000080)
ATTR_CMN_SCRIPT = Constant('ATTR_CMN_SCRIPT',0x00000100)
ATTR_CMN_CRTIME = Constant('ATTR_CMN_CRTIME',0x00000200)
ATTR_CMN_MODTIME = Constant('ATTR_CMN_MODTIME',0x00000400)
ATTR_CMN_CHGTIME = Constant('ATTR_CMN_CHGTIME',0x00000800)
ATTR_CMN_ACCTIME = Constant('ATTR_CMN_ACCTIME',0x00001000)
ATTR_CMN_BKUPTIME = Constant('ATTR_CMN_BKUPTIME',0x00002000)
ATTR_CMN_FNDRINFO = Constant('ATTR_CMN_FNDRINFO',0x00004000)
ATTR_CMN_OWNERID = Constant('ATTR_CMN_OWNERID',0x00008000)
ATTR_CMN_GRPID = Constant('ATTR_CMN_GRPID',0x00010000)
ATTR_CMN_ACCESSMASK = Constant('ATTR_CMN_ACCESSMASK',0x00020000)
ATTR_CMN_FLAGS = Constant('ATTR_CMN_FLAGS',0x00040000)
ATTR_CMN_GEN_COUNT = Constant('ATTR_CMN_GEN_COUNT',0x00080000)
ATTR_CMN_DOCUMENT_ID = Constant('ATTR_CMN_DOCUMENT_ID',0x00100000)
ATTR_CMN_USERACCESS = Constant('ATTR_CMN_USERACCESS',0x00200000)
ATTR_CMN_EXTENDED_SECURITY = Constant('ATTR_CMN_EXTENDED_SECURITY',0x00400000)
ATTR_CMN_UUID = Constant('ATTR_CMN_UUID',0x00800000)
ATTR_CMN_GRPUUID = Constant('ATTR_CMN_GRPUUID',0x01000000)
ATTR_CMN_FILEID = Constant('ATTR_CMN_FILEID',0x02000000)
ATTR_CMN_PARENTID = Constant('ATTR_CMN_PARENTID',0x04000000)
ATTR_CMN_FULLPATH = Constant('ATTR_CMN_FULLPATH',0x08000000)
ATTR_CMN_ADDEDTIME = Constant('ATTR_CMN_ADDEDTIME',0x10000000)
ATTR_CMN_ERROR = Constant('ATTR_CMN_ERROR',0x20000000)
ATTR_CMN_DATA_PROTECT_FLAGS = Constant('ATTR_CMN_DATA_PROTECT_FLAGS',0x40000000)
ATTR_CMN_RETURNED_ATTRS = Constant('ATTR_CMN_RETURNED_ATTRS',0x80000000)
ATTR_CMN_VALIDMASK = Constant('ATTR_CMN_VALIDMASK',0xFFFFFFFF)
ATTR_CMN_SETMASK = Constant('ATTR_CMN_SETMASK',0x51C7FF00)
ATTR_CMN_VOLSETMASK = Constant('ATTR_CMN_VOLSETMASK',0x00006700)
ATTR_VOL_FSTYPE = Constant('ATTR_VOL_FSTYPE',0x00000001)
ATTR_VOL_SIGNATURE = Constant('ATTR_VOL_SIGNATURE',0x00000002)
ATTR_VOL_SIZE = Constant('ATTR_VOL_SIZE',0x00000004)
ATTR_VOL_SPACEFREE = Constant('ATTR_VOL_SPACEFREE',0x00000008)
ATTR_VOL_SPACEAVAIL = Constant('ATTR_VOL_SPACEAVAIL',0x00000010)
ATTR_VOL_MINALLOCATION = Constant('ATTR_VOL_MINALLOCATION',0x00000020)
ATTR_VOL_ALLOCATIONCLUMP = Constant('ATTR_VOL_ALLOCATIONCLUMP',0x00000040)
ATTR_VOL_IOBLOCKSIZE = Constant('ATTR_VOL_IOBLOCKSIZE',0x00000080)
ATTR_VOL_OBJCOUNT = Constant('ATTR_VOL_OBJCOUNT',0x00000100)
ATTR_VOL_FILECOUNT = Constant('ATTR_VOL_FILECOUNT',0x00000200)
ATTR_VOL_DIRCOUNT = Constant('ATTR_VOL_DIRCOUNT',0x00000400)
ATTR_VOL_MAXOBJCOUNT = Constant('ATTR_VOL_MAXOBJCOUNT',0x00000800)
ATTR_VOL_MOUNTPOINT = Constant('ATTR_VOL_MOUNTPOINT',0x00001000)
ATTR_VOL_NAME = Constant('ATTR_VOL_NAME',0x00002000)
ATTR_VOL_MOUNTFLAGS = Constant('ATTR_VOL_MOUNTFLAGS',0x00004000)
ATTR_VOL_MOUNTEDDEVICE = Constant('ATTR_VOL_MOUNTEDDEVICE',0x00008000)
ATTR_VOL_ENCODINGSUSED = Constant('ATTR_VOL_ENCODINGSUSED',0x00010000)
ATTR_VOL_CAPABILITIES = Constant('ATTR_VOL_CAPABILITIES',0x00020000)
ATTR_VOL_UUID = Constant('ATTR_VOL_UUID',0x00040000)
ATTR_VOL_FSTYPENAME = Constant('ATTR_VOL_FSTYPENAME',0x00100000)
ATTR_VOL_FSSUBTYPE = Constant('ATTR_VOL_FSSUBTYPE',0x00200000)
ATTR_VOL_SPACEUSED = Constant('ATTR_VOL_SPACEUSED',0x00800000)
ATTR_VOL_QUOTA_SIZE = Constant('ATTR_VOL_QUOTA_SIZE',0x10000000)
ATTR_VOL_RESERVED_SIZE = Constant('ATTR_VOL_RESERVED_SIZE',0x20000000)
ATTR_VOL_ATTRIBUTES = Constant('ATTR_VOL_ATTRIBUTES',0x40000000)
ATTR_VOL_INFO = Constant('ATTR_VOL_INFO',0x80000000)
ATTR_VOL_VALIDMASK = Constant('ATTR_VOL_VALIDMASK',0xF0B7FFFF)
ATTR_VOL_SETMASK = Constant('ATTR_VOL_SETMASK',0x80002000)
ATTR_DIR_LINKCOUNT = Constant('ATTR_DIR_LINKCOUNT',0x00000001)
ATTR_DIR_ENTRYCOUNT = Constant('ATTR_DIR_ENTRYCOUNT',0x00000002)
ATTR_DIR_MOUNTSTATUS = Constant('ATTR_DIR_MOUNTSTATUS',0x00000004)
ATTR_DIR_ALLOCSIZE = Constant('ATTR_DIR_ALLOCSIZE',0x00000008)
ATTR_DIR_IOBLOCKSIZE = Constant('ATTR_DIR_IOBLOCKSIZE',0x00000010)
ATTR_DIR_DATALENGTH = Constant('ATTR_DIR_DATALENGTH',0x00000020)
DIR_MNTSTATUS_MNTPOINT = Constant('DIR_MNTSTATUS_MNTPOINT',0x00000001)
DIR_MNTSTATUS_TRIGGER = Constant('DIR_MNTSTATUS_TRIGGER',0x00000002)
ATTR_DIR_VALIDMASK = Constant('ATTR_DIR_VALIDMASK',0x0000003f)
ATTR_DIR_SETMASK = Constant('ATTR_DIR_SETMASK',0x00000000)
ATTR_FILE_LINKCOUNT = Constant('ATTR_FILE_LINKCOUNT',0x00000001)
ATTR_FILE_TOTALSIZE = Constant('ATTR_FILE_TOTALSIZE',0x00000002)
ATTR_FILE_ALLOCSIZE = Constant('ATTR_FILE_ALLOCSIZE',0x00000004)
ATTR_FILE_IOBLOCKSIZE = Constant('ATTR_FILE_IOBLOCKSIZE',0x00000008)
ATTR_FILE_DEVTYPE = Constant('ATTR_FILE_DEVTYPE',0x00000020)
ATTR_FILE_FORKCOUNT = Constant('ATTR_FILE_FORKCOUNT',0x00000080)
ATTR_FILE_FORKLIST = Constant('ATTR_FILE_FORKLIST',0x00000100)
ATTR_FILE_DATALENGTH = Constant('ATTR_FILE_DATALENGTH',0x00000200)
ATTR_FILE_DATAALLOCSIZE = Constant('ATTR_FILE_DATAALLOCSIZE',0x00000400)
ATTR_FILE_RSRCLENGTH = Constant('ATTR_FILE_RSRCLENGTH',0x00001000)
ATTR_FILE_RSRCALLOCSIZE = Constant('ATTR_FILE_RSRCALLOCSIZE',0x00002000)
ATTR_FILE_VALIDMASK = Constant('ATTR_FILE_VALIDMASK',0x000037FF)
ATTR_FILE_SETMASK = Constant('ATTR_FILE_SETMASK',0x00000020)
ATTR_CMNEXT_RELPATH = Constant('ATTR_CMNEXT_RELPATH',0x00000004)
ATTR_CMNEXT_PRIVATESIZE = Constant('ATTR_CMNEXT_PRIVATESIZE',0x00000008)
ATTR_CMNEXT_LINKID = Constant('ATTR_CMNEXT_LINKID',0x00000010)
ATTR_CMNEXT_NOFIRMLINKPATH = Constant('ATTR_CMNEXT_NOFIRMLINKPATH',0x00000020)
ATTR_CMNEXT_REALDEVID = Constant('ATTR_CMNEXT_REALDEVID',0x00000040)
ATTR_CMNEXT_REALFSID = Constant('ATTR_CMNEXT_REALFSID',0x00000080)
ATTR_CMNEXT_CLONEID = Constant('ATTR_CMNEXT_CLONEID',0x00000100)
ATTR_CMNEXT_EXT_FLAGS = Constant('ATTR_CMNEXT_EXT_FLAGS',0x00000200)
ATTR_CMNEXT_RECURSIVE_GENCOUNT = Constant('ATTR_CMNEXT_RECURSIVE_GENCOUNT',0x00000400)
ATTR_CMNEXT_ATTRIBUTION_TAG = Constant('ATTR_CMNEXT_ATTRIBUTION_TAG',0x00000800)
ATTR_CMNEXT_CLONE_REFCNT = Constant('ATTR_CMNEXT_CLONE_REFCNT',0x00001000)
ATTR_CMNEXT_VALIDMASK = Constant('ATTR_CMNEXT_VALIDMASK',0x00001ffc)
ATTR_CMNEXT_SETMASK = Constant('ATTR_CMNEXT_SETMASK',0x00000000)
ATTR_FORK_TOTALSIZE = Constant('ATTR_FORK_TOTALSIZE',0x00000001)
ATTR_FORK_ALLOCSIZE = Constant('ATTR_FORK_ALLOCSIZE',0x00000002)
ATTR_FORK_RESERVED = Constant('ATTR_FORK_RESERVED',0xffffffff)
ATTR_FORK_VALIDMASK = Constant('ATTR_FORK_VALIDMASK',0x00000003)
ATTR_FORK_SETMASK = Constant('ATTR_FORK_SETMASK',0x00000000)
ATTR_CMN_NAMEDATTRCOUNT = Constant('ATTR_CMN_NAMEDATTRCOUNT',0x00080000)
ATTR_CMN_NAMEDATTRLIST = Constant('ATTR_CMN_NAMEDATTRLIST',0x00100000)
ATTR_FILE_CLUMPSIZE = Constant('ATTR_FILE_CLUMPSIZE',0x00000010)
ATTR_FILE_FILETYPE = Constant('ATTR_FILE_FILETYPE',0x00000040)
ATTR_FILE_DATAEXTENTS = Constant('ATTR_FILE_DATAEXTENTS',0x00000800)
ATTR_FILE_RSRCEXTENTS = Constant('ATTR_FILE_RSRCEXTENTS',0x00004000)
SRCHFS_START = Constant('SRCHFS_START',0x00000001)
SRCHFS_MATCHPARTIALNAMES = Constant('SRCHFS_MATCHPARTIALNAMES',0x00000002)
SRCHFS_MATCHDIRS = Constant('SRCHFS_MATCHDIRS',0x00000004)
SRCHFS_MATCHFILES = Constant('SRCHFS_MATCHFILES',0x00000008)
SRCHFS_SKIPLINKS = Constant('SRCHFS_SKIPLINKS',0x00000010)
SRCHFS_SKIPINVISIBLE = Constant('SRCHFS_SKIPINVISIBLE',0x00000020)
SRCHFS_SKIPPACKAGES = Constant('SRCHFS_SKIPPACKAGES',0x00000040)
SRCHFS_SKIPINAPPROPRIATE = Constant('SRCHFS_SKIPINAPPROPRIATE',0x00000080)
SRCHFS_NEGATEPARAMS = Constant('SRCHFS_NEGATEPARAMS',0x80000000)
SRCHFS_VALIDOPTIONSMASK = Constant('SRCHFS_VALIDOPTIONSMASK',0x800000FF)
KEV_ANY_VENDOR = Constant('KEV_ANY_VENDOR',0)
KEV_ANY_CLASS = Constant('KEV_ANY_CLASS',0)
KEV_ANY_SUBCLASS = Constant('KEV_ANY_SUBCLASS',0)
KEV_VENDOR_APPLE = Constant('KEV_VENDOR_APPLE',1)
KEV_NETWORK_CLASS = Constant('KEV_NETWORK_CLASS',1)
KEV_IOKIT_CLASS = Constant('KEV_IOKIT_CLASS',2)
KEV_SYSTEM_CLASS = Constant('KEV_SYSTEM_CLASS',3)
KEV_APPLESHARE_CLASS = Constant('KEV_APPLESHARE_CLASS',4)
KEV_FIREWALL_CLASS = Constant('KEV_FIREWALL_CLASS',5)
KEV_IEEE80211_CLASS = Constant('KEV_IEEE80211_CLASS',6)
KEV_NKE_CLASS = Constant('KEV_NKE_CLASS',7)
KEV_NKE_ALF_SUBCLASS = Constant('KEV_NKE_ALF_SUBCLASS',1)
KEV_NKE_ALF_STATE_CHANGED = Constant('KEV_NKE_ALF_STATE_CHANGED',1)
XNU_KERN_EVENT_DATA_SIZE = Constant('XNU_KERN_EVENT_DATA_SIZE',1)
KEV_VENDOR_CODE_MAX_STR_LEN = Constant('KEV_VENDOR_CODE_MAX_STR_LEN',200)
N_KEV_VECTORS = Constant('N_KEV_VECTORS',5)
M_WAITOK = Constant('M_WAITOK',0x0000)
M_NOWAIT = Constant('M_NOWAIT',0x0001)
M_ZERO = Constant('M_ZERO',0x0004)
M_NULL = Constant('M_NULL',0x0008)
M_PCB = Constant('M_PCB',4)
M_RTABLE = Constant('M_RTABLE',5)
M_IFADDR = Constant('M_IFADDR',9)
M_SONAME = Constant('M_SONAME',11)
M_LOCKF = Constant('M_LOCKF',40)
M_TEMP = Constant('M_TEMP',80)
M_UDFNODE = Constant('M_UDFNODE',84)
M_UDFMNT = Constant('M_UDFMNT',85)
M_KAUTH = Constant('M_KAUTH',100)
HAVE_VT_LOCKERFS = Constant('HAVE_VT_LOCKERFS',1)
VNODE_READ = Constant('VNODE_READ',0x01)
VNODE_WRITE = Constant('VNODE_WRITE',0x02)
VNODE_BLOCKMAP_NO_TRACK = Constant('VNODE_BLOCKMAP_NO_TRACK',0x04)
VNODE_CLUSTER_VERIFY = Constant('VNODE_CLUSTER_VERIFY',0x08)
PREALLOCATE = Constant('PREALLOCATE',0x00000001)
ALLOCATECONTIG = Constant('ALLOCATECONTIG',0x00000002)
ALLOCATEALL = Constant('ALLOCATEALL',0x00000004)
ALLOCATEPERSIST = Constant('ALLOCATEPERSIST',0x00000008)
ALLOCATEFROMPEOF = Constant('ALLOCATEFROMPEOF',0x00000010)
ALLOCATEFROMVOL = Constant('ALLOCATEFROMVOL',0x00000020)
IO_UNIT = Constant('IO_UNIT',0x0001)
IO_APPEND = Constant('IO_APPEND',0x0002)
IO_SYNC = Constant('IO_SYNC',0x0004)
IO_NODELOCKED = Constant('IO_NODELOCKED',0x0008)
IO_NDELAY = Constant('IO_NDELAY',0x0010)
IO_NOZEROFILL = Constant('IO_NOZEROFILL',0x0020)
IO_TAILZEROFILL = Constant('IO_TAILZEROFILL',0x0040)
IO_HEADZEROFILL = Constant('IO_HEADZEROFILL',0x0080)
IO_NOZEROVALID = Constant('IO_NOZEROVALID',0x0100)
IO_NOZERODIRTY = Constant('IO_NOZERODIRTY',0x0200)
IO_CLOSE = Constant('IO_CLOSE',0x0400)
IO_NOCACHE = Constant('IO_NOCACHE',0x0800)
IO_RAOFF = Constant('IO_RAOFF',0x1000)
IO_DEFWRITE = Constant('IO_DEFWRITE',0x2000)
IO_PASSIVE = Constant('IO_PASSIVE',0x4000)
IO_NOAUTH = Constant('IO_NOAUTH',0x8000)
IO_NODIRECT = Constant('IO_NODIRECT',0x10000)
IO_ENCRYPTED = Constant('IO_ENCRYPTED',0x20000)
IO_RETURN_ON_THROTTLE = Constant('IO_RETURN_ON_THROTTLE',0x40000)
IO_SINGLE_WRITER = Constant('IO_SINGLE_WRITER',0x80000)
IO_SYSCALL_DISPATCH = Constant('IO_SYSCALL_DISPATCH',0x100000)
IO_SWAP_DISPATCH = Constant('IO_SWAP_DISPATCH',0x200000)
IO_SKIP_ENCRYPTION = Constant('IO_SKIP_ENCRYPTION',0x400000)
IO_EVTONLY = Constant('IO_EVTONLY',0x800000)
IO_NOCACHE_SYSSPACE = Constant('IO_NOCACHE_SYSSPACE',0x1000000)
IO_NOCACHE_SWRITE = Constant('IO_NOCACHE_SWRITE',0x2000000)
LOOKUP = Constant('LOOKUP',0)
CREATE = Constant('CREATE',1)
DELETE = Constant('DELETE',2)
RENAME = Constant('RENAME',3)
OPMASK = Constant('OPMASK',3)
FOLLOW = Constant('FOLLOW',0x00000040)
ISDOTDOT = Constant('ISDOTDOT',0x00002000)
MAKEENTRY = Constant('MAKEENTRY',0x00004000)
ISLASTCN = Constant('ISLASTCN',0x00008000)
VNFS_NOCACHE = Constant('VNFS_NOCACHE',0x01)
VNFS_CANTCACHE = Constant('VNFS_CANTCACHE',0x02)
VNFS_ADDFSREF = Constant('VNFS_ADDFSREF',0x04)
VNCREATE_FLAVOR = Constant('VNCREATE_FLAVOR',0)
VA_UTIMES_NULL = Constant('VA_UTIMES_NULL',0x010000)
VA_EXCLUSIVE = Constant('VA_EXCLUSIVE',0x020000)
VA_NOINHERIT = Constant('VA_NOINHERIT',0x040000)
VA_NOAUTH = Constant('VA_NOAUTH',0x080000)
VA_64BITOBJIDS = Constant('VA_64BITOBJIDS',0x100000)
VA_REALFSID = Constant('VA_REALFSID',0x200000)
VA_USEFSID = Constant('VA_USEFSID',0x400000)
VA_FILESEC_ACL = Constant('VA_FILESEC_ACL',0x800000)
VSUID = Constant('VSUID',0x800)
VSGID = Constant('VSGID',0x400)
VSVTX = Constant('VSVTX',0x200)
VREAD = Constant('VREAD',0x100)
VWRITE = Constant('VWRITE',0x080)
VEXEC = Constant('VEXEC',0x040)
SKIPSYSTEM = Constant('SKIPSYSTEM',0x0001)
FORCECLOSE = Constant('FORCECLOSE',0x0002)
WRITECLOSE = Constant('WRITECLOSE',0x0004)
SKIPSWAP = Constant('SKIPSWAP',0x0008)
SKIPROOT = Constant('SKIPROOT',0x0010)
DOCLOSE = Constant('DOCLOSE',0x0008)
V_SAVE = Constant('V_SAVE',0x0001)
V_SAVEMETA = Constant('V_SAVEMETA',0x0002)
REVOKEALL = Constant('REVOKEALL',0x0001)
VNODE_REMOVE_NODELETEBUSY = Constant('VNODE_REMOVE_NODELETEBUSY',0x0001)
VNODE_REMOVE_SKIP_NAMESPACE_EVENT = Constant('VNODE_REMOVE_SKIP_NAMESPACE_EVENT',0x0002)
VNODE_REMOVE_NO_AUDIT_PATH = Constant('VNODE_REMOVE_NO_AUDIT_PATH',0x0004)
VNODE_REMOVE_DATALESS_DIR = Constant('VNODE_REMOVE_DATALESS_DIR',0x0008)
VNODE_READDIR_EXTENDED = Constant('VNODE_READDIR_EXTENDED',0x0001)
VNODE_READDIR_REQSEEKOFF = Constant('VNODE_READDIR_REQSEEKOFF',0x0002)
VNODE_READDIR_SEEKOFF32 = Constant('VNODE_READDIR_SEEKOFF32',0x0004)
VNODE_READDIR_NAMEMAX = Constant('VNODE_READDIR_NAMEMAX',0x0008)
VNODE_CLONEFILE_DEFAULT = Constant('VNODE_CLONEFILE_DEFAULT',0x0000)
VNODE_CLONEFILE_NOOWNERCOPY = Constant('VNODE_CLONEFILE_NOOWNERCOPY',0x0001)
VNODE_ASYNC_THROTTLE = Constant('VNODE_ASYNC_THROTTLE',15)
VNODE_UPDATE_PARENT = Constant('VNODE_UPDATE_PARENT',0x01)
VNODE_UPDATE_NAME = Constant('VNODE_UPDATE_NAME',0x02)
VNODE_UPDATE_CACHE = Constant('VNODE_UPDATE_CACHE',0x04)
VNODE_UPDATE_PURGE = Constant('VNODE_UPDATE_PURGE',0x08)
VNODE_LOOKUP_NOFOLLOW = Constant('VNODE_LOOKUP_NOFOLLOW',0x01)
VNODE_LOOKUP_NOCROSSMOUNT = Constant('VNODE_LOOKUP_NOCROSSMOUNT',0x02)
VNODE_LOOKUP_CROSSMOUNTNOWAIT = Constant('VNODE_LOOKUP_CROSSMOUNTNOWAIT',0x04)
VNODE_LOOKUP_NOFOLLOW_ANY = Constant('VNODE_LOOKUP_NOFOLLOW_ANY',0x08)
VNODE_RELOAD = Constant('VNODE_RELOAD',0x01)
VNODE_WAIT = Constant('VNODE_WAIT',0x02)
VNODE_WRITEABLE = Constant('VNODE_WRITEABLE',0x04)
VNODE_WITHID = Constant('VNODE_WITHID',0x08)
VNODE_NOLOCK_INTERNAL = Constant('VNODE_NOLOCK_INTERNAL',0x10)
VNODE_NODEAD = Constant('VNODE_NODEAD',0x20)
VNODE_NOSUSPEND = Constant('VNODE_NOSUSPEND',0x40)
VNODE_ITERATE_ALL = Constant('VNODE_ITERATE_ALL',0x80)
VNODE_ITERATE_ACTIVE = Constant('VNODE_ITERATE_ACTIVE',0x100)
VNODE_ITERATE_INACTIVE = Constant('VNODE_ITERATE_INACTIVE',0x200)
VNODE_RETURNED = Constant('VNODE_RETURNED',0)
VNODE_RETURNED_DONE = Constant('VNODE_RETURNED_DONE',1)
VNODE_CLAIMED = Constant('VNODE_CLAIMED',2)
VNODE_CLAIMED_DONE = Constant('VNODE_CLAIMED_DONE',3)
IOCS_BUFFER_NUM_SIZE_BUCKETS = Constant('IOCS_BUFFER_NUM_SIZE_BUCKETS',10)
IOCS_BUFFER_MAX_BUCKET = Constant('IOCS_BUFFER_MAX_BUCKET',9)
IOCS_BUFFER_NUM_COMPRESSION_BUCKETS = Constant('IOCS_BUFFER_NUM_COMPRESSION_BUCKETS',7)
IOCS_BLOCK_NUM_SIZE_BUCKETS = Constant('IOCS_BLOCK_NUM_SIZE_BUCKETS',16)
IOCS_SBE_PATH_LEN = Constant('IOCS_SBE_PATH_LEN',128)
IOCS_PATH_START_BYTES_TO_COPY = Constant('IOCS_PATH_START_BYTES_TO_COPY',108)
IOCS_PATH_END_BYTES_TO_COPY = Constant('IOCS_PATH_END_BYTES_TO_COPY',20)
IOCS_SYSCTL_LIVE = Constant('IOCS_SYSCTL_LIVE',0x00000001)
IOCS_SYSCTL_STORE_BUFFER_RD_ONLY = Constant('IOCS_SYSCTL_STORE_BUFFER_RD_ONLY',0x00000002)
IOCS_SYSCTL_STORE_BUFFER_MARK = Constant('IOCS_SYSCTL_STORE_BUFFER_MARK',0x00000004)
TANDEM = Constant('TANDEM',0x00000001)
CBREAK = Constant('CBREAK',0x00000002)
LCASE = Constant('LCASE',0x00000004)
ECHO = Constant('ECHO',0x00000008)
CRMOD = Constant('CRMOD',0x00000010)
RAW = Constant('RAW',0x00000020)
ODDP = Constant('ODDP',0x00000040)
EVENP = Constant('EVENP',0x00000080)
ANYP = Constant('ANYP',0x000000c0)
NLDELAY = Constant('NLDELAY',0x00000300)
TBDELAY = Constant('TBDELAY',0x00000c00)
XTABS = Constant('XTABS',0x00000c00)
CRDELAY = Constant('CRDELAY',0x00003000)
VTDELAY = Constant('VTDELAY',0x00004000)
BSDELAY = Constant('BSDELAY',0x00008000)
NL0 = Constant('NL0',0x00000000)
NL1 = Constant('NL1',0x00000100)
NL2 = Constant('NL2',0x00000200)
NL3 = Constant('NL3',0x00000300)
TAB0 = Constant('TAB0',0x00000000)
TAB1 = Constant('TAB1',0x00000400)
TAB2 = Constant('TAB2',0x00000800)
CR0 = Constant('CR0',0x00000000)
CR1 = Constant('CR1',0x00001000)
CR2 = Constant('CR2',0x00002000)
CR3 = Constant('CR3',0x00003000)
FF0 = Constant('FF0',0x00000000)
FF1 = Constant('FF1',0x00004000)
BS0 = Constant('BS0',0x00000000)
BS1 = Constant('BS1',0x00008000)
CRTBS = Constant('CRTBS',0x00010000)
PRTERA = Constant('PRTERA',0x00020000)
CRTERA = Constant('CRTERA',0x00040000)
TILDE = Constant('TILDE',0x00080000)
MDMBUF = Constant('MDMBUF',0x00100000)
LITOUT = Constant('LITOUT',0x00200000)
TOSTOP = Constant('TOSTOP',0x00400000)
FLUSHO = Constant('FLUSHO',0x00800000)
NOHANG = Constant('NOHANG',0x01000000)
L001000 = Constant('L001000',0x02000000)
CRTKIL = Constant('CRTKIL',0x04000000)
PASS8 = Constant('PASS8',0x08000000)
CTLECH = Constant('CTLECH',0x10000000)
PENDIN = Constant('PENDIN',0x20000000)
DECCTQ = Constant('DECCTQ',0x40000000)
NOFLSH = Constant('NOFLSH',0x80000000)
OTTYDISC = Constant('OTTYDISC',0)
NETLDISC = Constant('NETLDISC',1)
NTTYDISC = Constant('NTTYDISC',2)
LOCKLEAF = Constant('LOCKLEAF',0x0004)
LOCKPARENT = Constant('LOCKPARENT',0x0008)
WANTPARENT = Constant('WANTPARENT',0x0010)
UIO_MAXIOV = Constant('UIO_MAXIOV',1024)
UIO_SMALLIOV = Constant('UIO_SMALLIOV',8)
EVFILT_SYSCOUNT = Constant('EVFILT_SYSCOUNT',18)
KEVENT_FLAG_NONE = Constant('KEVENT_FLAG_NONE',0x000000)
KEVENT_FLAG_IMMEDIATE = Constant('KEVENT_FLAG_IMMEDIATE',0x000001)
KEVENT_FLAG_ERROR_EVENTS = Constant('KEVENT_FLAG_ERROR_EVENTS',0x000002)
EV_ADD = Constant('EV_ADD',0x0001)
EV_DELETE = Constant('EV_DELETE',0x0002)
EV_ENABLE = Constant('EV_ENABLE',0x0004)
EV_DISABLE = Constant('EV_DISABLE',0x0008)
EV_ONESHOT = Constant('EV_ONESHOT',0x0010)
EV_CLEAR = Constant('EV_CLEAR',0x0020)
EV_RECEIPT = Constant('EV_RECEIPT',0x0040)
EV_DISPATCH = Constant('EV_DISPATCH',0x0080)
EV_UDATA_SPECIFIC = Constant('EV_UDATA_SPECIFIC',0x0100)
EV_VANISHED = Constant('EV_VANISHED',0x0200)
EV_SYSFLAGS = Constant('EV_SYSFLAGS',0xF000)
EV_FLAG0 = Constant('EV_FLAG0',0x1000)
EV_FLAG1 = Constant('EV_FLAG1',0x2000)
EV_EOF = Constant('EV_EOF',0x8000)
EV_ERROR = Constant('EV_ERROR',0x4000)
NOTE_TRIGGER = Constant('NOTE_TRIGGER',0x01000000)
NOTE_FFNOP = Constant('NOTE_FFNOP',0x00000000)
NOTE_FFAND = Constant('NOTE_FFAND',0x40000000)
NOTE_FFOR = Constant('NOTE_FFOR',0x80000000)
NOTE_FFCOPY = Constant('NOTE_FFCOPY',0xc0000000)
NOTE_FFCTRLMASK = Constant('NOTE_FFCTRLMASK',0xc0000000)
NOTE_FFLAGSMASK = Constant('NOTE_FFLAGSMASK',0x00ffffff)
NOTE_LOWAT = Constant('NOTE_LOWAT',0x00000001)
NOTE_OOB = Constant('NOTE_OOB',0x00000002)
NOTE_DELETE = Constant('NOTE_DELETE',0x00000001)
NOTE_WRITE = Constant('NOTE_WRITE',0x00000002)
NOTE_EXTEND = Constant('NOTE_EXTEND',0x00000004)
NOTE_ATTRIB = Constant('NOTE_ATTRIB',0x00000008)
NOTE_LINK = Constant('NOTE_LINK',0x00000010)
NOTE_RENAME = Constant('NOTE_RENAME',0x00000020)
NOTE_REVOKE = Constant('NOTE_REVOKE',0x00000040)
NOTE_NONE = Constant('NOTE_NONE',0x00000080)
NOTE_FUNLOCK = Constant('NOTE_FUNLOCK',0x00000100)
NOTE_LEASE_DOWNGRADE = Constant('NOTE_LEASE_DOWNGRADE',0x00000200)
NOTE_LEASE_RELEASE = Constant('NOTE_LEASE_RELEASE',0x00000400)
NOTE_EXIT = Constant('NOTE_EXIT',0x80000000)
NOTE_FORK = Constant('NOTE_FORK',0x40000000)
NOTE_EXEC = Constant('NOTE_EXEC',0x20000000)
NOTE_SIGNAL = Constant('NOTE_SIGNAL',0x08000000)
NOTE_EXITSTATUS = Constant('NOTE_EXITSTATUS',0x04000000)
NOTE_EXIT_DETAIL = Constant('NOTE_EXIT_DETAIL',0x02000000)
NOTE_PDATAMASK = Constant('NOTE_PDATAMASK',0x000fffff)
NOTE_EXIT_DETAIL_MASK = Constant('NOTE_EXIT_DETAIL_MASK',0x00070000)
NOTE_EXIT_DECRYPTFAIL = Constant('NOTE_EXIT_DECRYPTFAIL',0x00010000)
NOTE_EXIT_MEMORY = Constant('NOTE_EXIT_MEMORY',0x00020000)
NOTE_EXIT_CSERROR = Constant('NOTE_EXIT_CSERROR',0x00040000)
NOTE_VM_PRESSURE = Constant('NOTE_VM_PRESSURE',0x80000000)
NOTE_VM_PRESSURE_TERMINATE = Constant('NOTE_VM_PRESSURE_TERMINATE',0x40000000)
NOTE_VM_PRESSURE_SUDDEN_TERMINATE = Constant('NOTE_VM_PRESSURE_SUDDEN_TERMINATE',0x20000000)
NOTE_VM_ERROR = Constant('NOTE_VM_ERROR',0x10000000)
NOTE_SECONDS = Constant('NOTE_SECONDS',0x00000001)
NOTE_USECONDS = Constant('NOTE_USECONDS',0x00000002)
NOTE_NSECONDS = Constant('NOTE_NSECONDS',0x00000004)
NOTE_ABSOLUTE = Constant('NOTE_ABSOLUTE',0x00000008)
NOTE_LEEWAY = Constant('NOTE_LEEWAY',0x00000010)
NOTE_CRITICAL = Constant('NOTE_CRITICAL',0x00000020)
NOTE_BACKGROUND = Constant('NOTE_BACKGROUND',0x00000040)
NOTE_MACH_CONTINUOUS_TIME = Constant('NOTE_MACH_CONTINUOUS_TIME',0x00000080)
NOTE_MACHTIME = Constant('NOTE_MACHTIME',0x00000100)
NOTE_TRACK = Constant('NOTE_TRACK',0x00000001)
NOTE_TRACKERR = Constant('NOTE_TRACKERR',0x00000002)
NOTE_CHILD = Constant('NOTE_CHILD',0x00000004)
VMADDR_CID_HYPERVISOR = Constant('VMADDR_CID_HYPERVISOR',0)
VMADDR_CID_RESERVED = Constant('VMADDR_CID_RESERVED',1)
VMADDR_CID_HOST = Constant('VMADDR_CID_HOST',2)
IMG_SHSIZE = Constant('IMG_SHSIZE',512)
IMGPF_NONE = Constant('IMGPF_NONE',0x00000000)
IMGPF_INTERPRET = Constant('IMGPF_INTERPRET',0x00000001)
IMGPF_RESERVED = Constant('IMGPF_RESERVED',0x00000002)
IMGPF_WAS_64BIT_ADDR = Constant('IMGPF_WAS_64BIT_ADDR',0x00000004)
IMGPF_IS_64BIT_ADDR = Constant('IMGPF_IS_64BIT_ADDR',0x00000008)
IMGPF_SPAWN = Constant('IMGPF_SPAWN',0x00000010)
IMGPF_DISABLE_ASLR = Constant('IMGPF_DISABLE_ASLR',0x00000020)
IMGPF_ALLOW_DATA_EXEC = Constant('IMGPF_ALLOW_DATA_EXEC',0x00000040)
IMGPF_3P_PLUGINS = Constant('IMGPF_3P_PLUGINS',0x00000080)
IMGPF_EXEC = Constant('IMGPF_EXEC',0x00000100)
IMGPF_HIGH_BITS_ASLR = Constant('IMGPF_HIGH_BITS_ASLR',0x00000200)
IMGPF_IS_64BIT_DATA = Constant('IMGPF_IS_64BIT_DATA',0x00000400)
IMGPF_DRIVER = Constant('IMGPF_DRIVER',0x00000800)
IMGPF_RESLIDE = Constant('IMGPF_RESLIDE',0x00001000)
IMGPF_PLUGIN_HOST_DISABLE_A_KEYS = Constant('IMGPF_PLUGIN_HOST_DISABLE_A_KEYS',0x00002000)
IMGPF_HW_TPRO = Constant('IMGPF_HW_TPRO',0x00004000)
IMGPF_ROSETTA = Constant('IMGPF_ROSETTA',0x10000000)
IMGPF_ALT_ROSETTA = Constant('IMGPF_ALT_ROSETTA',0x20000000)
IMGPF_RESERVED_2 = Constant('IMGPF_RESERVED_2',0x40000000)
IMGPF_NOJOP = Constant('IMGPF_NOJOP',0x80000000)
IMGPF_SB_DEFAULT = Constant('IMGPF_SB_DEFAULT',0)
IMGPF_SB_TRUE = Constant('IMGPF_SB_TRUE',1)
IMGPF_SB_FALSE = Constant('IMGPF_SB_FALSE',2)
_POSIX_THREAD_KEYS_MAX = Constant('_POSIX_THREAD_KEYS_MAX',128)
F_OK = Constant('F_OK',0)
ACCESSX_MAX_DESCRIPTORS = Constant('ACCESSX_MAX_DESCRIPTORS',100)
_PC_LINK_MAX = Constant('_PC_LINK_MAX',1)
_PC_MAX_CANON = Constant('_PC_MAX_CANON',2)
_PC_MAX_INPUT = Constant('_PC_MAX_INPUT',3)
_PC_NAME_MAX = Constant('_PC_NAME_MAX',4)
_PC_PATH_MAX = Constant('_PC_PATH_MAX',5)
_PC_PIPE_BUF = Constant('_PC_PIPE_BUF',6)
_PC_CHOWN_RESTRICTED = Constant('_PC_CHOWN_RESTRICTED',7)
_PC_NO_TRUNC = Constant('_PC_NO_TRUNC',8)
_PC_VDISABLE = Constant('_PC_VDISABLE',9)
_PC_NAME_CHARS_MAX = Constant('_PC_NAME_CHARS_MAX',10)
_PC_CASE_SENSITIVE = Constant('_PC_CASE_SENSITIVE',11)
_PC_CASE_PRESERVING = Constant('_PC_CASE_PRESERVING',12)
_PC_EXTENDED_SECURITY_NP = Constant('_PC_EXTENDED_SECURITY_NP',13)
_PC_AUTH_OPAQUE_NP = Constant('_PC_AUTH_OPAQUE_NP',14)
_PC_2_SYMLINKS = Constant('_PC_2_SYMLINKS',15)
_PC_ALLOC_SIZE_MIN = Constant('_PC_ALLOC_SIZE_MIN',16)
_PC_ASYNC_IO = Constant('_PC_ASYNC_IO',17)
_PC_FILESIZEBITS = Constant('_PC_FILESIZEBITS',18)
_PC_PRIO_IO = Constant('_PC_PRIO_IO',19)
_PC_REC_INCR_XFER_SIZE = Constant('_PC_REC_INCR_XFER_SIZE',20)
_PC_REC_MAX_XFER_SIZE = Constant('_PC_REC_MAX_XFER_SIZE',21)
_PC_REC_MIN_XFER_SIZE = Constant('_PC_REC_MIN_XFER_SIZE',22)
_PC_REC_XFER_ALIGN = Constant('_PC_REC_XFER_ALIGN',23)
_PC_SYMLINK_MAX = Constant('_PC_SYMLINK_MAX',24)
_PC_SYNC_IO = Constant('_PC_SYNC_IO',25)
_PC_XATTR_SIZE_BITS = Constant('_PC_XATTR_SIZE_BITS',26)
_PC_MIN_HOLE_SIZE = Constant('_PC_MIN_HOLE_SIZE',27)
_CS_PATH = Constant('_CS_PATH',1)
_SYS_CONF_H_ = Constant('_SYS_CONF_H_',1)
D_TAPE = Constant('D_TAPE',1)
D_DISK = Constant('D_DISK',2)
D_TTY = Constant('D_TTY',3)
WNOHANG = Constant('WNOHANG',0x00000001)
WUNTRACED = Constant('WUNTRACED',0x00000002)
WCOREFLAG = Constant('WCOREFLAG',0o0200)
_WSTOPPED = Constant('_WSTOPPED',0o0177)
WEXITED = Constant('WEXITED',0x00000004)
WSTOPPED = Constant('WSTOPPED',0x00000008)
WCONTINUED = Constant('WCONTINUED',0x00000010)
WNOWAIT = Constant('WNOWAIT',0x00000020)
WAIT_MYPGRP = Constant('WAIT_MYPGRP',0)
PRIO_DARWIN_GPU = Constant('PRIO_DARWIN_GPU',5)
PRIO_DARWIN_GPU_ALLOW = Constant('PRIO_DARWIN_GPU_ALLOW',0x1)
PRIO_DARWIN_GPU_DENY = Constant('PRIO_DARWIN_GPU_DENY',0x2)
PRIO_DARWIN_ROLE = Constant('PRIO_DARWIN_ROLE',6)
PRIO_DARWIN_ROLE_DEFAULT = Constant('PRIO_DARWIN_ROLE_DEFAULT',0x0)
PRIO_DARWIN_ROLE_UI_FOCAL = Constant('PRIO_DARWIN_ROLE_UI_FOCAL',0x1)
PRIO_DARWIN_ROLE_UI = Constant('PRIO_DARWIN_ROLE_UI',0x2)
PRIO_DARWIN_ROLE_NON_UI = Constant('PRIO_DARWIN_ROLE_NON_UI',0x3)
PRIO_DARWIN_ROLE_UI_NON_FOCAL = Constant('PRIO_DARWIN_ROLE_UI_NON_FOCAL',0x4)
PRIO_DARWIN_ROLE_TAL_LAUNCH = Constant('PRIO_DARWIN_ROLE_TAL_LAUNCH',0x5)
PRIO_DARWIN_ROLE_DARWIN_BG = Constant('PRIO_DARWIN_ROLE_DARWIN_BG',0x6)
PRIO_DARWIN_GAME_MODE = Constant('PRIO_DARWIN_GAME_MODE',7)
PRIO_DARWIN_CARPLAY_MODE = Constant('PRIO_DARWIN_CARPLAY_MODE',8)
PRIO_DARWIN_GAME_MODE_OFF = Constant('PRIO_DARWIN_GAME_MODE_OFF',0x0)
PRIO_DARWIN_GAME_MODE_ON = Constant('PRIO_DARWIN_GAME_MODE_ON',0x1)
PRIO_DARWIN_CARPLAY_MODE_OFF = Constant('PRIO_DARWIN_CARPLAY_MODE_OFF',0x0)
PRIO_DARWIN_CARPLAY_MODE_ON = Constant('PRIO_DARWIN_CARPLAY_MODE_ON',0x1)
IOMON_ENABLE = Constant('IOMON_ENABLE',0x01)
IOMON_DISABLE = Constant('IOMON_DISABLE',0x02)
IOPOL_TYPE_VFS_HFS_CASE_SENSITIVITY = Constant('IOPOL_TYPE_VFS_HFS_CASE_SENSITIVITY',1)
IOPOL_TYPE_VFS_ALTLINK = Constant('IOPOL_TYPE_VFS_ALTLINK',11)
IOPOL_TYPE_VFS_NOCACHE_WRITE_FS_BLKSIZE = Constant('IOPOL_TYPE_VFS_NOCACHE_WRITE_FS_BLKSIZE',12)
IOPOL_VFS_HFS_CASE_SENSITIVITY_DEFAULT = Constant('IOPOL_VFS_HFS_CASE_SENSITIVITY_DEFAULT',0)
IOPOL_VFS_HFS_CASE_SENSITIVITY_FORCE_CASE_SENSITIVE = Constant('IOPOL_VFS_HFS_CASE_SENSITIVITY_FORCE_CASE_SENSITIVE',1)
IOPOL_VFS_ALTLINK_DISABLED = Constant('IOPOL_VFS_ALTLINK_DISABLED',0)
IOPOL_VFS_ALTLINK_ENABLED = Constant('IOPOL_VFS_ALTLINK_ENABLED',1)
IOPOL_CMD_GET = Constant('IOPOL_CMD_GET',0x00000001)
IOPOL_CMD_SET = Constant('IOPOL_CMD_SET',0x00000002)
IPC_CREAT = Constant('IPC_CREAT',0o001000)
IPC_EXCL = Constant('IPC_EXCL',0o002000)
IPC_NOWAIT = Constant('IPC_NOWAIT',0o004000)
IPC_RMID = Constant('IPC_RMID',0)
IPC_SET = Constant('IPC_SET',1)
IPC_STAT = Constant('IPC_STAT',2)
IPC_R = Constant('IPC_R',0o000400)
IPC_W = Constant('IPC_W',0o000200)
IPC_M = Constant('IPC_M',0o010000)
O_RDONLY = Constant('O_RDONLY',0x0000)
O_WRONLY = Constant('O_WRONLY',0x0001)
O_RDWR = Constant('O_RDWR',0x0002)
O_ACCMODE = Constant('O_ACCMODE',0x0003)
FREAD = Constant('FREAD',0x00000001)
FWRITE = Constant('FWRITE',0x00000002)
O_NONBLOCK = Constant('O_NONBLOCK',0x00000004)
O_APPEND = Constant('O_APPEND',0x00000008)
O_SHLOCK = Constant('O_SHLOCK',0x00000010)
O_EXLOCK = Constant('O_EXLOCK',0x00000020)
O_ASYNC = Constant('O_ASYNC',0x00000040)
O_NOFOLLOW = Constant('O_NOFOLLOW',0x00000100)
O_CREAT = Constant('O_CREAT',0x00000200)
O_TRUNC = Constant('O_TRUNC',0x00000400)
O_EXCL = Constant('O_EXCL',0x00000800)
FMARK = Constant('FMARK',0x00001000)
FDEFER = Constant('FDEFER',0x00002000)
FWASLOCKED = Constant('FWASLOCKED',0x00004000)
O_EVTONLY = Constant('O_EVTONLY',0x00008000)
FWASWRITTEN = Constant('FWASWRITTEN',0x00010000)
O_NOCTTY = Constant('O_NOCTTY',0x00020000)
FNOCACHE = Constant('FNOCACHE',0x00040000)
FNORDAHEAD = Constant('FNORDAHEAD',0x00080000)
O_DIRECTORY = Constant('O_DIRECTORY',0x00100000)
O_SYMLINK = Constant('O_SYMLINK',0x00200000)
FNODIRECT = Constant('FNODIRECT',0x00800000)
O_CLOEXEC = Constant('O_CLOEXEC',0x01000000)
FENCRYPTED = Constant('FENCRYPTED',0x02000000)
FSINGLE_WRITER = Constant('FSINGLE_WRITER',0x04000000)
O_CLOFORK = Constant('O_CLOFORK',0x08000000)
FUNENCRYPTED = Constant('FUNENCRYPTED',0x10000000)
O_NOFOLLOW_ANY = Constant('O_NOFOLLOW_ANY',0x20000000)
O_EXEC = Constant('O_EXEC',0x40000000)
AT_EACCESS = Constant('AT_EACCESS',0x0010)
AT_SYMLINK_NOFOLLOW = Constant('AT_SYMLINK_NOFOLLOW',0x0020)
AT_SYMLINK_FOLLOW = Constant('AT_SYMLINK_FOLLOW',0x0040)
AT_REMOVEDIR = Constant('AT_REMOVEDIR',0x0080)
AT_REALDEV = Constant('AT_REALDEV',0x0200)
AT_FDONLY = Constant('AT_FDONLY',0x0400)
AT_SYMLINK_NOFOLLOW_ANY = Constant('AT_SYMLINK_NOFOLLOW_ANY',0x0800)
O_DP_GETRAWENCRYPTED = Constant('O_DP_GETRAWENCRYPTED',0x0001)
O_DP_GETRAWUNENCRYPTED = Constant('O_DP_GETRAWUNENCRYPTED',0x0002)
O_DP_AUTHENTICATE = Constant('O_DP_AUTHENTICATE',0x0004)
CPF_OVERWRITE = Constant('CPF_OVERWRITE',0x0001)
CPF_IGNORE_MODE = Constant('CPF_IGNORE_MODE',0x0002)
F_DUPFD = Constant('F_DUPFD',0)
F_GETFD = Constant('F_GETFD',1)
F_SETFD = Constant('F_SETFD',2)
F_GETFL = Constant('F_GETFL',3)
F_SETFL = Constant('F_SETFL',4)
F_GETOWN = Constant('F_GETOWN',5)
F_SETOWN = Constant('F_SETOWN',6)
F_GETLK = Constant('F_GETLK',7)
F_SETLK = Constant('F_SETLK',8)
F_SETLKW = Constant('F_SETLKW',9)
F_SETLKWTIMEOUT = Constant('F_SETLKWTIMEOUT',10)
F_FLUSH_DATA = Constant('F_FLUSH_DATA',40)
F_CHKCLEAN = Constant('F_CHKCLEAN',41)
F_PREALLOCATE = Constant('F_PREALLOCATE',42)
F_SETSIZE = Constant('F_SETSIZE',43)
F_RDADVISE = Constant('F_RDADVISE',44)
F_RDAHEAD = Constant('F_RDAHEAD',45)
F_NOCACHE = Constant('F_NOCACHE',48)
F_LOG2PHYS = Constant('F_LOG2PHYS',49)
F_GETPATH = Constant('F_GETPATH',50)
F_FULLFSYNC = Constant('F_FULLFSYNC',51)
F_PATHPKG_CHECK = Constant('F_PATHPKG_CHECK',52)
F_FREEZE_FS = Constant('F_FREEZE_FS',53)
F_THAW_FS = Constant('F_THAW_FS',54)
F_GLOBAL_NOCACHE = Constant('F_GLOBAL_NOCACHE',55)
F_ADDSIGS = Constant('F_ADDSIGS',59)
F_ADDFILESIGS = Constant('F_ADDFILESIGS',61)
F_NODIRECT = Constant('F_NODIRECT',62)
F_GETPROTECTIONCLASS = Constant('F_GETPROTECTIONCLASS',63)
F_SETPROTECTIONCLASS = Constant('F_SETPROTECTIONCLASS',64)
F_LOG2PHYS_EXT = Constant('F_LOG2PHYS_EXT',65)
F_GETLKPID = Constant('F_GETLKPID',66)
F_SETBACKINGSTORE = Constant('F_SETBACKINGSTORE',70)
F_GETPATH_MTMINFO = Constant('F_GETPATH_MTMINFO',71)
F_GETCODEDIR = Constant('F_GETCODEDIR',72)
F_SETNOSIGPIPE = Constant('F_SETNOSIGPIPE',73)
F_GETNOSIGPIPE = Constant('F_GETNOSIGPIPE',74)
F_TRANSCODEKEY = Constant('F_TRANSCODEKEY',75)
F_SINGLE_WRITER = Constant('F_SINGLE_WRITER',76)
F_GETPROTECTIONLEVEL = Constant('F_GETPROTECTIONLEVEL',77)
F_FINDSIGS = Constant('F_FINDSIGS',78)
F_ADDFILESIGS_FOR_DYLD_SIM = Constant('F_ADDFILESIGS_FOR_DYLD_SIM',83)
F_BARRIERFSYNC = Constant('F_BARRIERFSYNC',85)
F_OFD_SETLK = Constant('F_OFD_SETLK',90)
F_OFD_SETLKW = Constant('F_OFD_SETLKW',91)
F_OFD_GETLK = Constant('F_OFD_GETLK',92)
F_OFD_SETLKWTIMEOUT = Constant('F_OFD_SETLKWTIMEOUT',93)
F_ADDFILESIGS_RETURN = Constant('F_ADDFILESIGS_RETURN',97)
F_CHECK_LV = Constant('F_CHECK_LV',98)
F_PUNCHHOLE = Constant('F_PUNCHHOLE',99)
F_TRIM_ACTIVE_FILE = Constant('F_TRIM_ACTIVE_FILE',100)
F_SPECULATIVE_READ = Constant('F_SPECULATIVE_READ',101)
F_GETPATH_NOFIRMLINK = Constant('F_GETPATH_NOFIRMLINK',102)
F_ADDFILESIGS_INFO = Constant('F_ADDFILESIGS_INFO',103)
F_ADDFILESUPPL = Constant('F_ADDFILESUPPL',104)
F_GETSIGSINFO = Constant('F_GETSIGSINFO',105)
F_SETLEASE = Constant('F_SETLEASE',106)
F_GETLEASE = Constant('F_GETLEASE',107)
F_TRANSFEREXTENTS = Constant('F_TRANSFEREXTENTS',110)
F_ATTRIBUTION_TAG = Constant('F_ATTRIBUTION_TAG',111)
F_ADDSIGS_MAIN_BINARY = Constant('F_ADDSIGS_MAIN_BINARY',113)
FCNTL_FS_SPECIFIC_BASE = Constant('FCNTL_FS_SPECIFIC_BASE',0x00010000)
F_DUPFD_CLOEXEC = Constant('F_DUPFD_CLOEXEC',67)
FD_CLOEXEC = Constant('FD_CLOEXEC',1)
F_RDLCK = Constant('F_RDLCK',1)
F_UNLCK = Constant('F_UNLCK',2)
F_WRLCK = Constant('F_WRLCK',3)
F_WAIT = Constant('F_WAIT',0x010)
F_FLOCK = Constant('F_FLOCK',0x020)
F_POSIX = Constant('F_POSIX',0x040)
F_PROV = Constant('F_PROV',0x080)
F_WAKE1_SAFE = Constant('F_WAKE1_SAFE',0x100)
F_ABORT = Constant('F_ABORT',0x200)
F_OFD_LOCK = Constant('F_OFD_LOCK',0x400)
F_TRANSFER = Constant('F_TRANSFER',0x800)
F_CONFINED = Constant('F_CONFINED',0x1000)
F_ALLOCATECONTIG = Constant('F_ALLOCATECONTIG',0x00000002)
F_ALLOCATEALL = Constant('F_ALLOCATEALL',0x00000004)
F_ALLOCATEPERSIST = Constant('F_ALLOCATEPERSIST',0x00000008)
F_PEOFPOSMODE = Constant('F_PEOFPOSMODE',3)
F_VOLPOSMODE = Constant('F_VOLPOSMODE',4)
USER_FSIGNATURES_CDHASH_LEN = Constant('USER_FSIGNATURES_CDHASH_LEN',20)
GETSIGSINFO_PLATFORM_BINARY = Constant('GETSIGSINFO_PLATFORM_BINARY',1)
LOCK_SH = Constant('LOCK_SH',0x01)
LOCK_EX = Constant('LOCK_EX',0x02)
LOCK_NB = Constant('LOCK_NB',0x04)
LOCK_UN = Constant('LOCK_UN',0x08)
ATTRIBUTION_NAME_MAX = Constant('ATTRIBUTION_NAME_MAX',255)
F_CREATE_TAG = Constant('F_CREATE_TAG',0x00000001)
F_DELETE_TAG = Constant('F_DELETE_TAG',0x00000002)
F_QUERY_TAG = Constant('F_QUERY_TAG',0x00000004)
O_POPUP = Constant('O_POPUP',0x80000000)
O_ALERT = Constant('O_ALERT',0x20000000)
S_BLKSIZE = Constant('S_BLKSIZE',512)
UF_SETTABLE = Constant('UF_SETTABLE',0x0000ffff)
UF_NODUMP = Constant('UF_NODUMP',0x00000001)
UF_IMMUTABLE = Constant('UF_IMMUTABLE',0x00000002)
UF_APPEND = Constant('UF_APPEND',0x00000004)
UF_OPAQUE = Constant('UF_OPAQUE',0x00000008)
UF_COMPRESSED = Constant('UF_COMPRESSED',0x00000020)
UF_TRACKED = Constant('UF_TRACKED',0x00000040)
UF_DATAVAULT = Constant('UF_DATAVAULT',0x00000080)
UF_HIDDEN = Constant('UF_HIDDEN',0x00008000)
SF_SUPPORTED = Constant('SF_SUPPORTED',0x009f0000)
SF_SETTABLE = Constant('SF_SETTABLE',0x3fff0000)
SF_SYNTHETIC = Constant('SF_SYNTHETIC',0xc0000000)
SF_ARCHIVED = Constant('SF_ARCHIVED',0x00010000)
SF_IMMUTABLE = Constant('SF_IMMUTABLE',0x00020000)
SF_APPEND = Constant('SF_APPEND',0x00040000)
SF_RESTRICTED = Constant('SF_RESTRICTED',0x00080000)
SF_NOUNLINK = Constant('SF_NOUNLINK',0x00100000)
SF_FIRMLINK = Constant('SF_FIRMLINK',0x00800000)
SF_DATALESS = Constant('SF_DATALESS',0x40000000)
EF_MAY_SHARE_BLOCKS = Constant('EF_MAY_SHARE_BLOCKS',0x00000001)
EF_NO_XATTRS = Constant('EF_NO_XATTRS',0x00000002)
EF_IS_SYNC_ROOT = Constant('EF_IS_SYNC_ROOT',0x00000004)
EF_IS_PURGEABLE = Constant('EF_IS_PURGEABLE',0x00000008)
EF_IS_SPARSE = Constant('EF_IS_SPARSE',0x00000010)
EF_IS_SYNTHETIC = Constant('EF_IS_SYNTHETIC',0x00000020)
EF_SHARES_ALL_BLOCKS = Constant('EF_SHARES_ALL_BLOCKS',0x00000040)
MBUF_COPYALL = Constant('MBUF_COPYALL',1000000000)
__DARWIN_NSIG = Constant('__DARWIN_NSIG',32)
SIGHUP = Constant('SIGHUP',1)
SIGINT = Constant('SIGINT',2)
SIGQUIT = Constant('SIGQUIT',3)
SIGILL = Constant('SIGILL',4)
SIGTRAP = Constant('SIGTRAP',5)
SIGABRT = Constant('SIGABRT',6)
SIGPOLL = Constant('SIGPOLL',7)
SIGEMT = Constant('SIGEMT',7)
SIGFPE = Constant('SIGFPE',8)
SIGKILL = Constant('SIGKILL',9)
SIGBUS = Constant('SIGBUS',10)
SIGSEGV = Constant('SIGSEGV',11)
SIGSYS = Constant('SIGSYS',12)
SIGPIPE = Constant('SIGPIPE',13)
SIGALRM = Constant('SIGALRM',14)
SIGTERM = Constant('SIGTERM',15)
SIGURG = Constant('SIGURG',16)
SIGSTOP = Constant('SIGSTOP',17)
SIGTSTP = Constant('SIGTSTP',18)
SIGCONT = Constant('SIGCONT',19)
SIGCHLD = Constant('SIGCHLD',20)
SIGTTIN = Constant('SIGTTIN',21)
SIGTTOU = Constant('SIGTTOU',22)
SIGIO = Constant('SIGIO',23)
SIGXCPU = Constant('SIGXCPU',24)
SIGXFSZ = Constant('SIGXFSZ',25)
SIGVTALRM = Constant('SIGVTALRM',26)
SIGPROF = Constant('SIGPROF',27)
SIGWINCH = Constant('SIGWINCH',28)
SIGINFO = Constant('SIGINFO',29)
SIGUSR1 = Constant('SIGUSR1',30)
SIGUSR2 = Constant('SIGUSR2',31)
SIGEV_NONE = Constant('SIGEV_NONE',0)
SIGEV_SIGNAL = Constant('SIGEV_SIGNAL',1)
SIGEV_THREAD = Constant('SIGEV_THREAD',3)
ILL_NOOP = Constant('ILL_NOOP',0)
ILL_ILLOPC = Constant('ILL_ILLOPC',1)
ILL_ILLTRP = Constant('ILL_ILLTRP',2)
ILL_PRVOPC = Constant('ILL_PRVOPC',3)
ILL_ILLOPN = Constant('ILL_ILLOPN',4)
ILL_ILLADR = Constant('ILL_ILLADR',5)
ILL_PRVREG = Constant('ILL_PRVREG',6)
ILL_COPROC = Constant('ILL_COPROC',7)
ILL_BADSTK = Constant('ILL_BADSTK',8)
FPE_NOOP = Constant('FPE_NOOP',0)
FPE_FLTDIV = Constant('FPE_FLTDIV',1)
FPE_FLTOVF = Constant('FPE_FLTOVF',2)
FPE_FLTUND = Constant('FPE_FLTUND',3)
FPE_FLTRES = Constant('FPE_FLTRES',4)
FPE_FLTINV = Constant('FPE_FLTINV',5)
FPE_FLTSUB = Constant('FPE_FLTSUB',6)
FPE_INTDIV = Constant('FPE_INTDIV',7)
FPE_INTOVF = Constant('FPE_INTOVF',8)
SEGV_NOOP = Constant('SEGV_NOOP',0)
SEGV_MAPERR = Constant('SEGV_MAPERR',1)
SEGV_ACCERR = Constant('SEGV_ACCERR',2)
BUS_NOOP = Constant('BUS_NOOP',0)
BUS_ADRALN = Constant('BUS_ADRALN',1)
BUS_ADRERR = Constant('BUS_ADRERR',2)
BUS_OBJERR = Constant('BUS_OBJERR',3)
TRAP_BRKPT = Constant('TRAP_BRKPT',1)
TRAP_TRACE = Constant('TRAP_TRACE',2)
CLD_NOOP = Constant('CLD_NOOP',0)
CLD_EXITED = Constant('CLD_EXITED',1)
CLD_KILLED = Constant('CLD_KILLED',2)
CLD_DUMPED = Constant('CLD_DUMPED',3)
CLD_TRAPPED = Constant('CLD_TRAPPED',4)
CLD_STOPPED = Constant('CLD_STOPPED',5)
CLD_CONTINUED = Constant('CLD_CONTINUED',6)
POLL_IN = Constant('POLL_IN',1)
POLL_OUT = Constant('POLL_OUT',2)
POLL_MSG = Constant('POLL_MSG',3)
POLL_ERR = Constant('POLL_ERR',4)
POLL_PRI = Constant('POLL_PRI',5)
POLL_HUP = Constant('POLL_HUP',6)
SA_ONSTACK = Constant('SA_ONSTACK',0x0001)
SA_RESTART = Constant('SA_RESTART',0x0002)
SA_RESETHAND = Constant('SA_RESETHAND',0x0004)
SA_NOCLDSTOP = Constant('SA_NOCLDSTOP',0x0008)
SA_NODEFER = Constant('SA_NODEFER',0x0010)
SA_NOCLDWAIT = Constant('SA_NOCLDWAIT',0x0020)
SA_SIGINFO = Constant('SA_SIGINFO',0x0040)
SA_USERTRAMP = Constant('SA_USERTRAMP',0x0100)
SA_64REGSET = Constant('SA_64REGSET',0x0200)
SIG_BLOCK = Constant('SIG_BLOCK',1)
SIG_UNBLOCK = Constant('SIG_UNBLOCK',2)
SIG_SETMASK = Constant('SIG_SETMASK',3)
SI_USER = Constant('SI_USER',0x10001)
SI_QUEUE = Constant('SI_QUEUE',0x10002)
SI_TIMER = Constant('SI_TIMER',0x10003)
SI_ASYNCIO = Constant('SI_ASYNCIO',0x10004)
SI_MESGQ = Constant('SI_MESGQ',0x10005)
SS_ONSTACK = Constant('SS_ONSTACK',0x0001)
SS_DISABLE = Constant('SS_DISABLE',0x0004)
MINSIGSTKSZ = Constant('MINSIGSTKSZ',32768)
SIGSTKSZ = Constant('SIGSTKSZ',131072)
__DARWIN_MAXNAMLEN = Constant('__DARWIN_MAXNAMLEN',255)
__DARWIN_MAXPATHLEN = Constant('__DARWIN_MAXPATHLEN',1024)
DT_UNKNOWN = Constant('DT_UNKNOWN',0)
DT_FIFO = Constant('DT_FIFO',1)
DT_CHR = Constant('DT_CHR',2)
DT_DIR = Constant('DT_DIR',4)
DT_BLK = Constant('DT_BLK',6)
DT_REG = Constant('DT_REG',8)
DT_LNK = Constant('DT_LNK',10)
DT_SOCK = Constant('DT_SOCK',12)
DT_WHT = Constant('DT_WHT',14)
POSIX_SPAWN_RESETIDS = Constant('POSIX_SPAWN_RESETIDS',0x0001)
POSIX_SPAWN_SETPGROUP = Constant('POSIX_SPAWN_SETPGROUP',0x0002)
POSIX_SPAWN_SETSIGDEF = Constant('POSIX_SPAWN_SETSIGDEF',0x0004)
POSIX_SPAWN_SETSIGMASK = Constant('POSIX_SPAWN_SETSIGMASK',0x0008)
POSIX_SPAWN_SETSCHEDPARAM = Constant('POSIX_SPAWN_SETSCHEDPARAM',0x0010)
POSIX_SPAWN_SETSCHEDULER = Constant('POSIX_SPAWN_SETSCHEDULER',0x0020)
POSIX_SPAWN_SETEXEC = Constant('POSIX_SPAWN_SETEXEC',0x0040)
POSIX_SPAWN_START_SUSPENDED = Constant('POSIX_SPAWN_START_SUSPENDED',0x0080)
POSIX_SPAWN_SETSID = Constant('POSIX_SPAWN_SETSID',0x0400)
POSIX_SPAWN_CLOEXEC_DEFAULT = Constant('POSIX_SPAWN_CLOEXEC_DEFAULT',0x4000)
_POSIX_SPAWN_RESLIDE = Constant('_POSIX_SPAWN_RESLIDE',0x0800)
POSIX_SPAWN_PCONTROL_NONE = Constant('POSIX_SPAWN_PCONTROL_NONE',0x0000)
POSIX_SPAWN_PCONTROL_THROTTLE = Constant('POSIX_SPAWN_PCONTROL_THROTTLE',0x0001)
POSIX_SPAWN_PCONTROL_SUSPEND = Constant('POSIX_SPAWN_PCONTROL_SUSPEND',0x0002)
POSIX_SPAWN_PCONTROL_KILL = Constant('POSIX_SPAWN_PCONTROL_KILL',0x0003)
POSIX_SPAWN_PANIC_ON_CRASH = Constant('POSIX_SPAWN_PANIC_ON_CRASH',0x1)
POSIX_SPAWN_PANIC_ON_NON_ZERO_EXIT = Constant('POSIX_SPAWN_PANIC_ON_NON_ZERO_EXIT',0x2)
POSIX_SPAWN_PANIC_ON_EXIT = Constant('POSIX_SPAWN_PANIC_ON_EXIT',0x4)
POSIX_SPAWN_PANIC_ON_SPAWN_FAIL = Constant('POSIX_SPAWN_PANIC_ON_SPAWN_FAIL',0x8)
PROT_NONE = Constant('PROT_NONE',0x00)
PROT_READ = Constant('PROT_READ',0x01)
PROT_WRITE = Constant('PROT_WRITE',0x02)
PROT_EXEC = Constant('PROT_EXEC',0x04)
MAP_SHARED = Constant('MAP_SHARED',0x0001)
MAP_PRIVATE = Constant('MAP_PRIVATE',0x0002)
MAP_FIXED = Constant('MAP_FIXED',0x0010)
MAP_RENAME = Constant('MAP_RENAME',0x0020)
MAP_NORESERVE = Constant('MAP_NORESERVE',0x0040)
MAP_RESERVED0080 = Constant('MAP_RESERVED0080',0x0080)
MAP_NOEXTEND = Constant('MAP_NOEXTEND',0x0100)
MAP_HASSEMAPHORE = Constant('MAP_HASSEMAPHORE',0x0200)
MAP_NOCACHE = Constant('MAP_NOCACHE',0x0400)
MAP_JIT = Constant('MAP_JIT',0x0800)
MAP_FILE = Constant('MAP_FILE',0x0000)
MAP_ANON = Constant('MAP_ANON',0x1000)
MAP_RESILIENT_CODESIGN = Constant('MAP_RESILIENT_CODESIGN',0x2000)
MAP_RESILIENT_MEDIA = Constant('MAP_RESILIENT_MEDIA',0x4000)
MAP_32BIT = Constant('MAP_32BIT',0x8000)
MAP_TRANSLATED_ALLOW_EXECUTE = Constant('MAP_TRANSLATED_ALLOW_EXECUTE',0x20000)
MAP_UNIX03 = Constant('MAP_UNIX03',0x40000)
MAP_TPRO = Constant('MAP_TPRO',0x80000)
MCL_CURRENT = Constant('MCL_CURRENT',0x0001)
MCL_FUTURE = Constant('MCL_FUTURE',0x0002)
MS_ASYNC = Constant('MS_ASYNC',0x0001)
MS_INVALIDATE = Constant('MS_INVALIDATE',0x0002)
MS_SYNC = Constant('MS_SYNC',0x0010)
MS_KILLPAGES = Constant('MS_KILLPAGES',0x0004)
MS_DEACTIVATE = Constant('MS_DEACTIVATE',0x0008)
POSIX_MADV_NORMAL = Constant('POSIX_MADV_NORMAL',0)
POSIX_MADV_RANDOM = Constant('POSIX_MADV_RANDOM',1)
POSIX_MADV_SEQUENTIAL = Constant('POSIX_MADV_SEQUENTIAL',2)
POSIX_MADV_WILLNEED = Constant('POSIX_MADV_WILLNEED',3)
POSIX_MADV_DONTNEED = Constant('POSIX_MADV_DONTNEED',4)
MADV_FREE = Constant('MADV_FREE',5)
MADV_ZERO_WIRED_PAGES = Constant('MADV_ZERO_WIRED_PAGES',6)
MADV_FREE_REUSABLE = Constant('MADV_FREE_REUSABLE',7)
MADV_FREE_REUSE = Constant('MADV_FREE_REUSE',8)
MADV_CAN_REUSE = Constant('MADV_CAN_REUSE',9)
MADV_PAGEOUT = Constant('MADV_PAGEOUT',10)
MADV_ZERO = Constant('MADV_ZERO',11)
MINCORE_INCORE = Constant('MINCORE_INCORE',0x1)
MINCORE_REFERENCED = Constant('MINCORE_REFERENCED',0x2)
MINCORE_MODIFIED = Constant('MINCORE_MODIFIED',0x4)
MINCORE_REFERENCED_OTHER = Constant('MINCORE_REFERENCED_OTHER',0x8)
MINCORE_MODIFIED_OTHER = Constant('MINCORE_MODIFIED_OTHER',0x10)
MINCORE_PAGED_OUT = Constant('MINCORE_PAGED_OUT',0x20)
MINCORE_COPIED = Constant('MINCORE_COPIED',0x40)
MINCORE_ANONYMOUS = Constant('MINCORE_ANONYMOUS',0x80)
B_WRITE = Constant('B_WRITE',0x00000000)
B_READ = Constant('B_READ',0x00000001)
B_ASYNC = Constant('B_ASYNC',0x00000002)
B_NOCACHE = Constant('B_NOCACHE',0x00000004)
B_DELWRI = Constant('B_DELWRI',0x00000008)
B_LOCKED = Constant('B_LOCKED',0x00000010)
B_PHYS = Constant('B_PHYS',0x00000020)
B_CLUSTER = Constant('B_CLUSTER',0x00000040)
B_PAGEIO = Constant('B_PAGEIO',0x00000080)
B_META = Constant('B_META',0x00000100)
B_RAW = Constant('B_RAW',0x00000200)
B_FUA = Constant('B_FUA',0x00000400)
B_PASSIVE = Constant('B_PASSIVE',0x00000800)
B_IOSTREAMING = Constant('B_IOSTREAMING',0x00001000)
B_THROTTLED_IO = Constant('B_THROTTLED_IO',0x00002000)
B_ENCRYPTED_IO = Constant('B_ENCRYPTED_IO',0x00004000)
B_STATICCONTENT = Constant('B_STATICCONTENT',0x00008000)
BUF_WAIT = Constant('BUF_WAIT',0x01)
BUF_WRITE_DATA = Constant('BUF_WRITE_DATA',0x0001)
BUF_SKIP_META = Constant('BUF_SKIP_META',0x0002)
BUF_INVALIDATE_LOCKED = Constant('BUF_INVALIDATE_LOCKED',0x0004)
BUF_SKIP_NONLOCKED = Constant('BUF_SKIP_NONLOCKED',0x01)
BUF_SKIP_LOCKED = Constant('BUF_SKIP_LOCKED',0x02)
BUF_SCAN_CLEAN = Constant('BUF_SCAN_CLEAN',0x04)
BUF_SCAN_DIRTY = Constant('BUF_SCAN_DIRTY',0x08)
BUF_NOTIFY_BUSY = Constant('BUF_NOTIFY_BUSY',0x10)
BUF_RETURNED = Constant('BUF_RETURNED',0)
BUF_RETURNED_DONE = Constant('BUF_RETURNED_DONE',1)
BUF_CLAIMED = Constant('BUF_CLAIMED',2)
BUF_CLAIMED_DONE = Constant('BUF_CLAIMED_DONE',3)
BLK_READ = Constant('BLK_READ',0x01)
BLK_WRITE = Constant('BLK_WRITE',0x02)
BLK_META = Constant('BLK_META',0x10)
BLK_ONLYVALID = Constant('BLK_ONLYVALID',0x80000000)
LOG_EMERG = Constant('LOG_EMERG',0)
LOG_ALERT = Constant('LOG_ALERT',1)
LOG_CRIT = Constant('LOG_CRIT',2)
LOG_ERR = Constant('LOG_ERR',3)
LOG_WARNING = Constant('LOG_WARNING',4)
LOG_NOTICE = Constant('LOG_NOTICE',5)
LOG_INFO = Constant('LOG_INFO',6)
LOG_DEBUG = Constant('LOG_DEBUG',7)
LOG_PRIMASK = Constant('LOG_PRIMASK',0x07)
INTERNAL_NOPRI = Constant('INTERNAL_NOPRI',0x10)
LOG_NFACILITIES = Constant('LOG_NFACILITIES',25)
LOG_FACMASK = Constant('LOG_FACMASK',0x03f8)
LOG_PID = Constant('LOG_PID',0x01)
LOG_CONS = Constant('LOG_CONS',0x02)
LOG_ODELAY = Constant('LOG_ODELAY',0x04)
LOG_NDELAY = Constant('LOG_NDELAY',0x08)
LOG_NOWAIT = Constant('LOG_NOWAIT',0x10)
LOG_PERROR = Constant('LOG_PERROR',0x20)
CRF_NOMEMBERD = Constant('CRF_NOMEMBERD',0x00000001)
CRF_MAC_ENFORCE = Constant('CRF_MAC_ENFORCE',0x00000002)
XUCRED_VERSION = Constant('XUCRED_VERSION',0)
DK_FEATURE_BARRIER = Constant('DK_FEATURE_BARRIER',0x00000002)
DK_FEATURE_PRIORITY = Constant('DK_FEATURE_PRIORITY',0x00000004)
DK_FEATURE_UNMAP = Constant('DK_FEATURE_UNMAP',0x00000010)
DK_SYNCHRONIZE_OPTION_BARRIER = Constant('DK_SYNCHRONIZE_OPTION_BARRIER',0x00000002)
DK_CORESTORAGE_PIN_YOUR_METADATA = Constant('DK_CORESTORAGE_PIN_YOUR_METADATA',0x00000001)
DK_CORESTORAGE_ENABLE_HOTFILES = Constant('DK_CORESTORAGE_ENABLE_HOTFILES',0x00000002)
DK_CORESTORAGE_PIN_YOUR_SWAPFILE = Constant('DK_CORESTORAGE_PIN_YOUR_SWAPFILE',0x00000004)
DK_PROVISION_TYPE_MAPPED = Constant('DK_PROVISION_TYPE_MAPPED',0x00)
DK_PROVISION_TYPE_DEALLOCATED = Constant('DK_PROVISION_TYPE_DEALLOCATED',0x01)
DK_PROVISION_TYPE_ANCHORED = Constant('DK_PROVISION_TYPE_ANCHORED',0x02)
DK_LOCATION_INTERNAL = Constant('DK_LOCATION_INTERNAL',0x00000000)
DK_LOCATION_EXTERNAL = Constant('DK_LOCATION_EXTERNAL',0x00000001)
DK_FEATURE_FORCE_UNIT_ACCESS = Constant('DK_FEATURE_FORCE_UNIT_ACCESS',0x00000001)
DK_ENCRYPTION_TYPE_AES_CBC = Constant('DK_ENCRYPTION_TYPE_AES_CBC',1)
DK_ENCRYPTION_TYPE_AES_XEX = Constant('DK_ENCRYPTION_TYPE_AES_XEX',2)
DK_ENCRYPTION_TYPE_AES_XTS = Constant('DK_ENCRYPTION_TYPE_AES_XTS',3)
DK_TIER_MASK = Constant('DK_TIER_MASK',0xC0)
DK_TIER_SHIFT = Constant('DK_TIER_SHIFT',6)
SOL_LOCAL = Constant('SOL_LOCAL',0)
LOCAL_PEERCRED = Constant('LOCAL_PEERCRED',0x001)
LOCAL_PEERPID = Constant('LOCAL_PEERPID',0x002)
LOCAL_PEEREPID = Constant('LOCAL_PEEREPID',0x003)
LOCAL_PEERUUID = Constant('LOCAL_PEERUUID',0x004)
LOCAL_PEEREUUID = Constant('LOCAL_PEEREUUID',0x005)
LOCAL_PEERTOKEN = Constant('LOCAL_PEERTOKEN',0x006)
_SYS_TIMEX_H_ = Constant('_SYS_TIMEX_H_',1)
NTP_API = Constant('NTP_API',4)
MINSEC = Constant('MINSEC',256)
MAXSEC = Constant('MAXSEC',2048)
MAXTC = Constant('MAXTC',10)
MOD_OFFSET = Constant('MOD_OFFSET',0x0001)
MOD_FREQUENCY = Constant('MOD_FREQUENCY',0x0002)
MOD_MAXERROR = Constant('MOD_MAXERROR',0x0004)
MOD_ESTERROR = Constant('MOD_ESTERROR',0x0008)
MOD_STATUS = Constant('MOD_STATUS',0x0010)
MOD_TIMECONST = Constant('MOD_TIMECONST',0x0020)
MOD_PPSMAX = Constant('MOD_PPSMAX',0x0040)
MOD_TAI = Constant('MOD_TAI',0x0080)
MOD_MICRO = Constant('MOD_MICRO',0x1000)
MOD_NANO = Constant('MOD_NANO',0x2000)
MOD_CLKB = Constant('MOD_CLKB',0x4000)
MOD_CLKA = Constant('MOD_CLKA',0x8000)
STA_PLL = Constant('STA_PLL',0x0001)
STA_PPSFREQ = Constant('STA_PPSFREQ',0x0002)
STA_PPSTIME = Constant('STA_PPSTIME',0x0004)
STA_FLL = Constant('STA_FLL',0x0008)
STA_INS = Constant('STA_INS',0x0010)
STA_DEL = Constant('STA_DEL',0x0020)
STA_UNSYNC = Constant('STA_UNSYNC',0x0040)
STA_FREQHOLD = Constant('STA_FREQHOLD',0x0080)
STA_PPSSIGNAL = Constant('STA_PPSSIGNAL',0x0100)
STA_PPSJITTER = Constant('STA_PPSJITTER',0x0200)
STA_PPSWANDER = Constant('STA_PPSWANDER',0x0400)
STA_PPSERROR = Constant('STA_PPSERROR',0x0800)
STA_CLOCKERR = Constant('STA_CLOCKERR',0x1000)
STA_NANO = Constant('STA_NANO',0x2000)
STA_MODE = Constant('STA_MODE',0x4000)
STA_CLK = Constant('STA_CLK',0x8000)
TIME_OK = Constant('TIME_OK',0)
TIME_INS = Constant('TIME_INS',1)
TIME_DEL = Constant('TIME_DEL',2)
TIME_OOP = Constant('TIME_OOP',3)
TIME_WAIT = Constant('TIME_WAIT',4)
TIME_ERROR = Constant('TIME_ERROR',5)
MT_FREE = Constant('MT_FREE',0)
MT_DATA = Constant('MT_DATA',1)
MT_HEADER = Constant('MT_HEADER',2)
MT_SOCKET = Constant('MT_SOCKET',3)
MT_PCB = Constant('MT_PCB',4)
MT_RTABLE = Constant('MT_RTABLE',5)
MT_HTABLE = Constant('MT_HTABLE',6)
MT_ATABLE = Constant('MT_ATABLE',7)
MT_SONAME = Constant('MT_SONAME',8)
MT_SOOPTS = Constant('MT_SOOPTS',10)
MT_FTABLE = Constant('MT_FTABLE',11)
MT_RIGHTS = Constant('MT_RIGHTS',12)
MT_IFADDR = Constant('MT_IFADDR',13)
MT_CONTROL = Constant('MT_CONTROL',14)
MT_OOBDATA = Constant('MT_OOBDATA',15)
MT_TAG = Constant('MT_TAG',16)
MT_MAX = Constant('MT_MAX',32)
MAX_MBUF_CNAME = Constant('MAX_MBUF_CNAME',15)
MCS_DISABLED = Constant('MCS_DISABLED',0)
MCS_ONLINE = Constant('MCS_ONLINE',1)
MCS_PURGING = Constant('MCS_PURGING',2)
MCS_OFFLINE = Constant('MCS_OFFLINE',3)
MSG_NOERROR = Constant('MSG_NOERROR',0o010000)
MSGSSZ = Constant('MSGSSZ',8)
MSGSEG = Constant('MSGSEG',2048)
MSGMNB = Constant('MSGMNB',2048)
MSGMNI = Constant('MSGMNI',40)
MSGTQL = Constant('MSGTQL',40)
MSG_LOCKED = Constant('MSG_LOCKED',0o01000)
DBG_MACH = Constant('DBG_MACH',1)
DBG_NETWORK = Constant('DBG_NETWORK',2)
DBG_FSYSTEM = Constant('DBG_FSYSTEM',3)
DBG_BSD = Constant('DBG_BSD',4)
DBG_IOKIT = Constant('DBG_IOKIT',5)
DBG_DRIVERS = Constant('DBG_DRIVERS',6)
DBG_TRACE = Constant('DBG_TRACE',7)
DBG_DLIL = Constant('DBG_DLIL',8)
DBG_PTHREAD = Constant('DBG_PTHREAD',9)
DBG_CORESTORAGE = Constant('DBG_CORESTORAGE',10)
DBG_CG = Constant('DBG_CG',11)
DBG_MONOTONIC = Constant('DBG_MONOTONIC',12)
DBG_MISC = Constant('DBG_MISC',20)
DBG_SECURITY = Constant('DBG_SECURITY',30)
DBG_DYLD = Constant('DBG_DYLD',31)
DBG_QT = Constant('DBG_QT',32)
DBG_APPS = Constant('DBG_APPS',33)
DBG_LAUNCHD = Constant('DBG_LAUNCHD',34)
DBG_SILICON = Constant('DBG_SILICON',35)
DBG_PERF = Constant('DBG_PERF',37)
DBG_IMPORTANCE = Constant('DBG_IMPORTANCE',38)
DBG_BANK = Constant('DBG_BANK',40)
DBG_XPC = Constant('DBG_XPC',41)
DBG_ATM = Constant('DBG_ATM',42)
DBG_ARIADNE = Constant('DBG_ARIADNE',43)
DBG_DAEMON = Constant('DBG_DAEMON',44)
DBG_ENERGYTRACE = Constant('DBG_ENERGYTRACE',45)
DBG_DISPATCH = Constant('DBG_DISPATCH',46)
DBG_IMG = Constant('DBG_IMG',49)
DBG_UMALLOC = Constant('DBG_UMALLOC',51)
DBG_TURNSTILE = Constant('DBG_TURNSTILE',53)
DBG_AUDIO = Constant('DBG_AUDIO',54)
DBG_MIG = Constant('DBG_MIG',255)
DBG_MACH_EXCP_KTRAP_x86 = Constant('DBG_MACH_EXCP_KTRAP_x86',0x02)
DBG_MACH_EXCP_DFLT = Constant('DBG_MACH_EXCP_DFLT',0x03)
DBG_MACH_EXCP_SYNC_ARM = Constant('DBG_MACH_EXCP_SYNC_ARM',0x03)
DBG_MACH_EXCP_IFLT = Constant('DBG_MACH_EXCP_IFLT',0x04)
DBG_MACH_EXCP_SERR_ARM = Constant('DBG_MACH_EXCP_SERR_ARM',0x04)
DBG_MACH_EXCP_INTR = Constant('DBG_MACH_EXCP_INTR',0x05)
DBG_MACH_EXCP_ALNG = Constant('DBG_MACH_EXCP_ALNG',0x06)
DBG_MACH_EXCP_UTRAP_x86 = Constant('DBG_MACH_EXCP_UTRAP_x86',0x07)
DBG_MACH_EXCP_FP = Constant('DBG_MACH_EXCP_FP',0x08)
DBG_MACH_EXCP_DECI = Constant('DBG_MACH_EXCP_DECI',0x09)
DBG_MACH_CHUD = Constant('DBG_MACH_CHUD',0x0A)
DBG_MACH_SIGNPOST = Constant('DBG_MACH_SIGNPOST',0x0A)
DBG_MACH_EXCP_SC = Constant('DBG_MACH_EXCP_SC',0x0C)
DBG_MACH_EXCP_TRACE = Constant('DBG_MACH_EXCP_TRACE',0x0D)
DBG_MACH_EXCP_EMUL = Constant('DBG_MACH_EXCP_EMUL',0x0E)
DBG_MACH_IHDLR = Constant('DBG_MACH_IHDLR',0x10)
DBG_MACH_IPC = Constant('DBG_MACH_IPC',0x20)
DBG_MACH_RESOURCE = Constant('DBG_MACH_RESOURCE',0x25)
DBG_MACH_EXCLAVES = Constant('DBG_MACH_EXCLAVES',0x2A)
DBG_MACH_EXCLAVES_SCHEDULER = Constant('DBG_MACH_EXCLAVES_SCHEDULER',0x2B)
DBG_MACH_EPOCH_SYNC = Constant('DBG_MACH_EPOCH_SYNC',0x2C)
DBG_MACH_VM = Constant('DBG_MACH_VM',0x30)
DBG_MACH_LEAKS = Constant('DBG_MACH_LEAKS',0x31)
DBG_MACH_WORKINGSET = Constant('DBG_MACH_WORKINGSET',0x32)
DBG_MACH_SCHED = Constant('DBG_MACH_SCHED',0x40)
DBG_MACH_MSGID_INVALID = Constant('DBG_MACH_MSGID_INVALID',0x50)
DBG_MACH_LOCKS = Constant('DBG_MACH_LOCKS',0x60)
DBG_MACH_PMAP = Constant('DBG_MACH_PMAP',0x70)
DBG_MACH_CLOCK = Constant('DBG_MACH_CLOCK',0x80)
DBG_MACH_MP = Constant('DBG_MACH_MP',0x90)
DBG_MACH_VM_PRESSURE = Constant('DBG_MACH_VM_PRESSURE',0xA0)
DBG_MACH_STACKSHOT = Constant('DBG_MACH_STACKSHOT',0xA1)
DBG_MACH_SFI = Constant('DBG_MACH_SFI',0xA2)
DBG_MACH_ENERGY_PERF = Constant('DBG_MACH_ENERGY_PERF',0xA3)
DBG_MACH_SYSDIAGNOSE = Constant('DBG_MACH_SYSDIAGNOSE',0xA4)
DBG_MACH_ZALLOC = Constant('DBG_MACH_ZALLOC',0xA5)
DBG_MACH_THREAD_GROUP = Constant('DBG_MACH_THREAD_GROUP',0xA6)
DBG_MACH_COALITION = Constant('DBG_MACH_COALITION',0xA7)
DBG_MACH_SHAREDREGION = Constant('DBG_MACH_SHAREDREGION',0xA8)
DBG_MACH_SCHED_CLUTCH = Constant('DBG_MACH_SCHED_CLUTCH',0xA9)
DBG_MACH_IO = Constant('DBG_MACH_IO',0xAA)
DBG_MACH_WORKGROUP = Constant('DBG_MACH_WORKGROUP',0xAB)
DBG_MACH_HV = Constant('DBG_MACH_HV',0xAC)
DBG_MACH_KCOV = Constant('DBG_MACH_KCOV',0xAD)
DBG_MACH_MACHDEP_EXCP_SC_x86 = Constant('DBG_MACH_MACHDEP_EXCP_SC_x86',0xAE)
DBG_MACH_MACHDEP_EXCP_SC_ARM = Constant('DBG_MACH_MACHDEP_EXCP_SC_ARM',0xAF)
DBG_MACH_VM_RECLAIM = Constant('DBG_MACH_VM_RECLAIM',0xB0)
DBC_MACH_IO_MMIO_READ = Constant('DBC_MACH_IO_MMIO_READ',0x1)
DBC_MACH_IO_MMIO_WRITE = Constant('DBC_MACH_IO_MMIO_WRITE',0x2)
DBC_MACH_IO_PHYS_READ = Constant('DBC_MACH_IO_PHYS_READ',0x3)
DBC_MACH_IO_PHYS_WRITE = Constant('DBC_MACH_IO_PHYS_WRITE',0x4)
DBC_MACH_IO_PORTIO_READ = Constant('DBC_MACH_IO_PORTIO_READ',0x5)
DBC_MACH_IO_PORTIO_WRITE = Constant('DBC_MACH_IO_PORTIO_WRITE',0x6)
DBG_INTR_TYPE_UNKNOWN = Constant('DBG_INTR_TYPE_UNKNOWN',0x0)
DBG_INTR_TYPE_IPI = Constant('DBG_INTR_TYPE_IPI',0x1)
DBG_INTR_TYPE_TIMER = Constant('DBG_INTR_TYPE_TIMER',0x2)
DBG_INTR_TYPE_OTHER = Constant('DBG_INTR_TYPE_OTHER',0x3)
DBG_INTR_TYPE_PMI = Constant('DBG_INTR_TYPE_PMI',0x4)
DBG_INTR_TYPE_RSVD1 = Constant('DBG_INTR_TYPE_RSVD1',0x5)
MACH_SCHED = Constant('MACH_SCHED',0x0)
MACH_STACK_ATTACH = Constant('MACH_STACK_ATTACH',0x1)
MACH_STACK_HANDOFF = Constant('MACH_STACK_HANDOFF',0x2)
MACH_CALL_CONT = Constant('MACH_CALL_CONT',0x3)
MACH_CALLOUT = Constant('MACH_CALLOUT',0x4)
MACH_STACK_DETACH = Constant('MACH_STACK_DETACH',0x5)
MACH_MAKE_RUNNABLE = Constant('MACH_MAKE_RUNNABLE',0x6)
MACH_PROMOTE = Constant('MACH_PROMOTE',0x7)
MACH_DEMOTE = Constant('MACH_DEMOTE',0x8)
MACH_IDLE = Constant('MACH_IDLE',0x9)
MACH_STACK_DEPTH = Constant('MACH_STACK_DEPTH',0xa)
MACH_MOVED = Constant('MACH_MOVED',0xb)
MACH_PSET_LOAD_AVERAGE = Constant('MACH_PSET_LOAD_AVERAGE',0xc)
MACH_AMP_DEBUG = Constant('MACH_AMP_DEBUG',0xd)
MACH_FAILSAFE = Constant('MACH_FAILSAFE',0xe)
MACH_BLOCK = Constant('MACH_BLOCK',0xf)
MACH_WAIT = Constant('MACH_WAIT',0x10)
MACH_GET_URGENCY = Constant('MACH_GET_URGENCY',0x14)
MACH_URGENCY = Constant('MACH_URGENCY',0x15)
MACH_REDISPATCH = Constant('MACH_REDISPATCH',0x16)
MACH_REMOTE_AST = Constant('MACH_REMOTE_AST',0x17)
MACH_SCHED_CHOOSE_PROCESSOR = Constant('MACH_SCHED_CHOOSE_PROCESSOR',0x18)
MACH_DEEP_IDLE = Constant('MACH_DEEP_IDLE',0x19)
MACH_CPU_THROTTLE_DISABLE = Constant('MACH_CPU_THROTTLE_DISABLE',0x1b)
MACH_RW_PROMOTE = Constant('MACH_RW_PROMOTE',0x1c)
MACH_RW_DEMOTE = Constant('MACH_RW_DEMOTE',0x1d)
MACH_SCHED_MAINTENANCE = Constant('MACH_SCHED_MAINTENANCE',0x1f)
MACH_DISPATCH = Constant('MACH_DISPATCH',0x20)
MACH_QUANTUM_HANDOFF = Constant('MACH_QUANTUM_HANDOFF',0x21)
MACH_SCHED_THREAD_SWITCH = Constant('MACH_SCHED_THREAD_SWITCH',0x23)
MACH_SCHED_SMT_BALANCE = Constant('MACH_SCHED_SMT_BALANCE',0x24)
MACH_REMOTE_DEFERRED_AST = Constant('MACH_REMOTE_DEFERRED_AST',0x25)
MACH_REMOTE_CANCEL_AST = Constant('MACH_REMOTE_CANCEL_AST',0x26)
MACH_SCHED_CHANGE_PRIORITY = Constant('MACH_SCHED_CHANGE_PRIORITY',0x27)
MACH_SCHED_UPDATE_REC_CORES = Constant('MACH_SCHED_UPDATE_REC_CORES',0x28)
MACH_STACK_WAIT = Constant('MACH_STACK_WAIT',0x29)
MACH_THREAD_BIND = Constant('MACH_THREAD_BIND',0x2a)
MACH_WAITQ_PROMOTE = Constant('MACH_WAITQ_PROMOTE',0x2b)
MACH_WAITQ_DEMOTE = Constant('MACH_WAITQ_DEMOTE',0x2c)
MACH_SCHED_LOAD = Constant('MACH_SCHED_LOAD',0x2d)
MACH_REC_CORES_FAILSAFE = Constant('MACH_REC_CORES_FAILSAFE',0x2e)
MACH_SCHED_QUANTUM_EXPIRED = Constant('MACH_SCHED_QUANTUM_EXPIRED',0x2f)
MACH_EXEC_PROMOTE = Constant('MACH_EXEC_PROMOTE',0x30)
MACH_EXEC_DEMOTE = Constant('MACH_EXEC_DEMOTE',0x31)
MACH_AMP_SIGNAL_SPILL = Constant('MACH_AMP_SIGNAL_SPILL',0x32)
MACH_AMP_STEAL = Constant('MACH_AMP_STEAL',0x33)
MACH_SCHED_LOAD_EFFECTIVE = Constant('MACH_SCHED_LOAD_EFFECTIVE',0x34)
MACH_QUIESCENT_COUNTER = Constant('MACH_QUIESCENT_COUNTER',0x38)
MACH_TURNSTILE_USER_CHANGE = Constant('MACH_TURNSTILE_USER_CHANGE',0x39)
MACH_AMP_RECOMMENDATION_CHANGE = Constant('MACH_AMP_RECOMMENDATION_CHANGE',0x3a)
MACH_AMP_PERFCTL_POLICY_CHANGE = Constant('MACH_AMP_PERFCTL_POLICY_CHANGE',0x3b)
MACH_TURNSTILE_KERNEL_CHANGE = Constant('MACH_TURNSTILE_KERNEL_CHANGE',0x40)
MACH_SCHED_WI_AUTO_JOIN = Constant('MACH_SCHED_WI_AUTO_JOIN',0x41)
MACH_SCHED_WI_DEFERRED_FINISH = Constant('MACH_SCHED_WI_DEFERRED_FINISH',0x42)
MACH_SET_RT_DEADLINE = Constant('MACH_SET_RT_DEADLINE',0x43)
MACH_CANCEL_RT_DEADLINE = Constant('MACH_CANCEL_RT_DEADLINE',0x44)
MACH_RT_SIGNAL_SPILL = Constant('MACH_RT_SIGNAL_SPILL',0x45)
MACH_RT_STEAL = Constant('MACH_RT_STEAL',0x46)
MACH_PENDING_AST_URGENT = Constant('MACH_PENDING_AST_URGENT',0x47)
MACH_SCHED_THREAD_SELECT = Constant('MACH_SCHED_THREAD_SELECT',0x48)
MACH_SCHED_NEXT_PROCESSOR = Constant('MACH_SCHED_NEXT_PROCESSOR',0x49)
MACH_PSET_AVG_EXEC_TIME = Constant('MACH_PSET_AVG_EXEC_TIME',0x50)
MACH_SUSPEND_USERSPACE = Constant('MACH_SUSPEND_USERSPACE',0x51)
MACH_PREEMPTION_EXPIRED = Constant('MACH_PREEMPTION_EXPIRED',0x52)
MACH_FLOOR_PROMOTE = Constant('MACH_FLOOR_PROMOTE',0x53)
MACH_FLOOR_DEMOTE = Constant('MACH_FLOOR_DEMOTE',0x54)
MACH_INT_MASKED_EXPIRED = Constant('MACH_INT_MASKED_EXPIRED',0x55)
MACH_INT_HANDLED_EXPIRED = Constant('MACH_INT_HANDLED_EXPIRED',0x56)
MACH_UPDATE_POWERED_CORES = Constant('MACH_UPDATE_POWERED_CORES',0x58)
MACH_MODE_DEMOTE_THROTTLED = Constant('MACH_MODE_DEMOTE_THROTTLED',0x59)
MACH_MODE_DEMOTE_FAILSAFE = Constant('MACH_MODE_DEMOTE_FAILSAFE',0x5a)
MACH_MODE_DEMOTE_RT_DISALLOWED = Constant('MACH_MODE_DEMOTE_RT_DISALLOWED',0x5b)
MACH_MODE_UNDEMOTE_THROTTLED = Constant('MACH_MODE_UNDEMOTE_THROTTLED',0x5c)
MACH_MODE_UNDEMOTE_FAILSAFE = Constant('MACH_MODE_UNDEMOTE_FAILSAFE',0x5d)
MACH_MODE_UNDEMOTE_RT_DISALLOWED = Constant('MACH_MODE_UNDEMOTE_RT_DISALLOWED',0x5e)
MACH_INT_MASKED_RESET = Constant('MACH_INT_MASKED_RESET',0x5f)
MACH_RT_DISALLOWED_WORK_INTERVAL = Constant('MACH_RT_DISALLOWED_WORK_INTERVAL',0x60)
MACH_SCHED_WI_EXTERNAL_WAKEUP = Constant('MACH_SCHED_WI_EXTERNAL_WAKEUP',0x61)
MACH_SCHED_AST_CHECK = Constant('MACH_SCHED_AST_CHECK',0x62)
MACH_SCHED_PREEMPT_TIMER_ACTIVE = Constant('MACH_SCHED_PREEMPT_TIMER_ACTIVE',0x63)
MACH_PROCESSOR_SHUTDOWN = Constant('MACH_PROCESSOR_SHUTDOWN',0x64)
MACH_SCHED_CLUTCH_ROOT_BUCKET_STATE = Constant('MACH_SCHED_CLUTCH_ROOT_BUCKET_STATE',0x0)
MACH_SCHED_CLUTCH_TG_BUCKET_STATE = Constant('MACH_SCHED_CLUTCH_TG_BUCKET_STATE',0x1)
MACH_SCHED_CLUTCH_THREAD_SELECT = Constant('MACH_SCHED_CLUTCH_THREAD_SELECT',0x2)
MACH_SCHED_CLUTCH_THREAD_STATE = Constant('MACH_SCHED_CLUTCH_THREAD_STATE',0x3)
MACH_SCHED_CLUTCH_TG_BUCKET_PRI = Constant('MACH_SCHED_CLUTCH_TG_BUCKET_PRI',0x4)
MACH_SCHED_EDGE_CLUSTER_OVERLOAD = Constant('MACH_SCHED_EDGE_CLUSTER_OVERLOAD',0x5)
MACH_SCHED_EDGE_STEAL = Constant('MACH_SCHED_EDGE_STEAL',0x6)
MACH_SCHED_EDGE_REBAL_RUNNABLE = Constant('MACH_SCHED_EDGE_REBAL_RUNNABLE',0x7)
MACH_SCHED_EDGE_REBAL_RUNNING = Constant('MACH_SCHED_EDGE_REBAL_RUNNING',0x8)
MACH_SCHED_EDGE_SHOULD_YIELD = Constant('MACH_SCHED_EDGE_SHOULD_YIELD',0x9)
MACH_SCHED_CLUTCH_THR_COUNT = Constant('MACH_SCHED_CLUTCH_THR_COUNT',0xa)
MACH_SCHED_EDGE_LOAD_AVG = Constant('MACH_SCHED_EDGE_LOAD_AVG',0xb)
MACH_SCHED_EDGE_CLUSTER_SHARED_LOAD = Constant('MACH_SCHED_EDGE_CLUSTER_SHARED_LOAD',0xc)
MACH_SCHED_EDGE_RSRC_HEAVY_THREAD = Constant('MACH_SCHED_EDGE_RSRC_HEAVY_THREAD',0xd)
MACH_SCHED_EDGE_SHARED_RSRC_MIGRATE = Constant('MACH_SCHED_EDGE_SHARED_RSRC_MIGRATE',0xe)
WORKGROUP_INTERVAL_CREATE = Constant('WORKGROUP_INTERVAL_CREATE',0x0)
WORKGROUP_INTERVAL_DESTROY = Constant('WORKGROUP_INTERVAL_DESTROY',0x1)
WORKGROUP_INTERVAL_CHANGE = Constant('WORKGROUP_INTERVAL_CHANGE',0x2)
WORKGROUP_INTERVAL_START = Constant('WORKGROUP_INTERVAL_START',0x3)
WORKGROUP_INTERVAL_UPDATE = Constant('WORKGROUP_INTERVAL_UPDATE',0x4)
WORKGROUP_INTERVAL_FINISH = Constant('WORKGROUP_INTERVAL_FINISH',0x5)
WORKGROUP_INTERVAL_SET_WORKLOAD_ID = Constant('WORKGROUP_INTERVAL_SET_WORKLOAD_ID',0x6)
WORKGROUP_INTERVAL_SET_WORKLOAD_ID_NAME = Constant('WORKGROUP_INTERVAL_SET_WORKLOAD_ID_NAME',0x7)
KCOV_STKSZ_THRESHOLD_ABOVE = Constant('KCOV_STKSZ_THRESHOLD_ABOVE',0x0)
KCOV_STKSZ_THRESHOLD_BELOW = Constant('KCOV_STKSZ_THRESHOLD_BELOW',0x1)
DBG_VM_VNODE_PAGEOUT = Constant('DBG_VM_VNODE_PAGEOUT',0x001)
DBG_VM_FAULT_INTERNAL = Constant('DBG_VM_FAULT_INTERNAL',0x002)
DBG_VM_PURGEABLE_TOKEN_ADD = Constant('DBG_VM_PURGEABLE_TOKEN_ADD',0x040)
DBG_VM_PURGEABLE_TOKEN_DELETE = Constant('DBG_VM_PURGEABLE_TOKEN_DELETE',0x041)
DBG_VM_PURGEABLE_TOKEN_RIPEN = Constant('DBG_VM_PURGEABLE_TOKEN_RIPEN',0x042)
DBG_VM_PURGEABLE_OBJECT_ADD = Constant('DBG_VM_PURGEABLE_OBJECT_ADD',0x048)
DBG_VM_PURGEABLE_OBJECT_REMOVE = Constant('DBG_VM_PURGEABLE_OBJECT_REMOVE',0x049)
DBG_VM_PURGEABLE_OBJECT_PURGE = Constant('DBG_VM_PURGEABLE_OBJECT_PURGE',0x04a)
DBG_VM_PURGEABLE_OBJECT_PURGE_ALL = Constant('DBG_VM_PURGEABLE_OBJECT_PURGE_ALL',0x04b)
DBG_VM_PURGEABLE_OBJECT_PURGE_ONE = Constant('DBG_VM_PURGEABLE_OBJECT_PURGE_ONE',0x04c)
DBG_VM_PURGEABLE_OBJECT_PURGE_LOOP = Constant('DBG_VM_PURGEABLE_OBJECT_PURGE_LOOP',0x04e)
DBG_VM_MAP_PARTIAL_REAP = Constant('DBG_VM_MAP_PARTIAL_REAP',0x054)
DBG_VM_MAP_WILLNEED = Constant('DBG_VM_MAP_WILLNEED',0x055)
DBG_VM_FAULT_CHECK_ZFDELAY = Constant('DBG_VM_FAULT_CHECK_ZFDELAY',0x100)
DBG_VM_FAULT_COWDELAY = Constant('DBG_VM_FAULT_COWDELAY',0x101)
DBG_VM_FAULT_ZFDELAY = Constant('DBG_VM_FAULT_ZFDELAY',0x102)
DBG_VM_FAULT_COMPRESSORDELAY = Constant('DBG_VM_FAULT_COMPRESSORDELAY',0x103)
DBG_VM_PAGEOUT_SCAN = Constant('DBG_VM_PAGEOUT_SCAN',0x104)
DBG_VM_PAGEOUT_BALANCE = Constant('DBG_VM_PAGEOUT_BALANCE',0x105)
DBG_VM_PAGEOUT_FREELIST = Constant('DBG_VM_PAGEOUT_FREELIST',0x106)
DBG_VM_PAGEOUT_PURGEONE = Constant('DBG_VM_PAGEOUT_PURGEONE',0x107)
DBG_VM_PAGEOUT_CACHE_EVICT = Constant('DBG_VM_PAGEOUT_CACHE_EVICT',0x108)
DBG_VM_PAGEOUT_THREAD_BLOCK = Constant('DBG_VM_PAGEOUT_THREAD_BLOCK',0x109)
DBG_VM_PAGEOUT_JETSAM = Constant('DBG_VM_PAGEOUT_JETSAM',0x10A)
DBG_VM_INFO1 = Constant('DBG_VM_INFO1',0x10B)
DBG_VM_INFO2 = Constant('DBG_VM_INFO2',0x10C)
DBG_VM_INFO3 = Constant('DBG_VM_INFO3',0x10D)
DBG_VM_INFO4 = Constant('DBG_VM_INFO4',0x10E)
DBG_VM_INFO5 = Constant('DBG_VM_INFO5',0x10F)
DBG_VM_INFO6 = Constant('DBG_VM_INFO6',0x110)
DBG_VM_INFO7 = Constant('DBG_VM_INFO7',0x111)
DBG_VM_INFO8 = Constant('DBG_VM_INFO8',0x112)
DBG_VM_INFO9 = Constant('DBG_VM_INFO9',0x113)
DBG_VM_INFO10 = Constant('DBG_VM_INFO10',0x114)
DBG_VM_UPL_PAGE_WAIT = Constant('DBG_VM_UPL_PAGE_WAIT',0x120)
DBG_VM_IOPL_PAGE_WAIT = Constant('DBG_VM_IOPL_PAGE_WAIT',0x121)
DBG_VM_PAGE_WAIT_BLOCK = Constant('DBG_VM_PAGE_WAIT_BLOCK',0x122)
DBG_VM_PAGE_SLEEP = Constant('DBG_VM_PAGE_SLEEP',0x123)
DBG_VM_PAGE_EXPEDITE = Constant('DBG_VM_PAGE_EXPEDITE',0x124)
DBG_VM_PAGE_EXPEDITE_NO_MEMORY = Constant('DBG_VM_PAGE_EXPEDITE_NO_MEMORY',0x125)
DBG_VM_PAGE_GRAB = Constant('DBG_VM_PAGE_GRAB',0x126)
DBG_VM_PAGE_RELEASE = Constant('DBG_VM_PAGE_RELEASE',0x127)
DBG_VM_COMPRESSOR_COMPACT_AND_SWAP = Constant('DBG_VM_COMPRESSOR_COMPACT_AND_SWAP',0x128)
DBG_VM_COMPRESSOR_DELAYED_COMPACT = Constant('DBG_VM_COMPRESSOR_DELAYED_COMPACT',0x129)
DBG_VM_OBJECT_SLEEP = Constant('DBG_VM_OBJECT_SLEEP',0x12a)
DBG_VM_PAGE_WAKEUP = Constant('DBG_VM_PAGE_WAKEUP',0x12b)
DBG_VM_PAGE_WAKEUP_DONE = Constant('DBG_VM_PAGE_WAKEUP_DONE',0x12c)
DBG_VM_PRESSURE_EVENT = Constant('DBG_VM_PRESSURE_EVENT',0x130)
DBG_VM_EXECVE = Constant('DBG_VM_EXECVE',0x131)
DBG_VM_WAKEUP_COMPACTOR_SWAPPER = Constant('DBG_VM_WAKEUP_COMPACTOR_SWAPPER',0x132)
DBG_VM_UPL_REQUEST = Constant('DBG_VM_UPL_REQUEST',0x133)
DBG_VM_IOPL_REQUEST = Constant('DBG_VM_IOPL_REQUEST',0x134)
DBG_VM_KERN_REQUEST = Constant('DBG_VM_KERN_REQUEST',0x135)
DBG_VM_DATA_WRITE = Constant('DBG_VM_DATA_WRITE',0x140)
DBG_VM_PRESSURE_LEVEL_CHANGE = Constant('DBG_VM_PRESSURE_LEVEL_CHANGE',0x141)
DBG_VM_PHYS_WRITE_ACCT = Constant('DBG_VM_PHYS_WRITE_ACCT',0x142)
DBG_VM_MAP_LOOKUP_ENTRY_FAILURE = Constant('DBG_VM_MAP_LOOKUP_ENTRY_FAILURE',0x143)
VM_DISCONNECT_ALL_PAGE_MAPPINGS = Constant('VM_DISCONNECT_ALL_PAGE_MAPPINGS',0x00)
VM_DISCONNECT_TASK_PAGE_MAPPINGS = Constant('VM_DISCONNECT_TASK_PAGE_MAPPINGS',0x01)
VM_REAL_FAULT_ADDR_INTERNAL = Constant('VM_REAL_FAULT_ADDR_INTERNAL',0x02)
VM_REAL_FAULT_ADDR_PURGABLE = Constant('VM_REAL_FAULT_ADDR_PURGABLE',0x03)
VM_REAL_FAULT_ADDR_EXTERNAL = Constant('VM_REAL_FAULT_ADDR_EXTERNAL',0x04)
VM_REAL_FAULT_ADDR_SHAREDCACHE = Constant('VM_REAL_FAULT_ADDR_SHAREDCACHE',0x05)
VM_REAL_FAULT_FAST = Constant('VM_REAL_FAULT_FAST',0x06)
VM_REAL_FAULT_SLOW = Constant('VM_REAL_FAULT_SLOW',0x07)
VM_MAP_LOOKUP_OBJECT = Constant('VM_MAP_LOOKUP_OBJECT',0x08)
DBG_ZERO_FILL_FAULT = Constant('DBG_ZERO_FILL_FAULT',0x01)
DBG_PAGEIN_FAULT = Constant('DBG_PAGEIN_FAULT',0x02)
DBG_COW_FAULT = Constant('DBG_COW_FAULT',0x03)
DBG_CACHE_HIT_FAULT = Constant('DBG_CACHE_HIT_FAULT',0x04)
DBG_NZF_PAGE_FAULT = Constant('DBG_NZF_PAGE_FAULT',0x05)
DBG_GUARD_FAULT = Constant('DBG_GUARD_FAULT',0x06)
DBG_PAGEINV_FAULT = Constant('DBG_PAGEINV_FAULT',0x07)
DBG_PAGEIND_FAULT = Constant('DBG_PAGEIND_FAULT',0x08)
DBG_COMPRESSOR_FAULT = Constant('DBG_COMPRESSOR_FAULT',0x09)
DBG_COMPRESSOR_SWAPIN_FAULT = Constant('DBG_COMPRESSOR_SWAPIN_FAULT',0x0a)
DBG_COR_FAULT = Constant('DBG_COR_FAULT',0x0b)
MACH_TASK_SUSPEND = Constant('MACH_TASK_SUSPEND',0x0)
MACH_TASK_RESUME = Constant('MACH_TASK_RESUME',0x1)
MACH_THREAD_SET_VOUCHER = Constant('MACH_THREAD_SET_VOUCHER',0x2)
MACH_IPC_MSG_SEND = Constant('MACH_IPC_MSG_SEND',0x3)
MACH_IPC_MSG_RECV = Constant('MACH_IPC_MSG_RECV',0x4)
MACH_IPC_MSG_RECV_VOUCHER_REFUSED = Constant('MACH_IPC_MSG_RECV_VOUCHER_REFUSED',0x5)
MACH_IPC_KMSG_FREE = Constant('MACH_IPC_KMSG_FREE',0x6)
MACH_IPC_VOUCHER_CREATE = Constant('MACH_IPC_VOUCHER_CREATE',0x7)
MACH_IPC_VOUCHER_CREATE_ATTR_DATA = Constant('MACH_IPC_VOUCHER_CREATE_ATTR_DATA',0x8)
MACH_IPC_VOUCHER_DESTROY = Constant('MACH_IPC_VOUCHER_DESTROY',0x9)
MACH_IPC_KMSG_INFO = Constant('MACH_IPC_KMSG_INFO',0xa)
MACH_IPC_KMSG_LINK = Constant('MACH_IPC_KMSG_LINK',0xb)
MACH_IPC_PORT_ENTRY_MODIFY = Constant('MACH_IPC_PORT_ENTRY_MODIFY',0xc)
MACH_IPC_DESTROY_GUARDED_DESC = Constant('MACH_IPC_DESTROY_GUARDED_DESC',0xd)
MACH_THREAD_SUSPEND = Constant('MACH_THREAD_SUSPEND',0xe)
MACH_THREAD_RESUME = Constant('MACH_THREAD_RESUME',0xf)
MACH_EXCLAVES_SWITCH = Constant('MACH_EXCLAVES_SWITCH',0x0)
MACH_EXCLAVES_XNUPROXY = Constant('MACH_EXCLAVES_XNUPROXY',0x1)
MACH_EXCLAVES_RPC = Constant('MACH_EXCLAVES_RPC',0x2)
MACH_EXCLAVES_UPCALL = Constant('MACH_EXCLAVES_UPCALL',0x3)
MACH_EXCLAVES_BOOT_TASK = Constant('MACH_EXCLAVES_BOOT_TASK',0x4)
MACH_EXCLAVES_SCHEDULER_YIELD = Constant('MACH_EXCLAVES_SCHEDULER_YIELD',0x0)
MACH_EXCLAVES_SCHEDULER_SPAWNED = Constant('MACH_EXCLAVES_SCHEDULER_SPAWNED',0x1)
MACH_EXCLAVES_SCHEDULER_TERMINATED = Constant('MACH_EXCLAVES_SCHEDULER_TERMINATED',0x2)
MACH_EXCLAVES_SCHEDULER_WAIT = Constant('MACH_EXCLAVES_SCHEDULER_WAIT',0x3)
MACH_EXCLAVES_SCHEDULER_WAKE = Constant('MACH_EXCLAVES_SCHEDULER_WAKE',0x4)
MACH_EXCLAVES_SCHEDULER_SUSPENDED = Constant('MACH_EXCLAVES_SCHEDULER_SUSPENDED',0x5)
MACH_EXCLAVES_SCHEDULER_RESUMED = Constant('MACH_EXCLAVES_SCHEDULER_RESUMED',0x6)
MACH_EXCLAVES_SCHEDULER_INTERRUPTED = Constant('MACH_EXCLAVES_SCHEDULER_INTERRUPTED',0x7)
MACH_EXCLAVES_SCHEDULER_NOTHING_SCHEDULED = Constant('MACH_EXCLAVES_SCHEDULER_NOTHING_SCHEDULED',0x8)
MACH_EXCLAVES_SCHEDULER_ALL_EXCLAVES_BOOTED = Constant('MACH_EXCLAVES_SCHEDULER_ALL_EXCLAVES_BOOTED',0x9)
MACH_EXCLAVES_SCHEDULER_EARLY_ALLOC = Constant('MACH_EXCLAVES_SCHEDULER_EARLY_ALLOC',0xa)
MACH_EPOCH_SYNC_WAIT_STALE = Constant('MACH_EPOCH_SYNC_WAIT_STALE',0x0)
MACH_EPOCH_SYNC_WAIT = Constant('MACH_EPOCH_SYNC_WAIT',0x1)
MACH_EPOCH_SYNC_WAKE_NO_WAITERS = Constant('MACH_EPOCH_SYNC_WAKE_NO_WAITERS',0x2)
MACH_EPOCH_SYNC_WAKE_ONE = Constant('MACH_EPOCH_SYNC_WAKE_ONE',0x3)
MACH_EPOCH_SYNC_WAKE_ALL = Constant('MACH_EPOCH_SYNC_WAKE_ALL',0x4)
MACH_EPOCH_SYNC_WAKE_ONE_WITH_OWNER = Constant('MACH_EPOCH_SYNC_WAKE_ONE_WITH_OWNER',0x5)
MACH_EPOCH_SYNC_WAKE_THREAD = Constant('MACH_EPOCH_SYNC_WAKE_THREAD',0x6)
MACH_THREAD_GROUP_NEW = Constant('MACH_THREAD_GROUP_NEW',0x0)
MACH_THREAD_GROUP_FREE = Constant('MACH_THREAD_GROUP_FREE',0x1)
MACH_THREAD_GROUP_SET = Constant('MACH_THREAD_GROUP_SET',0x2)
MACH_THREAD_GROUP_NAME = Constant('MACH_THREAD_GROUP_NAME',0x3)
MACH_THREAD_GROUP_NAME_FREE = Constant('MACH_THREAD_GROUP_NAME_FREE',0x4)
MACH_THREAD_GROUP_FLAGS = Constant('MACH_THREAD_GROUP_FLAGS',0x5)
MACH_THREAD_GROUP_BLOCK = Constant('MACH_THREAD_GROUP_BLOCK',0x6)
MACH_THREAD_GROUP_PREADOPT = Constant('MACH_THREAD_GROUP_PREADOPT',0x7)
MACH_THREAD_GROUP_PREADOPT_NEXTTIME = Constant('MACH_THREAD_GROUP_PREADOPT_NEXTTIME',0x8)
MACH_THREAD_GROUP_PREADOPT_CLEAR = Constant('MACH_THREAD_GROUP_PREADOPT_CLEAR',0x9)
MACH_THREAD_GROUP_PREADOPT_NA = Constant('MACH_THREAD_GROUP_PREADOPT_NA',0xa)
MACH_COALITION_NEW = Constant('MACH_COALITION_NEW',0x0)
MACH_COALITION_FREE = Constant('MACH_COALITION_FREE',0x1)
MACH_COALITION_ADOPT = Constant('MACH_COALITION_ADOPT',0x2)
MACH_COALITION_REMOVE = Constant('MACH_COALITION_REMOVE',0x3)
MACH_COALITION_THREAD_GROUP_SET = Constant('MACH_COALITION_THREAD_GROUP_SET',0x4)
PMAP__CREATE = Constant('PMAP__CREATE',0x0)
PMAP__DESTROY = Constant('PMAP__DESTROY',0x1)
PMAP__PROTECT = Constant('PMAP__PROTECT',0x2)
PMAP__PAGE_PROTECT = Constant('PMAP__PAGE_PROTECT',0x3)
PMAP__ENTER = Constant('PMAP__ENTER',0x4)
PMAP__REMOVE = Constant('PMAP__REMOVE',0x5)
PMAP__NEST = Constant('PMAP__NEST',0x6)
PMAP__UNNEST = Constant('PMAP__UNNEST',0x7)
PMAP__FLUSH_TLBS = Constant('PMAP__FLUSH_TLBS',0x8)
PMAP__UPDATE_INTERRUPT = Constant('PMAP__UPDATE_INTERRUPT',0x9)
PMAP__ATTRIBUTE_CLEAR = Constant('PMAP__ATTRIBUTE_CLEAR',0xa)
PMAP__REUSABLE = Constant('PMAP__REUSABLE',0xb)
PMAP__QUERY_RESIDENT = Constant('PMAP__QUERY_RESIDENT',0xc)
PMAP__FLUSH_KERN_TLBS = Constant('PMAP__FLUSH_KERN_TLBS',0xd)
PMAP__FLUSH_DELAYED_TLBS = Constant('PMAP__FLUSH_DELAYED_TLBS',0xe)
PMAP__FLUSH_TLBS_TO = Constant('PMAP__FLUSH_TLBS_TO',0xf)
PMAP__FLUSH_EPT = Constant('PMAP__FLUSH_EPT',0x10)
PMAP__FAST_FAULT = Constant('PMAP__FAST_FAULT',0x11)
PMAP__SWITCH = Constant('PMAP__SWITCH',0x12)
PMAP__TTE = Constant('PMAP__TTE',0x13)
PMAP__SWITCH_USER_TTB = Constant('PMAP__SWITCH_USER_TTB',0x14)
PMAP__UPDATE_CACHING = Constant('PMAP__UPDATE_CACHING',0x15)
PMAP__ATTRIBUTE_CLEAR_RANGE = Constant('PMAP__ATTRIBUTE_CLEAR_RANGE',0x16)
PMAP__CLEAR_USER_TTB = Constant('PMAP__CLEAR_USER_TTB',0x17)
PMAP__IOMMU_INIT = Constant('PMAP__IOMMU_INIT',0x18)
PMAP__IOMMU_IOVMALLOC = Constant('PMAP__IOMMU_IOVMALLOC',0x19)
PMAP__IOMMU_IOVMFREE = Constant('PMAP__IOMMU_IOVMFREE',0x1a)
PMAP__IOMMU_MAP = Constant('PMAP__IOMMU_MAP',0x1b)
PMAP__IOMMU_UNMAP = Constant('PMAP__IOMMU_UNMAP',0x1c)
PMAP__IOMMU_IOCTL = Constant('PMAP__IOMMU_IOCTL',0x1d)
PMAP__IOMMU_GRANT_PAGE = Constant('PMAP__IOMMU_GRANT_PAGE',0x1e)
PMAP__BATCH_UPDATE_CACHING = Constant('PMAP__BATCH_UPDATE_CACHING',0x1f)
PMAP__COLLECT_CACHE_OPS = Constant('PMAP__COLLECT_CACHE_OPS',0x20)
MACH_EPOCH_CHANGE = Constant('MACH_EPOCH_CHANGE',0x0)
MACH_BRIDGE_RCV_TS = Constant('MACH_BRIDGE_RCV_TS',0x1)
MACH_BRIDGE_REMOTE_TIME = Constant('MACH_BRIDGE_REMOTE_TIME',0x2)
MACH_BRIDGE_RESET_TS = Constant('MACH_BRIDGE_RESET_TS',0x3)
MACH_BRIDGE_TS_PARAMS = Constant('MACH_BRIDGE_TS_PARAMS',0x4)
MACH_BRIDGE_SKIP_TS = Constant('MACH_BRIDGE_SKIP_TS',0x5)
MACH_BRIDGE_TS_MISMATCH = Constant('MACH_BRIDGE_TS_MISMATCH',0x6)
MACH_BRIDGE_OBSV_RATE = Constant('MACH_BRIDGE_OBSV_RATE',0x7)
MICROSTACKSHOT_RECORD = Constant('MICROSTACKSHOT_RECORD',0x0)
MICROSTACKSHOT_GATHER = Constant('MICROSTACKSHOT_GATHER',0x1)
STACKSHOT_RECORD = Constant('STACKSHOT_RECORD',0x2)
STACKSHOT_RECORD_SHORT = Constant('STACKSHOT_RECORD_SHORT',0x3)
STACKSHOT_KERN_RECORD = Constant('STACKSHOT_KERN_RECORD',0x4)
SYSDIAGNOSE_NOTIFY_USER = Constant('SYSDIAGNOSE_NOTIFY_USER',0x0)
SYSDIAGNOSE_FULL = Constant('SYSDIAGNOSE_FULL',0x1)
SYSDIAGNOSE_STACKSHOT = Constant('SYSDIAGNOSE_STACKSHOT',0x2)
SYSDIAGNOSE_TAILSPIN = Constant('SYSDIAGNOSE_TAILSPIN',0x3)
SFI_SET_WINDOW = Constant('SFI_SET_WINDOW',0x0)
SFI_CANCEL_WINDOW = Constant('SFI_CANCEL_WINDOW',0x1)
SFI_SET_CLASS_OFFTIME = Constant('SFI_SET_CLASS_OFFTIME',0x2)
SFI_CANCEL_CLASS_OFFTIME = Constant('SFI_CANCEL_CLASS_OFFTIME',0x3)
SFI_THREAD_DEFER = Constant('SFI_THREAD_DEFER',0x4)
SFI_OFF_TIMER = Constant('SFI_OFF_TIMER',0x5)
SFI_ON_TIMER = Constant('SFI_ON_TIMER',0x6)
SFI_WAIT_CANCELED = Constant('SFI_WAIT_CANCELED',0x7)
SFI_PID_SET_MANAGED = Constant('SFI_PID_SET_MANAGED',0x8)
SFI_PID_CLEAR_MANAGED = Constant('SFI_PID_CLEAR_MANAGED',0x9)
SFI_GLOBAL_DEFER = Constant('SFI_GLOBAL_DEFER',0xa)
ZALLOC_ZCRAM = Constant('ZALLOC_ZCRAM',0x0)
RMON_ENABLE_CPUUSAGE_MONITOR = Constant('RMON_ENABLE_CPUUSAGE_MONITOR',0x001)
RMON_CPUUSAGE_VIOLATED = Constant('RMON_CPUUSAGE_VIOLATED',0x002)
RMON_CPUUSAGE_SUSPENDED = Constant('RMON_CPUUSAGE_SUSPENDED',0x003)
RMON_CPUUSAGE_VIOLATED_K32A = Constant('RMON_CPUUSAGE_VIOLATED_K32A',0x004)
RMON_CPUUSAGE_VIOLATED_K32B = Constant('RMON_CPUUSAGE_VIOLATED_K32B',0x005)
RMON_CPUUSAGE_RESUMED = Constant('RMON_CPUUSAGE_RESUMED',0x006)
RMON_DISABLE_CPUUSAGE_MONITOR = Constant('RMON_DISABLE_CPUUSAGE_MONITOR',0x00f)
RMON_ENABLE_CPUWAKES_MONITOR = Constant('RMON_ENABLE_CPUWAKES_MONITOR',0x011)
RMON_CPUWAKES_VIOLATED = Constant('RMON_CPUWAKES_VIOLATED',0x012)
RMON_CPUWAKES_VIOLATED_K32A = Constant('RMON_CPUWAKES_VIOLATED_K32A',0x014)
RMON_CPUWAKES_VIOLATED_K32B = Constant('RMON_CPUWAKES_VIOLATED_K32B',0x015)
RMON_DISABLE_CPUWAKES_MONITOR = Constant('RMON_DISABLE_CPUWAKES_MONITOR',0x01f)
RMON_ENABLE_IO_MONITOR = Constant('RMON_ENABLE_IO_MONITOR',0x021)
RMON_LOGWRITES_VIOLATED = Constant('RMON_LOGWRITES_VIOLATED',0x022)
RMON_PHYSWRITES_VIOLATED = Constant('RMON_PHYSWRITES_VIOLATED',0x023)
RMON_LOGWRITES_VIOLATED_K32A = Constant('RMON_LOGWRITES_VIOLATED_K32A',0x024)
RMON_LOGWRITES_VIOLATED_K32B = Constant('RMON_LOGWRITES_VIOLATED_K32B',0x025)
RMON_DISABLE_IO_MONITOR = Constant('RMON_DISABLE_IO_MONITOR',0x02f)
HV_X86_ENTER = Constant('HV_X86_ENTER',0x00)
HV_X86_ENTER_ERROR = Constant('HV_X86_ENTER_ERROR',0x01)
HV_X86_TRAP_TASK = Constant('HV_X86_TRAP_TASK',0x02)
HV_X86_TRAP_THREAD = Constant('HV_X86_TRAP_THREAD',0x03)
HV_X86_INTERRUPT_INJECT = Constant('HV_X86_INTERRUPT_INJECT',0x04)
HV_X86_INTERRUPT_RECV = Constant('HV_X86_INTERRUPT_RECV',0x05)
HV_X86_INTERRUPT_SEND = Constant('HV_X86_INTERRUPT_SEND',0x06)
HV_X86_IPI_SEND = Constant('HV_X86_IPI_SEND',0x07)
HV_X86_NMI_INJECT = Constant('HV_X86_NMI_INJECT',0x08)
HV_X86_NMI_SEND = Constant('HV_X86_NMI_SEND',0x09)
HV_X86_LSC_HIT = Constant('HV_X86_LSC_HIT',0x0a)
HV_X86_LSC_INSERT = Constant('HV_X86_LSC_INSERT',0x0b)
HV_X86_LSC_INSERT_IMM32 = Constant('HV_X86_LSC_INSERT_IMM32',0x0c)
HV_X86_LSC_INVALID = Constant('HV_X86_LSC_INVALID',0x0d)
HV_X86_LSC_INVALIDATE = Constant('HV_X86_LSC_INVALIDATE',0x0e)
HV_X86_LSC_MISS = Constant('HV_X86_LSC_MISS',0x0f)
HV_X86_TIMER_CANCEL = Constant('HV_X86_TIMER_CANCEL',0x10)
HV_X86_TIMER_FIRE = Constant('HV_X86_TIMER_FIRE',0x11)
HV_X86_TIMER_SCHEDULE = Constant('HV_X86_TIMER_SCHEDULE',0x12)
HV_X86_APIC_ACCESS_EXIT = Constant('HV_X86_APIC_ACCESS_EXIT',0x13)
HV_X86_APIC_WRITE_EXIT = Constant('HV_X86_APIC_WRITE_EXIT',0x14)
HV_X86_EPT_VIOLATION_EXIT = Constant('HV_X86_EPT_VIOLATION_EXIT',0x15)
HV_X86_EXC_NMI_EXIT = Constant('HV_X86_EXC_NMI_EXIT',0x16)
HV_X86_HLT_EXIT = Constant('HV_X86_HLT_EXIT',0x17)
HV_X86_IO_EXIT = Constant('HV_X86_IO_EXIT',0x18)
HV_X86_IRQ_EXIT = Constant('HV_X86_IRQ_EXIT',0x19)
HV_X86_IRQ_WND_EXIT = Constant('HV_X86_IRQ_WND_EXIT',0x1a)
HV_X86_MOV_DR_EXIT = Constant('HV_X86_MOV_DR_EXIT',0x1b)
HV_X86_NMI_WND_EXIT = Constant('HV_X86_NMI_WND_EXIT',0x1c)
HV_X86_RDMSR_EXIT = Constant('HV_X86_RDMSR_EXIT',0x1d)
HV_X86_RDPMC_EXIT = Constant('HV_X86_RDPMC_EXIT',0x1e)
HV_X86_TPR_THRESHOLD_EXIT = Constant('HV_X86_TPR_THRESHOLD_EXIT',0x1f)
HV_X86_VMX_TIMER_EXPIRED_EXIT = Constant('HV_X86_VMX_TIMER_EXPIRED_EXIT',0x20)
HV_X86_WRMSR_EXIT = Constant('HV_X86_WRMSR_EXIT',0x21)
HV_X86_VCPU_READ_APIC_TRAP = Constant('HV_X86_VCPU_READ_APIC_TRAP',0x22)
HV_X86_VCPU_READ_VMCS_TRAP = Constant('HV_X86_VCPU_READ_VMCS_TRAP',0x23)
HV_X86_VCPU_RUN_TRAP = Constant('HV_X86_VCPU_RUN_TRAP',0x24)
HV_X86_VCPU_RUN_UNTIL_TRAP = Constant('HV_X86_VCPU_RUN_UNTIL_TRAP',0x25)
HV_X86_VCPU_WRITE_APIC_TRAP = Constant('HV_X86_VCPU_WRITE_APIC_TRAP',0x26)
HV_X86_VM_ADDRSPACE_CREATE_TRAP = Constant('HV_X86_VM_ADDRSPACE_CREATE_TRAP',0x27)
HV_X86_VM_ADDRSPACE_DESTROY_TRAP = Constant('HV_X86_VM_ADDRSPACE_DESTROY_TRAP',0x28)
HV_X86_VM_INTR_MSI_TRAP = Constant('HV_X86_VM_INTR_MSI_TRAP',0x29)
HV_X86_VM_MAP_TRAP = Constant('HV_X86_VM_MAP_TRAP',0x2a)
HV_X86_VM_PROTECT_TRAP = Constant('HV_X86_VM_PROTECT_TRAP',0x2b)
HV_X86_VM_UNMAP_TRAP = Constant('HV_X86_VM_UNMAP_TRAP',0x2c)
HV_X86_TSC_OFFSET_SET = Constant('HV_X86_TSC_OFFSET_SET',0x2d)
VM_RECLAIM_UPDATE_ACCOUNTING = Constant('VM_RECLAIM_UPDATE_ACCOUNTING',0x01)
VM_RECLAIM_ENTRIES = Constant('VM_RECLAIM_ENTRIES',0x02)
VM_RECLAIM_CHUNK = Constant('VM_RECLAIM_CHUNK',0x03)
VM_RECLAIM_ENTRY = Constant('VM_RECLAIM_ENTRY',0x04)
VM_RECLAIM_ALL_MEMORY = Constant('VM_RECLAIM_ALL_MEMORY',0x05)
VM_RECLAIM_ASYNC_MEMORY = Constant('VM_RECLAIM_ASYNC_MEMORY',0x06)
VM_RECLAIM_INIT = Constant('VM_RECLAIM_INIT',0x07)
DBG_NETIP = Constant('DBG_NETIP',1)
DBG_NETARP = Constant('DBG_NETARP',2)
DBG_NETUDP = Constant('DBG_NETUDP',3)
DBG_NETTCP = Constant('DBG_NETTCP',4)
DBG_NETICMP = Constant('DBG_NETICMP',5)
DBG_NETIGMP = Constant('DBG_NETIGMP',6)
DBG_NETRIP = Constant('DBG_NETRIP',7)
DBG_NETOSPF = Constant('DBG_NETOSPF',8)
DBG_NETISIS = Constant('DBG_NETISIS',9)
DBG_NETSNMP = Constant('DBG_NETSNMP',10)
DBG_NETSOCK = Constant('DBG_NETSOCK',11)
DBG_NETAARP = Constant('DBG_NETAARP',100)
DBG_NETDDP = Constant('DBG_NETDDP',101)
DBG_NETNBP = Constant('DBG_NETNBP',102)
DBG_NETZIP = Constant('DBG_NETZIP',103)
DBG_NETADSP = Constant('DBG_NETADSP',104)
DBG_NETATP = Constant('DBG_NETATP',105)
DBG_NETASP = Constant('DBG_NETASP',106)
DBG_NETAFP = Constant('DBG_NETAFP',107)
DBG_NETRTMP = Constant('DBG_NETRTMP',108)
DBG_NETAURP = Constant('DBG_NETAURP',109)
DBG_NETIPSEC = Constant('DBG_NETIPSEC',128)
DBG_NETVMNET = Constant('DBG_NETVMNET',129)
DBG_IOINTC = Constant('DBG_IOINTC',0)
DBG_IOWORKLOOP = Constant('DBG_IOWORKLOOP',1)
DBG_IOINTES = Constant('DBG_IOINTES',2)
DBG_IOCLKES = Constant('DBG_IOCLKES',3)
DBG_IOCMDQ = Constant('DBG_IOCMDQ',4)
DBG_IOMCURS = Constant('DBG_IOMCURS',5)
DBG_IOMDESC = Constant('DBG_IOMDESC',6)
DBG_IOPOWER = Constant('DBG_IOPOWER',7)
DBG_IOSERVICE = Constant('DBG_IOSERVICE',8)
DBG_IOREGISTRY = Constant('DBG_IOREGISTRY',9)
DBG_IOPORT = Constant('DBG_IOPORT',10)
DBG_IOSTORAGE = Constant('DBG_IOSTORAGE',32)
DBG_IONETWORK = Constant('DBG_IONETWORK',33)
DBG_IOKEYBOARD = Constant('DBG_IOKEYBOARD',34)
DBG_IOHID = Constant('DBG_IOHID',35)
DBG_IOAUDIO = Constant('DBG_IOAUDIO',36)
DBG_IOSERIAL = Constant('DBG_IOSERIAL',37)
DBG_IOTTY = Constant('DBG_IOTTY',38)
DBG_IOSAM = Constant('DBG_IOSAM',39)
DBG_IOPARALLELATA = Constant('DBG_IOPARALLELATA',40)
DBG_IOPARALLELSCSI = Constant('DBG_IOPARALLELSCSI',41)
DBG_IOSATA = Constant('DBG_IOSATA',42)
DBG_IOSAS = Constant('DBG_IOSAS',43)
DBG_IOFIBRECHANNEL = Constant('DBG_IOFIBRECHANNEL',44)
DBG_IOUSB = Constant('DBG_IOUSB',45)
DBG_IOBLUETOOTH = Constant('DBG_IOBLUETOOTH',46)
DBG_IOFIREWIRE = Constant('DBG_IOFIREWIRE',47)
DBG_IOINFINIBAND = Constant('DBG_IOINFINIBAND',48)
DBG_IOCPUPM = Constant('DBG_IOCPUPM',49)
DBG_IOGRAPHICS = Constant('DBG_IOGRAPHICS',50)
DBG_HIBERNATE = Constant('DBG_HIBERNATE',51)
DBG_IOTHUNDERBOLT = Constant('DBG_IOTHUNDERBOLT',52)
DBG_BOOTER = Constant('DBG_BOOTER',53)
DBG_IOAUDIO2 = Constant('DBG_IOAUDIO2',54)
DBG_IOAFK = Constant('DBG_IOAFK',55)
DBG_IOSURFACEPA = Constant('DBG_IOSURFACEPA',64)
DBG_IOMDPA = Constant('DBG_IOMDPA',65)
DBG_IODARTPA = Constant('DBG_IODARTPA',66)
DBG_DRVSTORAGE = Constant('DBG_DRVSTORAGE',1)
DBG_DRVNETWORK = Constant('DBG_DRVNETWORK',2)
DBG_DRVKEYBOARD = Constant('DBG_DRVKEYBOARD',3)
DBG_DRVHID = Constant('DBG_DRVHID',4)
DBG_DRVAUDIO = Constant('DBG_DRVAUDIO',5)
DBG_DRVSERIAL = Constant('DBG_DRVSERIAL',7)
DBG_DRVSAM = Constant('DBG_DRVSAM',8)
DBG_DRVPARALLELATA = Constant('DBG_DRVPARALLELATA',9)
DBG_DRVPARALLELSCSI = Constant('DBG_DRVPARALLELSCSI',10)
DBG_DRVSATA = Constant('DBG_DRVSATA',11)
DBG_DRVSAS = Constant('DBG_DRVSAS',12)
DBG_DRVFIBRECHANNEL = Constant('DBG_DRVFIBRECHANNEL',13)
DBG_DRVUSB = Constant('DBG_DRVUSB',14)
DBG_DRVBLUETOOTH = Constant('DBG_DRVBLUETOOTH',15)
DBG_DRVFIREWIRE = Constant('DBG_DRVFIREWIRE',16)
DBG_DRVINFINIBAND = Constant('DBG_DRVINFINIBAND',17)
DBG_DRVGRAPHICS = Constant('DBG_DRVGRAPHICS',18)
DBG_DRVSD = Constant('DBG_DRVSD',19)
DBG_DRVNAND = Constant('DBG_DRVNAND',20)
DBG_SSD = Constant('DBG_SSD',21)
DBG_DRVSPI = Constant('DBG_DRVSPI',22)
DBG_DRVWLAN_802_11 = Constant('DBG_DRVWLAN_802_11',23)
DBG_DRVSSM = Constant('DBG_DRVSSM',24)
DBG_DRVSMC = Constant('DBG_DRVSMC',25)
DBG_DRVMACEFIMANAGER = Constant('DBG_DRVMACEFIMANAGER',26)
DBG_DRVANE = Constant('DBG_DRVANE',27)
DBG_DRVETHERNET = Constant('DBG_DRVETHERNET',28)
DBG_DRVMCC = Constant('DBG_DRVMCC',29)
DBG_DRVACCESSORY = Constant('DBG_DRVACCESSORY',30)
DBG_SOCDIAGS = Constant('DBG_SOCDIAGS',31)
DBG_DRVVIRTIO = Constant('DBG_DRVVIRTIO',32)
DBG_DRVCELLULAR = Constant('DBG_DRVCELLULAR',33)
DBG_DRVSPMI = Constant('DBG_DRVSPMI',34)
DBG_DLIL_STATIC = Constant('DBG_DLIL_STATIC',1)
DBG_DLIL_PR_MOD = Constant('DBG_DLIL_PR_MOD',2)
DBG_DLIL_IF_MOD = Constant('DBG_DLIL_IF_MOD',3)
DBG_DLIL_PR_FLT = Constant('DBG_DLIL_PR_FLT',4)
DBG_DLIL_IF_FLT = Constant('DBG_DLIL_IF_FLT',5)
DBG_FSRW = Constant('DBG_FSRW',0x1)
DBG_DKRW = Constant('DBG_DKRW',0x2)
DBG_FSVN = Constant('DBG_FSVN',0x3)
DBG_FSLOOOKUP = Constant('DBG_FSLOOOKUP',0x4)
DBG_JOURNAL = Constant('DBG_JOURNAL',0x5)
DBG_IOCTL = Constant('DBG_IOCTL',0x6)
DBG_BOOTCACHE = Constant('DBG_BOOTCACHE',0x7)
DBG_HFS = Constant('DBG_HFS',0x8)
DBG_APFS = Constant('DBG_APFS',0x9)
DBG_SMB = Constant('DBG_SMB',0xA)
DBG_MOUNT = Constant('DBG_MOUNT',0xB)
DBG_EXFAT = Constant('DBG_EXFAT',0xE)
DBG_MSDOS = Constant('DBG_MSDOS',0xF)
DBG_ACFS = Constant('DBG_ACFS',0x10)
DBG_THROTTLE = Constant('DBG_THROTTLE',0x11)
DBG_DECMP = Constant('DBG_DECMP',0x12)
DBG_VFS = Constant('DBG_VFS',0x13)
DBG_LIVEFS = Constant('DBG_LIVEFS',0x14)
DBG_NFS = Constant('DBG_NFS',0x15)
DBG_CONTENT_PROT = Constant('DBG_CONTENT_PROT',0xCF)
DBG_HFS_UPDATE_ACCTIME = Constant('DBG_HFS_UPDATE_ACCTIME',0x01)
DBG_HFS_UPDATE_MODTIME = Constant('DBG_HFS_UPDATE_MODTIME',0x02)
DBG_HFS_UPDATE_CHGTIME = Constant('DBG_HFS_UPDATE_CHGTIME',0x04)
DBG_HFS_UPDATE_MODIFIED = Constant('DBG_HFS_UPDATE_MODIFIED',0x08)
DBG_HFS_UPDATE_FORCE = Constant('DBG_HFS_UPDATE_FORCE',0x10)
DBG_HFS_UPDATE_DATEADDED = Constant('DBG_HFS_UPDATE_DATEADDED',0x20)
DBG_HFS_UPDATE_MINOR = Constant('DBG_HFS_UPDATE_MINOR',0x40)
DBG_HFS_UPDATE_SKIPPED = Constant('DBG_HFS_UPDATE_SKIPPED',0x80)
DBG_VFS_IO_COMPRESSION_STATS = Constant('DBG_VFS_IO_COMPRESSION_STATS',0x1000)
DBG_BSD_PROC = Constant('DBG_BSD_PROC',0x01)
DBG_BSD_MEMSTAT = Constant('DBG_BSD_MEMSTAT',0x02)
DBG_BSD_KEVENT = Constant('DBG_BSD_KEVENT',0x03)
DBG_BSD_EXCP_SC = Constant('DBG_BSD_EXCP_SC',0x0C)
DBG_BSD_AIO = Constant('DBG_BSD_AIO',0x0D)
DBG_BSD_SC_EXTENDED_INFO = Constant('DBG_BSD_SC_EXTENDED_INFO',0x0E)
DBG_BSD_SC_EXTENDED_INFO2 = Constant('DBG_BSD_SC_EXTENDED_INFO2',0x0F)
DBG_BSD_KDEBUG_TEST = Constant('DBG_BSD_KDEBUG_TEST',0xFF)
BSD_PROC_EXIT = Constant('BSD_PROC_EXIT',1)
BSD_PROC_FRCEXIT = Constant('BSD_PROC_FRCEXIT',2)
BSD_PROC_EXEC = Constant('BSD_PROC_EXEC',3)
BSD_PROC_EXITREASON_CREATE = Constant('BSD_PROC_EXITREASON_CREATE',4)
BSD_PROC_EXITREASON_COMMIT = Constant('BSD_PROC_EXITREASON_COMMIT',5)
BSD_MEMSTAT_SCAN = Constant('BSD_MEMSTAT_SCAN',1)
BSD_MEMSTAT_JETSAM = Constant('BSD_MEMSTAT_JETSAM',2)
BSD_MEMSTAT_JETSAM_HIWAT = Constant('BSD_MEMSTAT_JETSAM_HIWAT',3)
BSD_MEMSTAT_FREEZE = Constant('BSD_MEMSTAT_FREEZE',4)
BSD_MEMSTAT_FREEZE_SCAN = Constant('BSD_MEMSTAT_FREEZE_SCAN',5)
BSD_MEMSTAT_UPDATE = Constant('BSD_MEMSTAT_UPDATE',6)
BSD_MEMSTAT_IDLE_DEMOTE = Constant('BSD_MEMSTAT_IDLE_DEMOTE',7)
BSD_MEMSTAT_CLEAR_ERRORS = Constant('BSD_MEMSTAT_CLEAR_ERRORS',8)
BSD_MEMSTAT_DIRTY_TRACK = Constant('BSD_MEMSTAT_DIRTY_TRACK',9)
BSD_MEMSTAT_DIRTY_SET = Constant('BSD_MEMSTAT_DIRTY_SET',10)
BSD_MEMSTAT_DIRTY_CLEAR = Constant('BSD_MEMSTAT_DIRTY_CLEAR',11)
BSD_MEMSTAT_FAST_JETSAM = Constant('BSD_MEMSTAT_FAST_JETSAM',15)
BSD_MEMSTAT_COMPACTOR_RUN = Constant('BSD_MEMSTAT_COMPACTOR_RUN',16)
BSD_MEMSTAT_FREEZE_DISABLE = Constant('BSD_MEMSTAT_FREEZE_DISABLE',17)
BSD_MEMSTAT_RELAUNCH_FLAGS = Constant('BSD_MEMSTAT_RELAUNCH_FLAGS',18)
BSD_KEVENT_KQ_PROCESS_BEGIN = Constant('BSD_KEVENT_KQ_PROCESS_BEGIN',1)
BSD_KEVENT_KQ_PROCESS_END = Constant('BSD_KEVENT_KQ_PROCESS_END',2)
BSD_KEVENT_KQWQ_PROCESS_BEGIN = Constant('BSD_KEVENT_KQWQ_PROCESS_BEGIN',3)
BSD_KEVENT_KQWQ_PROCESS_END = Constant('BSD_KEVENT_KQWQ_PROCESS_END',4)
BSD_KEVENT_KQWQ_BIND = Constant('BSD_KEVENT_KQWQ_BIND',5)
BSD_KEVENT_KQWQ_UNBIND = Constant('BSD_KEVENT_KQWQ_UNBIND',6)
BSD_KEVENT_KQWQ_THREQUEST = Constant('BSD_KEVENT_KQWQ_THREQUEST',7)
BSD_KEVENT_KQWL_PROCESS_BEGIN = Constant('BSD_KEVENT_KQWL_PROCESS_BEGIN',8)
BSD_KEVENT_KQWL_PROCESS_END = Constant('BSD_KEVENT_KQWL_PROCESS_END',9)
BSD_KEVENT_KQWL_THREQUEST = Constant('BSD_KEVENT_KQWL_THREQUEST',10)
BSD_KEVENT_KQWL_THADJUST = Constant('BSD_KEVENT_KQWL_THADJUST',11)
BSD_KEVENT_KQ_REGISTER = Constant('BSD_KEVENT_KQ_REGISTER',12)
BSD_KEVENT_KQWQ_REGISTER = Constant('BSD_KEVENT_KQWQ_REGISTER',13)
BSD_KEVENT_KQWL_REGISTER = Constant('BSD_KEVENT_KQWL_REGISTER',14)
BSD_KEVENT_KNOTE_ACTIVATE = Constant('BSD_KEVENT_KNOTE_ACTIVATE',15)
BSD_KEVENT_KQ_PROCESS = Constant('BSD_KEVENT_KQ_PROCESS',16)
BSD_KEVENT_KQWQ_PROCESS = Constant('BSD_KEVENT_KQWQ_PROCESS',17)
BSD_KEVENT_KQWL_PROCESS = Constant('BSD_KEVENT_KQWL_PROCESS',18)
BSD_KEVENT_KQWL_BIND = Constant('BSD_KEVENT_KQWL_BIND',19)
BSD_KEVENT_KQWL_UNBIND = Constant('BSD_KEVENT_KQWL_UNBIND',20)
BSD_KEVENT_KNOTE_ENABLE = Constant('BSD_KEVENT_KNOTE_ENABLE',21)
BSD_KEVENT_KNOTE_VANISHED = Constant('BSD_KEVENT_KNOTE_VANISHED',22)
DBG_TRACE_DATA = Constant('DBG_TRACE_DATA',0)
DBG_TRACE_STRING = Constant('DBG_TRACE_STRING',1)
DBG_TRACE_INFO = Constant('DBG_TRACE_INFO',2)
DBG_CS_IO = Constant('DBG_CS_IO',0)
DBG_SEC_KERNEL = Constant('DBG_SEC_KERNEL',0)
DBG_SEC_SANDBOX = Constant('DBG_SEC_SANDBOX',1)
DBG_MT_INSTRS_CYCLES = Constant('DBG_MT_INSTRS_CYCLES',1)
DBG_MT_DEBUG = Constant('DBG_MT_DEBUG',2)
DBG_MT_RESOURCES_PROC_EXIT = Constant('DBG_MT_RESOURCES_PROC_EXIT',3)
DBG_MT_RESOURCES_THR_EXIT = Constant('DBG_MT_RESOURCES_THR_EXIT',4)
DBG_MT_INSTRS_CYCLES_ON_CPU = Constant('DBG_MT_INSTRS_CYCLES_ON_CPU',5)
DBG_MT_TMPTH = Constant('DBG_MT_TMPTH',0xfe)
DBG_MT_TMPCPU = Constant('DBG_MT_TMPCPU',0xff)
DBG_MISC_COREBRIGHTNESS = Constant('DBG_MISC_COREBRIGHTNESS',0x01)
DBG_MISC_VIDEOENG = Constant('DBG_MISC_VIDEOENG',0x02)
DBG_EVENT = Constant('DBG_EVENT',0x10)
DBG_MISC_INSTRUMENTS = Constant('DBG_MISC_INSTRUMENTS',0x11)
DBG_MISC_INSTRUMENTSBT = Constant('DBG_MISC_INSTRUMENTSBT',0x12)
DBG_MISC_RUNLOOP_DETAILS = Constant('DBG_MISC_RUNLOOP_DETAILS',0x13)
DBG_MISC_RUNLOOP_BUSY = Constant('DBG_MISC_RUNLOOP_BUSY',0x14)
DBG_MISC_LAYOUT = Constant('DBG_MISC_LAYOUT',0x1a)
DBG_BUFFER = Constant('DBG_BUFFER',0x20)
DKIO_DONE = Constant('DKIO_DONE',0x01)
DKIO_READ = Constant('DKIO_READ',0x02)
DKIO_ASYNC = Constant('DKIO_ASYNC',0x04)
DKIO_META = Constant('DKIO_META',0x08)
DKIO_PAGING = Constant('DKIO_PAGING',0x10)
DKIO_THROTTLE = Constant('DKIO_THROTTLE',0x20)
DKIO_PASSIVE = Constant('DKIO_PASSIVE',0x40)
DKIO_NOCACHE = Constant('DKIO_NOCACHE',0x80)
DKIO_TIER_MASK = Constant('DKIO_TIER_MASK',0xF00)
DKIO_TIER_SHIFT = Constant('DKIO_TIER_SHIFT',8)
DKIO_TIER_UPGRADE = Constant('DKIO_TIER_UPGRADE',0x1000)
DBG_APP_LOGINWINDOW = Constant('DBG_APP_LOGINWINDOW',0x03)
DBG_APP_AUDIO = Constant('DBG_APP_AUDIO',0x04)
DBG_APP_SYSTEMUI = Constant('DBG_APP_SYSTEMUI',0x05)
DBG_APP_SIGNPOST = Constant('DBG_APP_SIGNPOST',0x0A)
DBG_APP_TAL = Constant('DBG_APP_TAL',0x0B)
DBG_APP_APPKIT = Constant('DBG_APP_APPKIT',0x0C)
DBG_APP_UIKIT = Constant('DBG_APP_UIKIT',0x0D)
DBG_APP_DFR = Constant('DBG_APP_DFR',0x0E)
DBG_APP_LAYOUT = Constant('DBG_APP_LAYOUT',0x0F)
DBG_APP_COREDATA = Constant('DBG_APP_COREDATA',0x10)
DBG_APP_RUNLOOP_BASIC = Constant('DBG_APP_RUNLOOP_BASIC',0x11)
DBG_APP_RUNLOOP_ADVANCED = Constant('DBG_APP_RUNLOOP_ADVANCED',0x12)
DBG_APP_SAMBA = Constant('DBG_APP_SAMBA',0x80)
DBG_APP_EOSSUPPORT = Constant('DBG_APP_EOSSUPPORT',0x81)
DBG_APP_MACEFIMANAGER = Constant('DBG_APP_MACEFIMANAGER',0x82)
DBG_APP_ENTERPRISE = Constant('DBG_APP_ENTERPRISE',0x83)
OPEN_THROTTLE_WINDOW = Constant('OPEN_THROTTLE_WINDOW',0x1)
PROCESS_THROTTLED = Constant('PROCESS_THROTTLED',0x2)
IO_THROTTLE_DISABLE = Constant('IO_THROTTLE_DISABLE',0x3)
IO_TIER_UPL_MISMATCH = Constant('IO_TIER_UPL_MISMATCH',0x4)
IMP_ASSERTION = Constant('IMP_ASSERTION',0x10)
IMP_BOOST = Constant('IMP_BOOST',0x11)
IMP_MSG = Constant('IMP_MSG',0x12)
IMP_WATCHPORT = Constant('IMP_WATCHPORT',0x13)
IMP_TASK_SUPPRESSION = Constant('IMP_TASK_SUPPRESSION',0x17)
IMP_TASK_APPTYPE = Constant('IMP_TASK_APPTYPE',0x18)
IMP_UPDATE = Constant('IMP_UPDATE',0x19)
IMP_USYNCH_QOS_OVERRIDE = Constant('IMP_USYNCH_QOS_OVERRIDE',0x1A)
IMP_DONOR_CHANGE = Constant('IMP_DONOR_CHANGE',0x1B)
IMP_MAIN_THREAD_QOS = Constant('IMP_MAIN_THREAD_QOS',0x1C)
IMP_SYNC_IPC_QOS = Constant('IMP_SYNC_IPC_QOS',0x1D)
IMP_TASK_POLICY_DARWIN_BG = Constant('IMP_TASK_POLICY_DARWIN_BG',0x21)
IMP_TASK_POLICY_IOPOL = Constant('IMP_TASK_POLICY_IOPOL',0x22)
IMP_TASK_POLICY_IO = Constant('IMP_TASK_POLICY_IO',0x23)
IMP_TASK_POLICY_PASSIVE_IO = Constant('IMP_TASK_POLICY_PASSIVE_IO',0x24)
IMP_TASK_POLICY_DARWIN_BG_IOPOL = Constant('IMP_TASK_POLICY_DARWIN_BG_IOPOL',0x27)
IMP_TASK_POLICY_BOOST = Constant('IMP_TASK_POLICY_BOOST',0x29)
IMP_TASK_POLICY_ROLE = Constant('IMP_TASK_POLICY_ROLE',0x2A)
IMP_TASK_POLICY_TERMINATED = Constant('IMP_TASK_POLICY_TERMINATED',0x2C)
IMP_TASK_POLICY_NEW_SOCKETS_BG = Constant('IMP_TASK_POLICY_NEW_SOCKETS_BG',0x2D)
IMP_TASK_POLICY_SUP_ACTIVE = Constant('IMP_TASK_POLICY_SUP_ACTIVE',0x2E)
IMP_TASK_POLICY_LATENCY_QOS = Constant('IMP_TASK_POLICY_LATENCY_QOS',0x2F)
IMP_TASK_POLICY_THROUGH_QOS = Constant('IMP_TASK_POLICY_THROUGH_QOS',0x30)
IMP_TASK_POLICY_WATCHERS_BG = Constant('IMP_TASK_POLICY_WATCHERS_BG',0x31)
IMP_TASK_POLICY_SFI_MANAGED = Constant('IMP_TASK_POLICY_SFI_MANAGED',0x34)
IMP_TASK_POLICY_ALL_SOCKETS_BG = Constant('IMP_TASK_POLICY_ALL_SOCKETS_BG',0x37)
IMP_TASK_POLICY_BASE_LATENCY_AND_THROUGHPUT_QOS = Constant('IMP_TASK_POLICY_BASE_LATENCY_AND_THROUGHPUT_QOS',0x39)
IMP_TASK_POLICY_OVERRIDE_LATENCY_AND_THROUGHPUT_QOS = Constant('IMP_TASK_POLICY_OVERRIDE_LATENCY_AND_THROUGHPUT_QOS',0x3A)
IMP_TASK_POLICY_PIDBIND_BG = Constant('IMP_TASK_POLICY_PIDBIND_BG',0x32)
IMP_TASK_POLICY_QOS_OVERRIDE = Constant('IMP_TASK_POLICY_QOS_OVERRIDE',0x36)
IMP_TASK_POLICY_QOS_AND_RELPRIO = Constant('IMP_TASK_POLICY_QOS_AND_RELPRIO',0x38)
IMP_TASK_POLICY_QOS_WORKQ_OVERRIDE = Constant('IMP_TASK_POLICY_QOS_WORKQ_OVERRIDE',0x3B)
IMP_TASK_POLICY_QOS_PROMOTE = Constant('IMP_TASK_POLICY_QOS_PROMOTE',0x3C)
IMP_TASK_POLICY_QOS_KEVENT_OVERRIDE = Constant('IMP_TASK_POLICY_QOS_KEVENT_OVERRIDE',0x3D)
IMP_TASK_POLICY_QOS_SERVICER_OVERRIDE = Constant('IMP_TASK_POLICY_QOS_SERVICER_OVERRIDE',0x3E)
IMP_TASK_POLICY_IOTIER_KEVENT_OVERRIDE = Constant('IMP_TASK_POLICY_IOTIER_KEVENT_OVERRIDE',0x3F)
IMP_TASK_POLICY_WI_DRIVEN = Constant('IMP_TASK_POLICY_WI_DRIVEN',0x40)
IMP_HOLD = Constant('IMP_HOLD',0x2)
IMP_DROP = Constant('IMP_DROP',0x4)
IMP_EXTERN = Constant('IMP_EXTERN',0x8)
IMP_BOOSTED = Constant('IMP_BOOSTED',0x1)
IMP_UNBOOSTED = Constant('IMP_UNBOOSTED',0x2)
IMP_MSG_SEND = Constant('IMP_MSG_SEND',0x1)
IMP_MSG_DELV = Constant('IMP_MSG_DELV',0x2)
IMP_UPDATE_TASK_CREATE = Constant('IMP_UPDATE_TASK_CREATE',0x1)
IMP_USYNCH_ADD_OVERRIDE = Constant('IMP_USYNCH_ADD_OVERRIDE',0x0)
IMP_USYNCH_REMOVE_OVERRIDE = Constant('IMP_USYNCH_REMOVE_OVERRIDE',0x1)
IMP_DONOR_UPDATE_LIVE_DONOR_STATE = Constant('IMP_DONOR_UPDATE_LIVE_DONOR_STATE',0x0)
IMP_DONOR_INIT_DONOR_STATE = Constant('IMP_DONOR_INIT_DONOR_STATE',0x1)
IMP_SYNC_IPC_QOS_APPLIED = Constant('IMP_SYNC_IPC_QOS_APPLIED',0x0)
IMP_SYNC_IPC_QOS_REMOVED = Constant('IMP_SYNC_IPC_QOS_REMOVED',0x1)
IMP_SYNC_IPC_QOS_OVERFLOW = Constant('IMP_SYNC_IPC_QOS_OVERFLOW',0x2)
IMP_SYNC_IPC_QOS_UNDERFLOW = Constant('IMP_SYNC_IPC_QOS_UNDERFLOW',0x3)
TURNSTILE_HEAP_OPERATIONS = Constant('TURNSTILE_HEAP_OPERATIONS',0x10)
TURNSTILE_PRIORITY_OPERATIONS = Constant('TURNSTILE_PRIORITY_OPERATIONS',0x20)
TURNSTILE_FREELIST_OPERATIONS = Constant('TURNSTILE_FREELIST_OPERATIONS',0x30)
THREAD_ADDED_TO_TURNSTILE_WAITQ = Constant('THREAD_ADDED_TO_TURNSTILE_WAITQ',0x1)
THREAD_REMOVED_FROM_TURNSTILE_WAITQ = Constant('THREAD_REMOVED_FROM_TURNSTILE_WAITQ',0x2)
THREAD_MOVED_IN_TURNSTILE_WAITQ = Constant('THREAD_MOVED_IN_TURNSTILE_WAITQ',0x3)
TURNSTILE_ADDED_TO_TURNSTILE_HEAP = Constant('TURNSTILE_ADDED_TO_TURNSTILE_HEAP',0x4)
TURNSTILE_REMOVED_FROM_TURNSTILE_HEAP = Constant('TURNSTILE_REMOVED_FROM_TURNSTILE_HEAP',0x5)
TURNSTILE_MOVED_IN_TURNSTILE_HEAP = Constant('TURNSTILE_MOVED_IN_TURNSTILE_HEAP',0x6)
TURNSTILE_ADDED_TO_THREAD_HEAP = Constant('TURNSTILE_ADDED_TO_THREAD_HEAP',0x7)
TURNSTILE_REMOVED_FROM_THREAD_HEAP = Constant('TURNSTILE_REMOVED_FROM_THREAD_HEAP',0x8)
TURNSTILE_MOVED_IN_THREAD_HEAP = Constant('TURNSTILE_MOVED_IN_THREAD_HEAP',0x9)
TURNSTILE_UPDATE_STOPPED_BY_LIMIT = Constant('TURNSTILE_UPDATE_STOPPED_BY_LIMIT',0xa)
THREAD_NOT_WAITING_ON_TURNSTILE = Constant('THREAD_NOT_WAITING_ON_TURNSTILE',0xb)
TURNSTILE_PRIORITY_CHANGE = Constant('TURNSTILE_PRIORITY_CHANGE',0x1)
THREAD_USER_PROMOTION_CHANGE = Constant('THREAD_USER_PROMOTION_CHANGE',0x2)
TURNSTILE_PREPARE = Constant('TURNSTILE_PREPARE',0x1)
TURNSTILE_COMPLETE = Constant('TURNSTILE_COMPLETE',0x2)
BANK_ACCOUNT_INFO = Constant('BANK_ACCOUNT_INFO',0x10)
BANK_TASK_INFO = Constant('BANK_TASK_INFO',0x11)
ATM_SUBAID_INFO = Constant('ATM_SUBAID_INFO',0x10)
ATM_GETVALUE_INFO = Constant('ATM_GETVALUE_INFO',0x20)
ATM_UNREGISTER_INFO = Constant('ATM_UNREGISTER_INFO',0x30)
BANK_SETTLE_CPU_TIME = Constant('BANK_SETTLE_CPU_TIME',0x1)
BANK_SECURE_ORIGINATOR_CHANGED = Constant('BANK_SECURE_ORIGINATOR_CHANGED',0x2)
BANK_SETTLE_ENERGY = Constant('BANK_SETTLE_ENERGY',0x3)
ATM_MIN_CALLED = Constant('ATM_MIN_CALLED',0x1)
ATM_LINK_LIST_TRIM = Constant('ATM_LINK_LIST_TRIM',0x2)
ATM_VALUE_REPLACED = Constant('ATM_VALUE_REPLACED',0x1)
ATM_VALUE_ADDED = Constant('ATM_VALUE_ADDED',0x2)
ATM_VALUE_UNREGISTERED = Constant('ATM_VALUE_UNREGISTERED',0x1)
ATM_VALUE_DIFF_MAILBOX = Constant('ATM_VALUE_DIFF_MAILBOX',0x2)
DBG_DAEMON_COREDUET = Constant('DBG_DAEMON_COREDUET',0x1)
DBG_DAEMON_POWERD = Constant('DBG_DAEMON_POWERD',0x2)
DBG_UMALLOC_EXTERNAL = Constant('DBG_UMALLOC_EXTERNAL',0x1)
DBG_UMALLOC_INTERNAL = Constant('DBG_UMALLOC_INTERNAL',0x2)
BSD = Constant('BSD',199506)
BSD4_3 = Constant('BSD4_3',1)
BSD4_4 = Constant('BSD4_4',1)
NeXTBSD = Constant('NeXTBSD',1995064)
NeXTBSD4_0 = Constant('NeXTBSD4_0',0)
MAXCOMLEN = Constant('MAXCOMLEN',16)
MAXINTERP = Constant('MAXINTERP',64)
MAXLOGNAME = Constant('MAXLOGNAME',255)
NOFILE = Constant('NOFILE',256)
NOGROUP = Constant('NOGROUP',65535)
MAXHOSTNAMELEN = Constant('MAXHOSTNAMELEN',256)
MAXDOMNAMELEN = Constant('MAXDOMNAMELEN',256)
PSWP = Constant('PSWP',0)
PVM = Constant('PVM',4)
PINOD = Constant('PINOD',8)
PRIBIO = Constant('PRIBIO',16)
PVFS = Constant('PVFS',20)
PZERO = Constant('PZERO',22)
PSOCK = Constant('PSOCK',24)
PWAIT = Constant('PWAIT',32)
PLOCK = Constant('PLOCK',36)
PPAUSE = Constant('PPAUSE',40)
PUSER = Constant('PUSER',50)
MAXPRI = Constant('MAXPRI',127)
PRIMASK = Constant('PRIMASK',0x0ff)
PCATCH = Constant('PCATCH',0x100)
PTTYBLOCK = Constant('PTTYBLOCK',0x200)
PDROP = Constant('PDROP',0x400)
PSPIN = Constant('PSPIN',0x800)
CMASK = Constant('CMASK',0o022)
CBLOCK = Constant('CBLOCK',64)
MAXFRAG = Constant('MAXFRAG',8)
MAXSYMLINKS = Constant('MAXSYMLINKS',32)
FSHIFT = Constant('FSHIFT',11)
LF_NOT_BOOSTED = Constant('LF_NOT_BOOSTED',0)
LF_BOOSTED = Constant('LF_BOOSTED',1)
PSHMNAMLEN = Constant('PSHMNAMLEN',31)
SHM_RDONLY = Constant('SHM_RDONLY',0o010000)
SHM_RND = Constant('SHM_RND',0o020000)
SHMLBA = Constant('SHMLBA',4096)
TIOCM_LE = Constant('TIOCM_LE',0o0001)
TIOCM_DTR = Constant('TIOCM_DTR',0o0002)
TIOCM_RTS = Constant('TIOCM_RTS',0o0004)
TIOCM_ST = Constant('TIOCM_ST',0o0010)
TIOCM_SR = Constant('TIOCM_SR',0o0020)
TIOCM_CTS = Constant('TIOCM_CTS',0o0040)
TIOCM_CAR = Constant('TIOCM_CAR',0o0100)
TIOCM_RNG = Constant('TIOCM_RNG',0o0200)
TIOCM_DSR = Constant('TIOCM_DSR',0o0400)
TIOCPKT_DATA = Constant('TIOCPKT_DATA',0x00)
TIOCPKT_FLUSHREAD = Constant('TIOCPKT_FLUSHREAD',0x01)
TIOCPKT_FLUSHWRITE = Constant('TIOCPKT_FLUSHWRITE',0x02)
TIOCPKT_STOP = Constant('TIOCPKT_STOP',0x04)
TIOCPKT_START = Constant('TIOCPKT_START',0x08)
TIOCPKT_NOSTOP = Constant('TIOCPKT_NOSTOP',0x10)
TIOCPKT_DOSTOP = Constant('TIOCPKT_DOSTOP',0x20)
TIOCPKT_IOCTL = Constant('TIOCPKT_IOCTL',0x40)
TTYDISC = Constant('TTYDISC',0)
TABLDISC = Constant('TABLDISC',3)
SLIPDISC = Constant('SLIPDISC',4)
PPPDISC = Constant('PPPDISC',5)
CTL_MAXNAME = Constant('CTL_MAXNAME',12)
CTLTYPE = Constant('CTLTYPE',0xf)
CTLTYPE_NODE = Constant('CTLTYPE_NODE',1)
CTLTYPE_INT = Constant('CTLTYPE_INT',2)
CTLTYPE_STRING = Constant('CTLTYPE_STRING',3)
CTLTYPE_QUAD = Constant('CTLTYPE_QUAD',4)
CTLTYPE_OPAQUE = Constant('CTLTYPE_OPAQUE',5)
CTLFLAG_RD = Constant('CTLFLAG_RD',0x80000000)
CTLFLAG_WR = Constant('CTLFLAG_WR',0x40000000)
CTLFLAG_NOLOCK = Constant('CTLFLAG_NOLOCK',0x20000000)
CTLFLAG_ANYBODY = Constant('CTLFLAG_ANYBODY',0x10000000)
CTLFLAG_SECURE = Constant('CTLFLAG_SECURE',0x08000000)
CTLFLAG_MASKED = Constant('CTLFLAG_MASKED',0x04000000)
CTLFLAG_NOAUTO = Constant('CTLFLAG_NOAUTO',0x02000000)
CTLFLAG_KERN = Constant('CTLFLAG_KERN',0x01000000)
CTLFLAG_LOCKED = Constant('CTLFLAG_LOCKED',0x00800000)
CTLFLAG_OID2 = Constant('CTLFLAG_OID2',0x00400000)
CTLFLAG_EXPERIMENT = Constant('CTLFLAG_EXPERIMENT',0x00100000)
OID_AUTO_START = Constant('OID_AUTO_START',100)
SYSCTL_OID_VERSION = Constant('SYSCTL_OID_VERSION',1)
SYSCTL_SKMEM = Constant('SYSCTL_SKMEM',1)
CTL_UNSPEC = Constant('CTL_UNSPEC',0)
CTL_KERN = Constant('CTL_KERN',1)
CTL_VM = Constant('CTL_VM',2)
CTL_VFS = Constant('CTL_VFS',3)
CTL_NET = Constant('CTL_NET',4)
CTL_DEBUG = Constant('CTL_DEBUG',5)
CTL_HW = Constant('CTL_HW',6)
CTL_MACHDEP = Constant('CTL_MACHDEP',7)
CTL_USER = Constant('CTL_USER',8)
CTL_MAXID = Constant('CTL_MAXID',9)
KERN_OSTYPE = Constant('KERN_OSTYPE',1)
KERN_OSRELEASE = Constant('KERN_OSRELEASE',2)
KERN_OSREV = Constant('KERN_OSREV',3)
KERN_VERSION = Constant('KERN_VERSION',4)
KERN_MAXVNODES = Constant('KERN_MAXVNODES',5)
KERN_MAXPROC = Constant('KERN_MAXPROC',6)
KERN_MAXFILES = Constant('KERN_MAXFILES',7)
KERN_ARGMAX = Constant('KERN_ARGMAX',8)
KERN_SECURELVL = Constant('KERN_SECURELVL',9)
KERN_HOSTNAME = Constant('KERN_HOSTNAME',10)
KERN_HOSTID = Constant('KERN_HOSTID',11)
KERN_CLOCKRATE = Constant('KERN_CLOCKRATE',12)
KERN_VNODE = Constant('KERN_VNODE',13)
KERN_PROC = Constant('KERN_PROC',14)
KERN_FILE = Constant('KERN_FILE',15)
KERN_PROF = Constant('KERN_PROF',16)
KERN_POSIX1 = Constant('KERN_POSIX1',17)
KERN_NGROUPS = Constant('KERN_NGROUPS',18)
KERN_JOB_CONTROL = Constant('KERN_JOB_CONTROL',19)
KERN_SAVED_IDS = Constant('KERN_SAVED_IDS',20)
KERN_BOOTTIME = Constant('KERN_BOOTTIME',21)
KERN_NISDOMAINNAME = Constant('KERN_NISDOMAINNAME',22)
KERN_MAXPARTITIONS = Constant('KERN_MAXPARTITIONS',23)
KERN_KDEBUG = Constant('KERN_KDEBUG',24)
KERN_UPDATEINTERVAL = Constant('KERN_UPDATEINTERVAL',25)
KERN_OSRELDATE = Constant('KERN_OSRELDATE',26)
KERN_NTP_PLL = Constant('KERN_NTP_PLL',27)
KERN_BOOTFILE = Constant('KERN_BOOTFILE',28)
KERN_MAXFILESPERPROC = Constant('KERN_MAXFILESPERPROC',29)
KERN_MAXPROCPERUID = Constant('KERN_MAXPROCPERUID',30)
KERN_DUMPDEV = Constant('KERN_DUMPDEV',31)
KERN_IPC = Constant('KERN_IPC',32)
KERN_DUMMY = Constant('KERN_DUMMY',33)
KERN_PS_STRINGS = Constant('KERN_PS_STRINGS',34)
KERN_USRSTACK32 = Constant('KERN_USRSTACK32',35)
KERN_LOGSIGEXIT = Constant('KERN_LOGSIGEXIT',36)
KERN_SYMFILE = Constant('KERN_SYMFILE',37)
KERN_PROCARGS = Constant('KERN_PROCARGS',38)
KERN_NETBOOT = Constant('KERN_NETBOOT',40)
KERN_SYSV = Constant('KERN_SYSV',42)
KERN_AFFINITY = Constant('KERN_AFFINITY',43)
KERN_TRANSLATE = Constant('KERN_TRANSLATE',44)
KERN_EXEC = Constant('KERN_EXEC',45)
KERN_AIOMAX = Constant('KERN_AIOMAX',46)
KERN_AIOPROCMAX = Constant('KERN_AIOPROCMAX',47)
KERN_AIOTHREADS = Constant('KERN_AIOTHREADS',48)
KERN_PROCARGS2 = Constant('KERN_PROCARGS2',49)
KERN_COREFILE = Constant('KERN_COREFILE',50)
KERN_COREDUMP = Constant('KERN_COREDUMP',51)
KERN_SUGID_COREDUMP = Constant('KERN_SUGID_COREDUMP',52)
KERN_PROCDELAYTERM = Constant('KERN_PROCDELAYTERM',53)
KERN_SHREG_PRIVATIZABLE = Constant('KERN_SHREG_PRIVATIZABLE',54)
KERN_LOW_PRI_WINDOW = Constant('KERN_LOW_PRI_WINDOW',56)
KERN_LOW_PRI_DELAY = Constant('KERN_LOW_PRI_DELAY',57)
KERN_POSIX = Constant('KERN_POSIX',58)
KERN_USRSTACK64 = Constant('KERN_USRSTACK64',59)
KERN_NX_PROTECTION = Constant('KERN_NX_PROTECTION',60)
KERN_TFP = Constant('KERN_TFP',61)
KERN_PROCNAME = Constant('KERN_PROCNAME',62)
KERN_THALTSTACK = Constant('KERN_THALTSTACK',63)
KERN_SPECULATIVE_READS = Constant('KERN_SPECULATIVE_READS',64)
KERN_OSVERSION = Constant('KERN_OSVERSION',65)
KERN_SAFEBOOT = Constant('KERN_SAFEBOOT',66)
KERN_RAGEVNODE = Constant('KERN_RAGEVNODE',68)
KERN_TTY = Constant('KERN_TTY',69)
KERN_CHECKOPENEVT = Constant('KERN_CHECKOPENEVT',70)
KERN_THREADNAME = Constant('KERN_THREADNAME',71)
KERN_MAXID = Constant('KERN_MAXID',72)
KERN_RAGE_PROC = Constant('KERN_RAGE_PROC',1)
KERN_RAGE_THREAD = Constant('KERN_RAGE_THREAD',2)
KERN_UNRAGE_PROC = Constant('KERN_UNRAGE_PROC',3)
KERN_UNRAGE_THREAD = Constant('KERN_UNRAGE_THREAD',4)
KERN_OPENEVT_PROC = Constant('KERN_OPENEVT_PROC',1)
KERN_UNOPENEVT_PROC = Constant('KERN_UNOPENEVT_PROC',2)
KERN_TFP_POLICY = Constant('KERN_TFP_POLICY',1)
KERN_TFP_POLICY_DENY = Constant('KERN_TFP_POLICY_DENY',0)
KERN_TFP_POLICY_DEFAULT = Constant('KERN_TFP_POLICY_DEFAULT',2)
KERN_KDEFLAGS = Constant('KERN_KDEFLAGS',1)
KERN_KDDFLAGS = Constant('KERN_KDDFLAGS',2)
KERN_KDENABLE = Constant('KERN_KDENABLE',3)
KERN_KDSETBUF = Constant('KERN_KDSETBUF',4)
KERN_KDGETBUF = Constant('KERN_KDGETBUF',5)
KERN_KDSETUP = Constant('KERN_KDSETUP',6)
KERN_KDREMOVE = Constant('KERN_KDREMOVE',7)
KERN_KDSETREG = Constant('KERN_KDSETREG',8)
KERN_KDGETREG = Constant('KERN_KDGETREG',9)
KERN_KDREADTR = Constant('KERN_KDREADTR',10)
KERN_KDPIDTR = Constant('KERN_KDPIDTR',11)
KERN_KDTHRMAP = Constant('KERN_KDTHRMAP',12)
KERN_KDPIDEX = Constant('KERN_KDPIDEX',14)
KERN_KDSETRTCDEC = Constant('KERN_KDSETRTCDEC',15)
KERN_KDGETENTROPY = Constant('KERN_KDGETENTROPY',16)
KERN_KDWRITETR = Constant('KERN_KDWRITETR',17)
KERN_KDWRITEMAP = Constant('KERN_KDWRITEMAP',18)
KERN_KDTEST = Constant('KERN_KDTEST',19)
KERN_KDREADCURTHRMAP = Constant('KERN_KDREADCURTHRMAP',21)
KERN_KDSET_TYPEFILTER = Constant('KERN_KDSET_TYPEFILTER',22)
KERN_KDBUFWAIT = Constant('KERN_KDBUFWAIT',23)
KERN_KDCPUMAP = Constant('KERN_KDCPUMAP',24)
KERN_KDCPUMAP_EXT = Constant('KERN_KDCPUMAP_EXT',25)
KERN_KDSET_EDM = Constant('KERN_KDSET_EDM',26)
KERN_KDGET_EDM = Constant('KERN_KDGET_EDM',27)
KERN_KDWRITETR_V3 = Constant('KERN_KDWRITETR_V3',28)
KERN_PROC_ALL = Constant('KERN_PROC_ALL',0)
KERN_PROC_PID = Constant('KERN_PROC_PID',1)
KERN_PROC_PGRP = Constant('KERN_PROC_PGRP',2)
KERN_PROC_SESSION = Constant('KERN_PROC_SESSION',3)
KERN_PROC_TTY = Constant('KERN_PROC_TTY',4)
KERN_PROC_UID = Constant('KERN_PROC_UID',5)
KERN_PROC_RUID = Constant('KERN_PROC_RUID',6)
KERN_PROC_LCID = Constant('KERN_PROC_LCID',7)
KERN_VFSNSPACE_HANDLE_PROC = Constant('KERN_VFSNSPACE_HANDLE_PROC',1)
KERN_VFSNSPACE_UNHANDLE_PROC = Constant('KERN_VFSNSPACE_UNHANDLE_PROC',2)
KIPC_MAXSOCKBUF = Constant('KIPC_MAXSOCKBUF',1)
KIPC_SOCKBUF_WASTE = Constant('KIPC_SOCKBUF_WASTE',2)
KIPC_SOMAXCONN = Constant('KIPC_SOMAXCONN',3)
KIPC_MAX_LINKHDR = Constant('KIPC_MAX_LINKHDR',4)
KIPC_MAX_PROTOHDR = Constant('KIPC_MAX_PROTOHDR',5)
KIPC_MAX_HDR = Constant('KIPC_MAX_HDR',6)
KIPC_MAX_DATALEN = Constant('KIPC_MAX_DATALEN',7)
KIPC_MBSTAT = Constant('KIPC_MBSTAT',8)
KIPC_NMBCLUSTERS = Constant('KIPC_NMBCLUSTERS',9)
KIPC_SOQLIMITCOMPAT = Constant('KIPC_SOQLIMITCOMPAT',10)
VM_METER = Constant('VM_METER',1)
VM_LOADAVG = Constant('VM_LOADAVG',2)
VM_MACHFACTOR = Constant('VM_MACHFACTOR',4)
VM_SWAPUSAGE = Constant('VM_SWAPUSAGE',5)
VM_MAXID = Constant('VM_MAXID',6)
LSCALE = Constant('LSCALE',1000)
HW_MACHINE = Constant('HW_MACHINE',1)
HW_MODEL = Constant('HW_MODEL',2)
HW_NCPU = Constant('HW_NCPU',3)
HW_BYTEORDER = Constant('HW_BYTEORDER',4)
HW_PHYSMEM = Constant('HW_PHYSMEM',5)
HW_USERMEM = Constant('HW_USERMEM',6)
HW_PAGESIZE = Constant('HW_PAGESIZE',7)
HW_DISKNAMES = Constant('HW_DISKNAMES',8)
HW_DISKSTATS = Constant('HW_DISKSTATS',9)
HW_EPOCH = Constant('HW_EPOCH',10)
HW_FLOATINGPT = Constant('HW_FLOATINGPT',11)
HW_MACHINE_ARCH = Constant('HW_MACHINE_ARCH',12)
HW_VECTORUNIT = Constant('HW_VECTORUNIT',13)
HW_BUS_FREQ = Constant('HW_BUS_FREQ',14)
HW_CPU_FREQ = Constant('HW_CPU_FREQ',15)
HW_CACHELINE = Constant('HW_CACHELINE',16)
HW_L1ICACHESIZE = Constant('HW_L1ICACHESIZE',17)
HW_L1DCACHESIZE = Constant('HW_L1DCACHESIZE',18)
HW_L2SETTINGS = Constant('HW_L2SETTINGS',19)
HW_L2CACHESIZE = Constant('HW_L2CACHESIZE',20)
HW_L3SETTINGS = Constant('HW_L3SETTINGS',21)
HW_L3CACHESIZE = Constant('HW_L3CACHESIZE',22)
HW_TB_FREQ = Constant('HW_TB_FREQ',23)
HW_MEMSIZE = Constant('HW_MEMSIZE',24)
HW_AVAILCPU = Constant('HW_AVAILCPU',25)
HW_TARGET = Constant('HW_TARGET',26)
HW_PRODUCT = Constant('HW_PRODUCT',27)
HW_MAXID = Constant('HW_MAXID',28)
USER_CS_PATH = Constant('USER_CS_PATH',1)
USER_BC_BASE_MAX = Constant('USER_BC_BASE_MAX',2)
USER_BC_DIM_MAX = Constant('USER_BC_DIM_MAX',3)
USER_BC_SCALE_MAX = Constant('USER_BC_SCALE_MAX',4)
USER_BC_STRING_MAX = Constant('USER_BC_STRING_MAX',5)
USER_COLL_WEIGHTS_MAX = Constant('USER_COLL_WEIGHTS_MAX',6)
USER_EXPR_NEST_MAX = Constant('USER_EXPR_NEST_MAX',7)
USER_LINE_MAX = Constant('USER_LINE_MAX',8)
USER_RE_DUP_MAX = Constant('USER_RE_DUP_MAX',9)
USER_POSIX2_VERSION = Constant('USER_POSIX2_VERSION',10)
USER_POSIX2_C_BIND = Constant('USER_POSIX2_C_BIND',11)
USER_POSIX2_C_DEV = Constant('USER_POSIX2_C_DEV',12)
USER_POSIX2_CHAR_TERM = Constant('USER_POSIX2_CHAR_TERM',13)
USER_POSIX2_FORT_DEV = Constant('USER_POSIX2_FORT_DEV',14)
USER_POSIX2_FORT_RUN = Constant('USER_POSIX2_FORT_RUN',15)
USER_POSIX2_LOCALEDEF = Constant('USER_POSIX2_LOCALEDEF',16)
USER_POSIX2_SW_DEV = Constant('USER_POSIX2_SW_DEV',17)
USER_POSIX2_UPE = Constant('USER_POSIX2_UPE',18)
USER_STREAM_MAX = Constant('USER_STREAM_MAX',19)
USER_TZNAME_MAX = Constant('USER_TZNAME_MAX',20)
USER_MAXID = Constant('USER_MAXID',21)
CTL_DEBUG_NAME = Constant('CTL_DEBUG_NAME',0)
CTL_DEBUG_VALUE = Constant('CTL_DEBUG_VALUE',1)
CTL_DEBUG_MAXID = Constant('CTL_DEBUG_MAXID',20)
UTF_REVERSE_ENDIAN = Constant('UTF_REVERSE_ENDIAN',0x0001)
UTF_NO_NULL_TERM = Constant('UTF_NO_NULL_TERM',0x0002)
UTF_DECOMPOSED = Constant('UTF_DECOMPOSED',0x0004)
UTF_PRECOMPOSED = Constant('UTF_PRECOMPOSED',0x0008)
UTF_ESCAPE_ILLEGAL = Constant('UTF_ESCAPE_ILLEGAL',0x0010)
UTF_SFM_CONVERSIONS = Constant('UTF_SFM_CONVERSIONS',0x0020)
PRIO_PROCESS = Constant('PRIO_PROCESS',0)
PRIO_PGRP = Constant('PRIO_PGRP',1)
PRIO_USER = Constant('PRIO_USER',2)
PRIO_DARWIN_THREAD = Constant('PRIO_DARWIN_THREAD',3)
PRIO_DARWIN_PROCESS = Constant('PRIO_DARWIN_PROCESS',4)
PRIO_MAX = Constant('PRIO_MAX',20)
PRIO_DARWIN_BG = Constant('PRIO_DARWIN_BG',0x1000)
PRIO_DARWIN_NONUI = Constant('PRIO_DARWIN_NONUI',0x1001)
RUSAGE_SELF = Constant('RUSAGE_SELF',0)
RUSAGE_INFO_V0 = Constant('RUSAGE_INFO_V0',0)
RUSAGE_INFO_V1 = Constant('RUSAGE_INFO_V1',1)
RUSAGE_INFO_V2 = Constant('RUSAGE_INFO_V2',2)
RUSAGE_INFO_V3 = Constant('RUSAGE_INFO_V3',3)
RUSAGE_INFO_V4 = Constant('RUSAGE_INFO_V4',4)
RUSAGE_INFO_V5 = Constant('RUSAGE_INFO_V5',5)
RUSAGE_INFO_V6 = Constant('RUSAGE_INFO_V6',6)
RU_PROC_RUNS_RESLIDE = Constant('RU_PROC_RUNS_RESLIDE',0x00000001)
RLIMIT_CPU = Constant('RLIMIT_CPU',0)
RLIMIT_FSIZE = Constant('RLIMIT_FSIZE',1)
RLIMIT_DATA = Constant('RLIMIT_DATA',2)
RLIMIT_STACK = Constant('RLIMIT_STACK',3)
RLIMIT_CORE = Constant('RLIMIT_CORE',4)
RLIMIT_AS = Constant('RLIMIT_AS',5)
RLIMIT_MEMLOCK = Constant('RLIMIT_MEMLOCK',6)
RLIMIT_NPROC = Constant('RLIMIT_NPROC',7)
RLIMIT_NOFILE = Constant('RLIMIT_NOFILE',8)
RLIM_NLIMITS = Constant('RLIM_NLIMITS',9)
_RLIMIT_POSIX_FLAG = Constant('_RLIMIT_POSIX_FLAG',0x1000)
RLIMIT_WAKEUPS_MONITOR = Constant('RLIMIT_WAKEUPS_MONITOR',0x1)
RLIMIT_CPU_USAGE_MONITOR = Constant('RLIMIT_CPU_USAGE_MONITOR',0x2)
RLIMIT_THREAD_CPULIMITS = Constant('RLIMIT_THREAD_CPULIMITS',0x3)
RLIMIT_FOOTPRINT_INTERVAL = Constant('RLIMIT_FOOTPRINT_INTERVAL',0x4)
WAKEMON_ENABLE = Constant('WAKEMON_ENABLE',0x01)
WAKEMON_DISABLE = Constant('WAKEMON_DISABLE',0x02)
WAKEMON_GET_PARAMS = Constant('WAKEMON_GET_PARAMS',0x04)
WAKEMON_SET_DEFAULTS = Constant('WAKEMON_SET_DEFAULTS',0x08)
WAKEMON_MAKE_FATAL = Constant('WAKEMON_MAKE_FATAL',0x10)
CPUMON_MAKE_FATAL = Constant('CPUMON_MAKE_FATAL',0x1000)
FOOTPRINT_INTERVAL_RESET = Constant('FOOTPRINT_INTERVAL_RESET',0x1)
IOPOL_TYPE_DISK = Constant('IOPOL_TYPE_DISK',0)
IOPOL_TYPE_VFS_ATIME_UPDATES = Constant('IOPOL_TYPE_VFS_ATIME_UPDATES',2)
IOPOL_TYPE_VFS_MATERIALIZE_DATALESS_FILES = Constant('IOPOL_TYPE_VFS_MATERIALIZE_DATALESS_FILES',3)
IOPOL_TYPE_VFS_STATFS_NO_DATA_VOLUME = Constant('IOPOL_TYPE_VFS_STATFS_NO_DATA_VOLUME',4)
IOPOL_TYPE_VFS_TRIGGER_RESOLVE = Constant('IOPOL_TYPE_VFS_TRIGGER_RESOLVE',5)
IOPOL_TYPE_VFS_IGNORE_CONTENT_PROTECTION = Constant('IOPOL_TYPE_VFS_IGNORE_CONTENT_PROTECTION',6)
IOPOL_TYPE_VFS_IGNORE_PERMISSIONS = Constant('IOPOL_TYPE_VFS_IGNORE_PERMISSIONS',7)
IOPOL_TYPE_VFS_SKIP_MTIME_UPDATE = Constant('IOPOL_TYPE_VFS_SKIP_MTIME_UPDATE',8)
IOPOL_TYPE_VFS_ALLOW_LOW_SPACE_WRITES = Constant('IOPOL_TYPE_VFS_ALLOW_LOW_SPACE_WRITES',9)
IOPOL_TYPE_VFS_DISALLOW_RW_FOR_O_EVTONLY = Constant('IOPOL_TYPE_VFS_DISALLOW_RW_FOR_O_EVTONLY',10)
IOPOL_SCOPE_PROCESS = Constant('IOPOL_SCOPE_PROCESS',0)
IOPOL_SCOPE_THREAD = Constant('IOPOL_SCOPE_THREAD',1)
IOPOL_SCOPE_DARWIN_BG = Constant('IOPOL_SCOPE_DARWIN_BG',2)
IOPOL_DEFAULT = Constant('IOPOL_DEFAULT',0)
IOPOL_IMPORTANT = Constant('IOPOL_IMPORTANT',1)
IOPOL_PASSIVE = Constant('IOPOL_PASSIVE',2)
IOPOL_THROTTLE = Constant('IOPOL_THROTTLE',3)
IOPOL_UTILITY = Constant('IOPOL_UTILITY',4)
IOPOL_STANDARD = Constant('IOPOL_STANDARD',5)
IOPOL_ATIME_UPDATES_DEFAULT = Constant('IOPOL_ATIME_UPDATES_DEFAULT',0)
IOPOL_ATIME_UPDATES_OFF = Constant('IOPOL_ATIME_UPDATES_OFF',1)
IOPOL_MATERIALIZE_DATALESS_FILES_DEFAULT = Constant('IOPOL_MATERIALIZE_DATALESS_FILES_DEFAULT',0)
IOPOL_MATERIALIZE_DATALESS_FILES_OFF = Constant('IOPOL_MATERIALIZE_DATALESS_FILES_OFF',1)
IOPOL_MATERIALIZE_DATALESS_FILES_ON = Constant('IOPOL_MATERIALIZE_DATALESS_FILES_ON',2)
IOPOL_VFS_STATFS_NO_DATA_VOLUME_DEFAULT = Constant('IOPOL_VFS_STATFS_NO_DATA_VOLUME_DEFAULT',0)
IOPOL_VFS_STATFS_FORCE_NO_DATA_VOLUME = Constant('IOPOL_VFS_STATFS_FORCE_NO_DATA_VOLUME',1)
IOPOL_VFS_TRIGGER_RESOLVE_DEFAULT = Constant('IOPOL_VFS_TRIGGER_RESOLVE_DEFAULT',0)
IOPOL_VFS_TRIGGER_RESOLVE_OFF = Constant('IOPOL_VFS_TRIGGER_RESOLVE_OFF',1)
IOPOL_VFS_CONTENT_PROTECTION_DEFAULT = Constant('IOPOL_VFS_CONTENT_PROTECTION_DEFAULT',0)
IOPOL_VFS_CONTENT_PROTECTION_IGNORE = Constant('IOPOL_VFS_CONTENT_PROTECTION_IGNORE',1)
IOPOL_VFS_IGNORE_PERMISSIONS_OFF = Constant('IOPOL_VFS_IGNORE_PERMISSIONS_OFF',0)
IOPOL_VFS_IGNORE_PERMISSIONS_ON = Constant('IOPOL_VFS_IGNORE_PERMISSIONS_ON',1)
IOPOL_VFS_SKIP_MTIME_UPDATE_OFF = Constant('IOPOL_VFS_SKIP_MTIME_UPDATE_OFF',0)
IOPOL_VFS_SKIP_MTIME_UPDATE_ON = Constant('IOPOL_VFS_SKIP_MTIME_UPDATE_ON',1)
IOPOL_VFS_ALLOW_LOW_SPACE_WRITES_OFF = Constant('IOPOL_VFS_ALLOW_LOW_SPACE_WRITES_OFF',0)
IOPOL_VFS_ALLOW_LOW_SPACE_WRITES_ON = Constant('IOPOL_VFS_ALLOW_LOW_SPACE_WRITES_ON',1)
IOPOL_VFS_DISALLOW_RW_FOR_O_EVTONLY_DEFAULT = Constant('IOPOL_VFS_DISALLOW_RW_FOR_O_EVTONLY_DEFAULT',0)
IOPOL_VFS_DISALLOW_RW_FOR_O_EVTONLY_ON = Constant('IOPOL_VFS_DISALLOW_RW_FOR_O_EVTONLY_ON',1)
IOPOL_VFS_NOCACHE_WRITE_FS_BLKSIZE_DEFAULT = Constant('IOPOL_VFS_NOCACHE_WRITE_FS_BLKSIZE_DEFAULT',0)
IOPOL_VFS_NOCACHE_WRITE_FS_BLKSIZE_ON = Constant('IOPOL_VFS_NOCACHE_WRITE_FS_BLKSIZE_ON',1)
IOCPARM_MASK = Constant('IOCPARM_MASK',0x1fff)
XATTR_NOFOLLOW = Constant('XATTR_NOFOLLOW',0x0001)
XATTR_CREATE = Constant('XATTR_CREATE',0x0002)
XATTR_REPLACE = Constant('XATTR_REPLACE',0x0004)
XATTR_NOSECURITY = Constant('XATTR_NOSECURITY',0x0008)
XATTR_NODEFAULT = Constant('XATTR_NODEFAULT',0x0010)
XATTR_SHOWCOMPRESSION = Constant('XATTR_SHOWCOMPRESSION',0x0020)
XATTR_NOFOLLOW_ANY = Constant('XATTR_NOFOLLOW_ANY',0x0040)
XATTR_MAXNAMELEN = Constant('XATTR_MAXNAMELEN',127)
PR_SLOWHZ = Constant('PR_SLOWHZ',2)
PRC_IFDOWN = Constant('PRC_IFDOWN',0)
PRC_ROUTEDEAD = Constant('PRC_ROUTEDEAD',1)
PRC_IFUP = Constant('PRC_IFUP',2)
PRC_QUENCH2 = Constant('PRC_QUENCH2',3)
PRC_QUENCH = Constant('PRC_QUENCH',4)
PRC_MSGSIZE = Constant('PRC_MSGSIZE',5)
PRC_HOSTDEAD = Constant('PRC_HOSTDEAD',6)
PRC_HOSTUNREACH = Constant('PRC_HOSTUNREACH',7)
PRC_UNREACH_NET = Constant('PRC_UNREACH_NET',8)
PRC_UNREACH_HOST = Constant('PRC_UNREACH_HOST',9)
PRC_UNREACH_PROTOCOL = Constant('PRC_UNREACH_PROTOCOL',10)
PRC_UNREACH_PORT = Constant('PRC_UNREACH_PORT',11)
PRC_UNREACH_SRCFAIL = Constant('PRC_UNREACH_SRCFAIL',13)
PRC_REDIRECT_NET = Constant('PRC_REDIRECT_NET',14)
PRC_REDIRECT_HOST = Constant('PRC_REDIRECT_HOST',15)
PRC_REDIRECT_TOSNET = Constant('PRC_REDIRECT_TOSNET',16)
PRC_REDIRECT_TOSHOST = Constant('PRC_REDIRECT_TOSHOST',17)
PRC_TIMXCEED_INTRANS = Constant('PRC_TIMXCEED_INTRANS',18)
PRC_TIMXCEED_REASS = Constant('PRC_TIMXCEED_REASS',19)
PRC_PARAMPROB = Constant('PRC_PARAMPROB',20)
PRC_UNREACH_ADMIN_PROHIB = Constant('PRC_UNREACH_ADMIN_PROHIB',21)
PRC_NCMDS = Constant('PRC_NCMDS',22)
KEV_CTL_SUBCLASS = Constant('KEV_CTL_SUBCLASS',2)
KEV_CTL_REGISTERED = Constant('KEV_CTL_REGISTERED',1)
KEV_CTL_DEREGISTERED = Constant('KEV_CTL_DEREGISTERED',2)
MAX_KCTL_NAME = Constant('MAX_KCTL_NAME',96)
CTL_FLAG_PRIVILEGED = Constant('CTL_FLAG_PRIVILEGED',0x1)
CTL_FLAG_REG_ID_UNIT = Constant('CTL_FLAG_REG_ID_UNIT',0x2)
CTL_FLAG_REG_SOCK_STREAM = Constant('CTL_FLAG_REG_SOCK_STREAM',0x4)
CTL_DATA_NOWAKEUP = Constant('CTL_DATA_NOWAKEUP',0x1)
CTL_DATA_EOR = Constant('CTL_DATA_EOR',0x2)
__has_safe_buffers = Constant('__has_safe_buffers',0)
__DARWIN_ONLY_64_BIT_INO_T = Constant('__DARWIN_ONLY_64_BIT_INO_T',0)
__DARWIN_ONLY_UNIX_CONFORMANCE = Constant('__DARWIN_ONLY_UNIX_CONFORMANCE',0)
__DARWIN_ONLY_VERS_1050 = Constant('__DARWIN_ONLY_VERS_1050',0)
__STDC_WANT_LIB_EXT1__ = Constant('__STDC_WANT_LIB_EXT1__',1)
__DARWIN_NO_LONG_LONG = Constant('__DARWIN_NO_LONG_LONG',0)
_DARWIN_FEATURE_64_BIT_INODE = Constant('_DARWIN_FEATURE_64_BIT_INODE',1)
_DARWIN_FEATURE_ONLY_64_BIT_INODE = Constant('_DARWIN_FEATURE_ONLY_64_BIT_INODE',1)
_DARWIN_FEATURE_ONLY_VERS_1050 = Constant('_DARWIN_FEATURE_ONLY_VERS_1050',1)
_DARWIN_FEATURE_ONLY_UNIX_CONFORMANCE = Constant('_DARWIN_FEATURE_ONLY_UNIX_CONFORMANCE',1)
_DARWIN_FEATURE_UNIX_CONFORMANCE = Constant('_DARWIN_FEATURE_UNIX_CONFORMANCE',3)
__has_ptrcheck = Constant('__has_ptrcheck',0)
MAXMAXPARTITIONS = Constant('MAXMAXPARTITIONS',22)
NDDATA = Constant('NDDATA',5)
NSPARE = Constant('NSPARE',5)
DTYPE_SMD = Constant('DTYPE_SMD',1)
DTYPE_MSCP = Constant('DTYPE_MSCP',2)
DTYPE_DEC = Constant('DTYPE_DEC',3)
DTYPE_SCSI = Constant('DTYPE_SCSI',4)
DTYPE_ESDI = Constant('DTYPE_ESDI',5)
DTYPE_ST506 = Constant('DTYPE_ST506',6)
DTYPE_HPIB = Constant('DTYPE_HPIB',7)
DTYPE_HPFL = Constant('DTYPE_HPFL',8)
DTYPE_FLOPPY = Constant('DTYPE_FLOPPY',10)
FS_UNUSED = Constant('FS_UNUSED',0)
FS_SWAP = Constant('FS_SWAP',1)
FS_V6 = Constant('FS_V6',2)
FS_V7 = Constant('FS_V7',3)
FS_SYSV = Constant('FS_SYSV',4)
FS_V71K = Constant('FS_V71K',5)
FS_V8 = Constant('FS_V8',6)
FS_BSDFFS = Constant('FS_BSDFFS',7)
FS_MSDOS = Constant('FS_MSDOS',8)
FS_BSDLFS = Constant('FS_BSDLFS',9)
FS_OTHER = Constant('FS_OTHER',10)
FS_HPFS = Constant('FS_HPFS',11)
FS_ISO9660 = Constant('FS_ISO9660',12)
FS_BOOT = Constant('FS_BOOT',13)
FS_ADOS = Constant('FS_ADOS',14)
FS_HFS = Constant('FS_HFS',15)
D_REMOVABLE = Constant('D_REMOVABLE',0x01)
D_ECC = Constant('D_ECC',0x02)
D_BADSECT = Constant('D_BADSECT',0x04)
D_RAMDISK = Constant('D_RAMDISK',0x08)
D_CHAIN = Constant('D_CHAIN',0x10)
D_SSE = Constant('D_SSE',0x1)
EPERM = Constant('EPERM',1)
ENOENT = Constant('ENOENT',2)
ESRCH = Constant('ESRCH',3)
EINTR = Constant('EINTR',4)
EIO = Constant('EIO',5)
ENXIO = Constant('ENXIO',6)
E2BIG = Constant('E2BIG',7)
ENOEXEC = Constant('ENOEXEC',8)
EBADF = Constant('EBADF',9)
ECHILD = Constant('ECHILD',10)
EDEADLK = Constant('EDEADLK',11)
ENOMEM = Constant('ENOMEM',12)
EACCES = Constant('EACCES',13)
EFAULT = Constant('EFAULT',14)
ENOTBLK = Constant('ENOTBLK',15)
EBUSY = Constant('EBUSY',16)
EEXIST = Constant('EEXIST',17)
EXDEV = Constant('EXDEV',18)
ENODEV = Constant('ENODEV',19)
ENOTDIR = Constant('ENOTDIR',20)
EISDIR = Constant('EISDIR',21)
EINVAL = Constant('EINVAL',22)
ENFILE = Constant('ENFILE',23)
EMFILE = Constant('EMFILE',24)
ENOTTY = Constant('ENOTTY',25)
ETXTBSY = Constant('ETXTBSY',26)
EFBIG = Constant('EFBIG',27)
ENOSPC = Constant('ENOSPC',28)
ESPIPE = Constant('ESPIPE',29)
EROFS = Constant('EROFS',30)
EMLINK = Constant('EMLINK',31)
EPIPE = Constant('EPIPE',32)
EDOM = Constant('EDOM',33)
ERANGE = Constant('ERANGE',34)
EAGAIN = Constant('EAGAIN',35)
EINPROGRESS = Constant('EINPROGRESS',36)
EALREADY = Constant('EALREADY',37)
ENOTSOCK = Constant('ENOTSOCK',38)
EDESTADDRREQ = Constant('EDESTADDRREQ',39)
EMSGSIZE = Constant('EMSGSIZE',40)
EPROTOTYPE = Constant('EPROTOTYPE',41)
ENOPROTOOPT = Constant('ENOPROTOOPT',42)
EPROTONOSUPPORT = Constant('EPROTONOSUPPORT',43)
ESOCKTNOSUPPORT = Constant('ESOCKTNOSUPPORT',44)
ENOTSUP = Constant('ENOTSUP',45)
EPFNOSUPPORT = Constant('EPFNOSUPPORT',46)
EAFNOSUPPORT = Constant('EAFNOSUPPORT',47)
EADDRINUSE = Constant('EADDRINUSE',48)
EADDRNOTAVAIL = Constant('EADDRNOTAVAIL',49)
ENETDOWN = Constant('ENETDOWN',50)
ENETUNREACH = Constant('ENETUNREACH',51)
ENETRESET = Constant('ENETRESET',52)
ECONNABORTED = Constant('ECONNABORTED',53)
ECONNRESET = Constant('ECONNRESET',54)
ENOBUFS = Constant('ENOBUFS',55)
EISCONN = Constant('EISCONN',56)
ENOTCONN = Constant('ENOTCONN',57)
ESHUTDOWN = Constant('ESHUTDOWN',58)
ETOOMANYREFS = Constant('ETOOMANYREFS',59)
ETIMEDOUT = Constant('ETIMEDOUT',60)
ECONNREFUSED = Constant('ECONNREFUSED',61)
ELOOP = Constant('ELOOP',62)
ENAMETOOLONG = Constant('ENAMETOOLONG',63)
EHOSTDOWN = Constant('EHOSTDOWN',64)
EHOSTUNREACH = Constant('EHOSTUNREACH',65)
ENOTEMPTY = Constant('ENOTEMPTY',66)
EPROCLIM = Constant('EPROCLIM',67)
EUSERS = Constant('EUSERS',68)
EDQUOT = Constant('EDQUOT',69)
ESTALE = Constant('ESTALE',70)
EREMOTE = Constant('EREMOTE',71)
EBADRPC = Constant('EBADRPC',72)
ERPCMISMATCH = Constant('ERPCMISMATCH',73)
EPROGUNAVAIL = Constant('EPROGUNAVAIL',74)
EPROGMISMATCH = Constant('EPROGMISMATCH',75)
EPROCUNAVAIL = Constant('EPROCUNAVAIL',76)
ENOLCK = Constant('ENOLCK',77)
ENOSYS = Constant('ENOSYS',78)
EFTYPE = Constant('EFTYPE',79)
EAUTH = Constant('EAUTH',80)
ENEEDAUTH = Constant('ENEEDAUTH',81)
EPWROFF = Constant('EPWROFF',82)
EDEVERR = Constant('EDEVERR',83)
EOVERFLOW = Constant('EOVERFLOW',84)
EBADEXEC = Constant('EBADEXEC',85)
EBADARCH = Constant('EBADARCH',86)
ESHLIBVERS = Constant('ESHLIBVERS',87)
EBADMACHO = Constant('EBADMACHO',88)
ECANCELED = Constant('ECANCELED',89)
EIDRM = Constant('EIDRM',90)
ENOMSG = Constant('ENOMSG',91)
EILSEQ = Constant('EILSEQ',92)
ENOATTR = Constant('ENOATTR',93)
EBADMSG = Constant('EBADMSG',94)
EMULTIHOP = Constant('EMULTIHOP',95)
ENODATA = Constant('ENODATA',96)
ENOLINK = Constant('ENOLINK',97)
ENOSR = Constant('ENOSR',98)
ENOSTR = Constant('ENOSTR',99)
EPROTO = Constant('EPROTO',100)
ETIME = Constant('ETIME',101)
EOPNOTSUPP = Constant('EOPNOTSUPP',102)
ENOPOLICY = Constant('ENOPOLICY',103)
ENOTRECOVERABLE = Constant('ENOTRECOVERABLE',104)
EOWNERDEAD = Constant('EOWNERDEAD',105)
EQFULL = Constant('EQFULL',106)
ELAST = Constant('ELAST',106)
VEOF = Constant('VEOF',0)
VEOL = Constant('VEOL',1)
VEOL2 = Constant('VEOL2',2)
VERASE = Constant('VERASE',3)
VWERASE = Constant('VWERASE',4)
VKILL = Constant('VKILL',5)
VREPRINT = Constant('VREPRINT',6)
VINTR = Constant('VINTR',8)
VQUIT = Constant('VQUIT',9)
VSUSP = Constant('VSUSP',10)
VDSUSP = Constant('VDSUSP',11)
VSTART = Constant('VSTART',12)
VSTOP = Constant('VSTOP',13)
VLNEXT = Constant('VLNEXT',14)
VDISCARD = Constant('VDISCARD',15)
VMIN = Constant('VMIN',16)
VTIME = Constant('VTIME',17)
VSTATUS = Constant('VSTATUS',18)
NCCS = Constant('NCCS',20)
IGNBRK = Constant('IGNBRK',0x00000001)
BRKINT = Constant('BRKINT',0x00000002)
IGNPAR = Constant('IGNPAR',0x00000004)
PARMRK = Constant('PARMRK',0x00000008)
INPCK = Constant('INPCK',0x00000010)
ISTRIP = Constant('ISTRIP',0x00000020)
INLCR = Constant('INLCR',0x00000040)
IGNCR = Constant('IGNCR',0x00000080)
ICRNL = Constant('ICRNL',0x00000100)
IXON = Constant('IXON',0x00000200)
IXOFF = Constant('IXOFF',0x00000400)
IXANY = Constant('IXANY',0x00000800)
IMAXBEL = Constant('IMAXBEL',0x00002000)
IUTF8 = Constant('IUTF8',0x00004000)
OPOST = Constant('OPOST',0x00000001)
ONLCR = Constant('ONLCR',0x00000002)
OXTABS = Constant('OXTABS',0x00000004)
ONOEOT = Constant('ONOEOT',0x00000008)
OCRNL = Constant('OCRNL',0x00000010)
ONOCR = Constant('ONOCR',0x00000020)
ONLRET = Constant('ONLRET',0x00000040)
OFILL = Constant('OFILL',0x00000080)
NLDLY = Constant('NLDLY',0x00000300)
TABDLY = Constant('TABDLY',0x00000c04)
CRDLY = Constant('CRDLY',0x00003000)
FFDLY = Constant('FFDLY',0x00004000)
BSDLY = Constant('BSDLY',0x00008000)
VTDLY = Constant('VTDLY',0x00010000)
OFDEL = Constant('OFDEL',0x00020000)
TAB3 = Constant('TAB3',0x00000004)
VT0 = Constant('VT0',0x00000000)
VT1 = Constant('VT1',0x00010000)
CIGNORE = Constant('CIGNORE',0x00000001)
CSIZE = Constant('CSIZE',0x00000300)
CS5 = Constant('CS5',0x00000000)
CS6 = Constant('CS6',0x00000100)
CS7 = Constant('CS7',0x00000200)
CS8 = Constant('CS8',0x00000300)
CSTOPB = Constant('CSTOPB',0x00000400)
CREAD = Constant('CREAD',0x00000800)
PARENB = Constant('PARENB',0x00001000)
PARODD = Constant('PARODD',0x00002000)
HUPCL = Constant('HUPCL',0x00004000)
CLOCAL = Constant('CLOCAL',0x00008000)
CCTS_OFLOW = Constant('CCTS_OFLOW',0x00010000)
CRTS_IFLOW = Constant('CRTS_IFLOW',0x00020000)
CDTR_IFLOW = Constant('CDTR_IFLOW',0x00040000)
CDSR_OFLOW = Constant('CDSR_OFLOW',0x00080000)
CCAR_OFLOW = Constant('CCAR_OFLOW',0x00100000)
ECHOKE = Constant('ECHOKE',0x00000001)
ECHOE = Constant('ECHOE',0x00000002)
ECHOK = Constant('ECHOK',0x00000004)
ECHONL = Constant('ECHONL',0x00000010)
ECHOPRT = Constant('ECHOPRT',0x00000020)
ECHOCTL = Constant('ECHOCTL',0x00000040)
ISIG = Constant('ISIG',0x00000080)
ICANON = Constant('ICANON',0x00000100)
ALTWERASE = Constant('ALTWERASE',0x00000200)
IEXTEN = Constant('IEXTEN',0x00000400)
EXTPROC = Constant('EXTPROC',0x00000800)
NOKERNINFO = Constant('NOKERNINFO',0x02000000)
TCSANOW = Constant('TCSANOW',0)
TCSADRAIN = Constant('TCSADRAIN',1)
TCSAFLUSH = Constant('TCSAFLUSH',2)
TCSASOFT = Constant('TCSASOFT',0x10)
B0 = Constant('B0',0)
B50 = Constant('B50',50)
B75 = Constant('B75',75)
B110 = Constant('B110',110)
B134 = Constant('B134',134)
B150 = Constant('B150',150)
B200 = Constant('B200',200)
B300 = Constant('B300',300)
B600 = Constant('B600',600)
B1200 = Constant('B1200',1200)
B1800 = Constant('B1800',1800)
B2400 = Constant('B2400',2400)
B4800 = Constant('B4800',4800)
B9600 = Constant('B9600',9600)
B19200 = Constant('B19200',19200)
B38400 = Constant('B38400',38400)
B7200 = Constant('B7200',7200)
B14400 = Constant('B14400',14400)
B28800 = Constant('B28800',28800)
B57600 = Constant('B57600',57600)
B76800 = Constant('B76800',76800)
B115200 = Constant('B115200',115200)
B230400 = Constant('B230400',230400)
EXTA = Constant('EXTA',19200)
EXTB = Constant('EXTB',38400)
RENAME_SECLUDE = Constant('RENAME_SECLUDE',0x00000001)
RENAME_SWAP = Constant('RENAME_SWAP',0x00000002)
RENAME_EXCL = Constant('RENAME_EXCL',0x00000004)
RENAME_RESERVED1 = Constant('RENAME_RESERVED1',0x00000008)
RENAME_NOFOLLOW_ANY = Constant('RENAME_NOFOLLOW_ANY',0x00000010)
MFSNAMELEN = Constant('MFSNAMELEN',15)
MFSTYPENAMELEN = Constant('MFSTYPENAMELEN',16)
MNAMELEN = Constant('MNAMELEN',90)
MNT_EXT_ROOT_DATA_VOL = Constant('MNT_EXT_ROOT_DATA_VOL',0x00000001)
MNT_EXT_FSKIT = Constant('MNT_EXT_FSKIT',0x00000002)
MNT_RDONLY = Constant('MNT_RDONLY',0x00000001)
MNT_SYNCHRONOUS = Constant('MNT_SYNCHRONOUS',0x00000002)
MNT_NOEXEC = Constant('MNT_NOEXEC',0x00000004)
MNT_NOSUID = Constant('MNT_NOSUID',0x00000008)
MNT_NODEV = Constant('MNT_NODEV',0x00000010)
MNT_UNION = Constant('MNT_UNION',0x00000020)
MNT_ASYNC = Constant('MNT_ASYNC',0x00000040)
MNT_CPROTECT = Constant('MNT_CPROTECT',0x00000080)
MNT_EXPORTED = Constant('MNT_EXPORTED',0x00000100)
MNT_REMOVABLE = Constant('MNT_REMOVABLE',0x00000200)
MNT_QUARANTINE = Constant('MNT_QUARANTINE',0x00000400)
MNT_LOCAL = Constant('MNT_LOCAL',0x00001000)
MNT_QUOTA = Constant('MNT_QUOTA',0x00002000)
MNT_ROOTFS = Constant('MNT_ROOTFS',0x00004000)
MNT_DOVOLFS = Constant('MNT_DOVOLFS',0x00008000)
MNT_DONTBROWSE = Constant('MNT_DONTBROWSE',0x00100000)
MNT_IGNORE_OWNERSHIP = Constant('MNT_IGNORE_OWNERSHIP',0x00200000)
MNT_AUTOMOUNTED = Constant('MNT_AUTOMOUNTED',0x00400000)
MNT_JOURNALED = Constant('MNT_JOURNALED',0x00800000)
MNT_NOUSERXATTR = Constant('MNT_NOUSERXATTR',0x01000000)
MNT_DEFWRITE = Constant('MNT_DEFWRITE',0x02000000)
MNT_MULTILABEL = Constant('MNT_MULTILABEL',0x04000000)
MNT_NOFOLLOW = Constant('MNT_NOFOLLOW',0x08000000)
MNT_NOATIME = Constant('MNT_NOATIME',0x10000000)
MNT_SNAPSHOT = Constant('MNT_SNAPSHOT',0x40000000)
MNT_STRICTATIME = Constant('MNT_STRICTATIME',0x80000000)
MNT_UPDATE = Constant('MNT_UPDATE',0x00010000)
MNT_NOBLOCK = Constant('MNT_NOBLOCK',0x00020000)
MNT_RELOAD = Constant('MNT_RELOAD',0x00040000)
MNT_FORCE = Constant('MNT_FORCE',0x00080000)
VFS_GENERIC = Constant('VFS_GENERIC',0)
VFS_NUMMNTOPS = Constant('VFS_NUMMNTOPS',1)
VFS_MAXTYPENUM = Constant('VFS_MAXTYPENUM',1)
VFS_CONF = Constant('VFS_CONF',2)
MNT_WAIT = Constant('MNT_WAIT',1)
MNT_NOWAIT = Constant('MNT_NOWAIT',2)
MNT_DWAIT = Constant('MNT_DWAIT',4)
MNT_VOLUME = Constant('MNT_VOLUME',8)
VFS_CTL_VERS1 = Constant('VFS_CTL_VERS1',0x01)
VFS_CTL_OSTATFS = Constant('VFS_CTL_OSTATFS',0x00010001)
VFS_CTL_UMOUNT = Constant('VFS_CTL_UMOUNT',0x00010002)
VFS_CTL_QUERY = Constant('VFS_CTL_QUERY',0x00010003)
VFS_CTL_NEWADDR = Constant('VFS_CTL_NEWADDR',0x00010004)
VFS_CTL_TIMEO = Constant('VFS_CTL_TIMEO',0x00010005)
VFS_CTL_NOLOCKS = Constant('VFS_CTL_NOLOCKS',0x00010006)
VFS_CTL_SADDR = Constant('VFS_CTL_SADDR',0x00010007)
VFS_CTL_DISC = Constant('VFS_CTL_DISC',0x00010008)
VFS_CTL_SERVERINFO = Constant('VFS_CTL_SERVERINFO',0x00010009)
VFS_CTL_NSTATUS = Constant('VFS_CTL_NSTATUS',0x0001000A)
VFS_CTL_STATFS64 = Constant('VFS_CTL_STATFS64',0x0001000B)
VQ_NOTRESP = Constant('VQ_NOTRESP',0x0001)
VQ_NEEDAUTH = Constant('VQ_NEEDAUTH',0x0002)
VQ_LOWDISK = Constant('VQ_LOWDISK',0x0004)
VQ_MOUNT = Constant('VQ_MOUNT',0x0008)
VQ_UNMOUNT = Constant('VQ_UNMOUNT',0x0010)
VQ_DEAD = Constant('VQ_DEAD',0x0020)
VQ_ASSIST = Constant('VQ_ASSIST',0x0040)
VQ_NOTRESPLOCK = Constant('VQ_NOTRESPLOCK',0x0080)
VQ_UPDATE = Constant('VQ_UPDATE',0x0100)
VQ_VERYLOWDISK = Constant('VQ_VERYLOWDISK',0x0200)
VQ_SYNCEVENT = Constant('VQ_SYNCEVENT',0x0400)
VQ_SERVEREVENT = Constant('VQ_SERVEREVENT',0x0800)
VQ_QUOTA = Constant('VQ_QUOTA',0x1000)
VQ_NEARLOWDISK = Constant('VQ_NEARLOWDISK',0x2000)
VQ_DESIRED_DISK = Constant('VQ_DESIRED_DISK',0x4000)
VQ_FREE_SPACE_CHANGE = Constant('VQ_FREE_SPACE_CHANGE',0x8000)
VQ_PURGEABLE_SPACE_CHANGE = Constant('VQ_PURGEABLE_SPACE_CHANGE',0x10000)
VQ_FLAG20000 = Constant('VQ_FLAG20000',0x20000)
VFS_IOATTR_FLAGS_FUA = Constant('VFS_IOATTR_FLAGS_FUA',0x00000001)
VFS_IOATTR_FLAGS_UNMAP = Constant('VFS_IOATTR_FLAGS_UNMAP',0x00000002)
VFS_IOATTR_FLAGS_SWAPPIN_SUPPORTED = Constant('VFS_IOATTR_FLAGS_SWAPPIN_SUPPORTED',0x00000010)
VFS_TBLTHREADSAFE = Constant('VFS_TBLTHREADSAFE',0x0001)
VFS_TBLFSNODELOCK = Constant('VFS_TBLFSNODELOCK',0x0002)
VFS_TBLNOTYPENUM = Constant('VFS_TBLNOTYPENUM',0x0008)
VFS_TBLLOCALVOL = Constant('VFS_TBLLOCALVOL',0x0010)
VFS_TBL64BITREADY = Constant('VFS_TBL64BITREADY',0x0020)
VFS_TBLNATIVEXATTR = Constant('VFS_TBLNATIVEXATTR',0x0040)
VFS_TBLDIRLINKS = Constant('VFS_TBLDIRLINKS',0x0080)
VFS_TBLUNMOUNT_PREFLIGHT = Constant('VFS_TBLUNMOUNT_PREFLIGHT',0x0100)
VFS_TBLGENERICMNTARGS = Constant('VFS_TBLGENERICMNTARGS',0x0200)
VFS_TBLREADDIR_EXTENDED = Constant('VFS_TBLREADDIR_EXTENDED',0x0400)
VFS_TBLNOMACLABEL = Constant('VFS_TBLNOMACLABEL',0x1000)
VFS_TBLVNOP_PAGEINV2 = Constant('VFS_TBLVNOP_PAGEINV2',0x2000)
VFS_TBLVNOP_PAGEOUTV2 = Constant('VFS_TBLVNOP_PAGEOUTV2',0x4000)
VFS_TBLVNOP_NOUPDATEID_RENAME = Constant('VFS_TBLVNOP_NOUPDATEID_RENAME',0x8000)
VFS_TBLVNOP_SECLUDE_RENAME = Constant('VFS_TBLVNOP_SECLUDE_RENAME',0x10000)
VFS_TBLCANMOUNTROOT = Constant('VFS_TBLCANMOUNTROOT',0x20000)
VFSIOC_MOUNT_BYROLE_has_recovery = Constant('VFSIOC_MOUNT_BYROLE_has_recovery',1)
VFS_RETURNED = Constant('VFS_RETURNED',0)
VFS_RETURNED_DONE = Constant('VFS_RETURNED_DONE',1)
VFS_CLAIMED = Constant('VFS_CLAIMED',2)
VFS_CLAIMED_DONE = Constant('VFS_CLAIMED_DONE',3)
VFS_USER_EVENT = Constant('VFS_USER_EVENT',0)
VFS_KERNEL_EVENT = Constant('VFS_KERNEL_EVENT',1)
LK_NOWAIT = Constant('LK_NOWAIT',1)
NFSV4_MAX_FH_SIZE = Constant('NFSV4_MAX_FH_SIZE',128)
NFSV3_MAX_FH_SIZE = Constant('NFSV3_MAX_FH_SIZE',64)
NFSV2_MAX_FH_SIZE = Constant('NFSV2_MAX_FH_SIZE',32)
CRYPTEX_AUTH_STRUCT_VERSION = Constant('CRYPTEX_AUTH_STRUCT_VERSION',2)
EV_FD = Constant('EV_FD',1)
EV_RE = Constant('EV_RE',1)
EV_WR = Constant('EV_WR',2)
EV_EX = Constant('EV_EX',4)
EV_RM = Constant('EV_RM',8)
EV_MASK = Constant('EV_MASK',0xf)
EV_RBYTES = Constant('EV_RBYTES',0x100)
EV_WBYTES = Constant('EV_WBYTES',0x200)
EV_RCLOSED = Constant('EV_RCLOSED',0x400)
EV_RCONN = Constant('EV_RCONN',0x800)
EV_WCLOSED = Constant('EV_WCLOSED',0x1000)
EV_WCONN = Constant('EV_WCONN',0x2000)
EV_OOB = Constant('EV_OOB',0x4000)
EV_FIN = Constant('EV_FIN',0x8000)
EV_RESET = Constant('EV_RESET',0x10000)
EV_TIMEOUT = Constant('EV_TIMEOUT',0x20000)
EV_DMASK = Constant('EV_DMASK',0xffffff00)
KDEBUG_LEVEL_NONE = Constant('KDEBUG_LEVEL_NONE',0)
KDEBUG_LEVEL_IST = Constant('KDEBUG_LEVEL_IST',1)
KDEBUG_LEVEL_STANDARD = Constant('KDEBUG_LEVEL_STANDARD',2)
KDEBUG_LEVEL_FULL = Constant('KDEBUG_LEVEL_FULL',3)
KDBG_FLAG_FILTERED = Constant('KDBG_FLAG_FILTERED',0x01)
KDBG_FLAG_NOPROCFILT = Constant('KDBG_FLAG_NOPROCFILT',0x02)
__DARWIN_LITTLE_ENDIAN = Constant('__DARWIN_LITTLE_ENDIAN',1234)
__DARWIN_BIG_ENDIAN = Constant('__DARWIN_BIG_ENDIAN',4321)
__DARWIN_PDP_ENDIAN = Constant('__DARWIN_PDP_ENDIAN',3412)
USE_CLANG_TYPES = Constant('USE_CLANG_TYPES',0)
__DARWIN_NULL = Constant('__DARWIN_NULL',0)
UBC_PUSHDIRTY = Constant('UBC_PUSHDIRTY',0x01)
UBC_PUSHALL = Constant('UBC_PUSHALL',0x02)
UBC_INVALIDATE = Constant('UBC_INVALIDATE',0x04)
UBC_SYNC = Constant('UBC_SYNC',0x08)
KAUTH_NTSID_MAX_AUTHORITIES = Constant('KAUTH_NTSID_MAX_AUTHORITIES',16)
KAUTH_EXTLOOKUP_SUCCESS = Constant('KAUTH_EXTLOOKUP_SUCCESS',0)
KAUTH_EXTLOOKUP_BADRQ = Constant('KAUTH_EXTLOOKUP_BADRQ',1)
KAUTH_EXTLOOKUP_FAILURE = Constant('KAUTH_EXTLOOKUP_FAILURE',2)
KAUTH_EXTLOOKUP_FATAL = Constant('KAUTH_EXTLOOKUP_FATAL',3)
KAUTH_EXTLOOKUP_INPROG = Constant('KAUTH_EXTLOOKUP_INPROG',100)
KAUTH_ACE_KINDMASK = Constant('KAUTH_ACE_KINDMASK',0xf)
KAUTH_ACE_PERMIT = Constant('KAUTH_ACE_PERMIT',1)
KAUTH_ACE_DENY = Constant('KAUTH_ACE_DENY',2)
KAUTH_ACE_AUDIT = Constant('KAUTH_ACE_AUDIT',3)
KAUTH_ACE_ALARM = Constant('KAUTH_ACE_ALARM',4)
KAUTH_ACL_MAX_ENTRIES = Constant('KAUTH_ACL_MAX_ENTRIES',128)
KAUTH_FILESEC_MAGIC = Constant('KAUTH_FILESEC_MAGIC',0x012cc16d)
KAUTH_ENDIAN_HOST = Constant('KAUTH_ENDIAN_HOST',0x00000001)
KAUTH_ENDIAN_DISK = Constant('KAUTH_ENDIAN_DISK',0x00000002)
KAUTH_GENERIC_ISSUSER = Constant('KAUTH_GENERIC_ISSUSER',1)
KAUTH_PROCESS_CANSIGNAL = Constant('KAUTH_PROCESS_CANSIGNAL',1)
KAUTH_PROCESS_CANTRACE = Constant('KAUTH_PROCESS_CANTRACE',2)
KAUTH_FILEOP_OPEN = Constant('KAUTH_FILEOP_OPEN',1)
KAUTH_FILEOP_CLOSE = Constant('KAUTH_FILEOP_CLOSE',2)
KAUTH_FILEOP_RENAME = Constant('KAUTH_FILEOP_RENAME',3)
KAUTH_FILEOP_EXCHANGE = Constant('KAUTH_FILEOP_EXCHANGE',4)
KAUTH_FILEOP_LINK = Constant('KAUTH_FILEOP_LINK',5)
KAUTH_FILEOP_EXEC = Constant('KAUTH_FILEOP_EXEC',6)
KAUTH_FILEOP_DELETE = Constant('KAUTH_FILEOP_DELETE',7)
KAUTH_FILEOP_WILL_RENAME = Constant('KAUTH_FILEOP_WILL_RENAME',8)
DBG_PPT = Constant('DBG_PPT',36)
DBG_PERFCTRL = Constant('DBG_PERFCTRL',39)
DBG_CLPC = Constant('DBG_CLPC',50)
DBG_MUSE = Constant('DBG_MUSE',52)
DBG_ANS = Constant('DBG_ANS',128)
DBG_SIO = Constant('DBG_SIO',129)
DBG_SEP = Constant('DBG_SEP',130)
DBG_ISP = Constant('DBG_ISP',131)
DBG_OSCAR = Constant('DBG_OSCAR',132)
DBG_EMBEDDEDGFX = Constant('DBG_EMBEDDEDGFX',133)
DBG_PMP = Constant('DBG_PMP',134)
DBG_RTKIT = Constant('DBG_RTKIT',135)
DBG_DCP = Constant('DBG_DCP',136)
DBG_KMP = Constant('DBG_KMP',137)
DBG_SKYWALK_ALWAYSON = Constant('DBG_SKYWALK_ALWAYSON',0x10)
DBG_SKYWALK_FLOWSWITCH = Constant('DBG_SKYWALK_FLOWSWITCH',0x11)
DBG_SKYWALK_NETIF = Constant('DBG_SKYWALK_NETIF',0x12)
DBG_SKYWALK_CHANNEL = Constant('DBG_SKYWALK_CHANNEL',0x13)
DBG_SKYWALK_PACKET = Constant('DBG_SKYWALK_PACKET',0x14)
DBG_AQM_ALWAYSON = Constant('DBG_AQM_ALWAYSON',0x30)
DBG_AQM_STATS = Constant('DBG_AQM_STATS',0x31)
PPT_TEST = Constant('PPT_TEST',0x01)
PPT_JETSAM_HIWAT = Constant('PPT_JETSAM_HIWAT',0x02)
PPT_JETSAM_TOPPROC = Constant('PPT_JETSAM_TOPPROC',0x03)
DBG_SEC_SSMA = Constant('DBG_SEC_SSMA',0x02)
KDBG_CPU_SHIFT = Constant('KDBG_CPU_SHIFT',56)
KDBG_INIT = Constant('KDBG_INIT',0x01)
KDBG_FREERUN = Constant('KDBG_FREERUN',0x04)
KDBG_CPUMAP_IS_IOP = Constant('KDBG_CPUMAP_IS_IOP',0x1)
KDEBUG_COMMPAGE_ENABLE_TRACE = Constant('KDEBUG_COMMPAGE_ENABLE_TRACE',0x1)
KDEBUG_COMMPAGE_ENABLE_TYPEFILTER = Constant('KDEBUG_COMMPAGE_ENABLE_TYPEFILTER',0x2)
KDEBUG_COMMPAGE_CONTINUOUS = Constant('KDEBUG_COMMPAGE_CONTINUOUS',0x4)
KDBG_LOCKINIT = Constant('KDBG_LOCKINIT',0x0080)
KDBG_CLASSTYPE = Constant('KDBG_CLASSTYPE',0x10000)
KDBG_SUBCLSTYPE = Constant('KDBG_SUBCLSTYPE',0x20000)
KDBG_RANGETYPE = Constant('KDBG_RANGETYPE',0x40000)
KDBG_TYPENONE = Constant('KDBG_TYPENONE',0x80000)
KDBG_CKTYPES = Constant('KDBG_CKTYPES',0xF0000)
RAW_VERSION0 = Constant('RAW_VERSION0',0x55aa0000)
RAW_VERSION1 = Constant('RAW_VERSION1',0x55aa0101)
RAW_VERSION2 = Constant('RAW_VERSION2',0x55aa0200)
kEnTrCompKernel = Constant('kEnTrCompKernel',2)
kEnTrActKernSocket = Constant('kEnTrActKernSocket',1)
kEnTrActKernSockRead = Constant('kEnTrActKernSockRead',2)
kEnTrActKernSockWrite = Constant('kEnTrActKernSockWrite',3)
kEnTrActKernPoll = Constant('kEnTrActKernPoll',10)
kEnTrActKernSelect = Constant('kEnTrActKernSelect',11)
kEnTrActKernKQWait = Constant('kEnTrActKernKQWait',12)
kEnTrEvUnblocked = Constant('kEnTrEvUnblocked',256)
kEnTrFlagNonBlocking = Constant('kEnTrFlagNonBlocking',0x1)
kEnTrFlagNoWork = Constant('kEnTrFlagNoWork',0x2)
ENTR_SHOULDTRACE = Constant('ENTR_SHOULDTRACE',0)
SYS_syscall = Constant('SYS_syscall',0)
SYS_exit = Constant('SYS_exit',1)
SYS_fork = Constant('SYS_fork',2)
SYS_read = Constant('SYS_read',3)
SYS_write = Constant('SYS_write',4)
SYS_open = Constant('SYS_open',5)
SYS_close = Constant('SYS_close',6)
SYS_wait4 = Constant('SYS_wait4',7)
SYS_link = Constant('SYS_link',9)
SYS_unlink = Constant('SYS_unlink',10)
SYS_chdir = Constant('SYS_chdir',12)
SYS_fchdir = Constant('SYS_fchdir',13)
SYS_mknod = Constant('SYS_mknod',14)
SYS_chmod = Constant('SYS_chmod',15)
SYS_chown = Constant('SYS_chown',16)
SYS_getfsstat = Constant('SYS_getfsstat',18)
SYS_getpid = Constant('SYS_getpid',20)
SYS_setuid = Constant('SYS_setuid',23)
SYS_getuid = Constant('SYS_getuid',24)
SYS_geteuid = Constant('SYS_geteuid',25)
SYS_ptrace = Constant('SYS_ptrace',26)
SYS_recvmsg = Constant('SYS_recvmsg',27)
SYS_sendmsg = Constant('SYS_sendmsg',28)
SYS_recvfrom = Constant('SYS_recvfrom',29)
SYS_accept = Constant('SYS_accept',30)
SYS_getpeername = Constant('SYS_getpeername',31)
SYS_getsockname = Constant('SYS_getsockname',32)
SYS_access = Constant('SYS_access',33)
SYS_chflags = Constant('SYS_chflags',34)
SYS_fchflags = Constant('SYS_fchflags',35)
SYS_sync = Constant('SYS_sync',36)
SYS_kill = Constant('SYS_kill',37)
SYS_crossarch_trap = Constant('SYS_crossarch_trap',38)
SYS_getppid = Constant('SYS_getppid',39)
SYS_dup = Constant('SYS_dup',41)
SYS_pipe = Constant('SYS_pipe',42)
SYS_getegid = Constant('SYS_getegid',43)
SYS_sigaction = Constant('SYS_sigaction',46)
SYS_getgid = Constant('SYS_getgid',47)
SYS_sigprocmask = Constant('SYS_sigprocmask',48)
SYS_getlogin = Constant('SYS_getlogin',49)
SYS_setlogin = Constant('SYS_setlogin',50)
SYS_acct = Constant('SYS_acct',51)
SYS_sigpending = Constant('SYS_sigpending',52)
SYS_sigaltstack = Constant('SYS_sigaltstack',53)
SYS_ioctl = Constant('SYS_ioctl',54)
SYS_reboot = Constant('SYS_reboot',55)
SYS_revoke = Constant('SYS_revoke',56)
SYS_symlink = Constant('SYS_symlink',57)
SYS_readlink = Constant('SYS_readlink',58)
SYS_execve = Constant('SYS_execve',59)
SYS_umask = Constant('SYS_umask',60)
SYS_chroot = Constant('SYS_chroot',61)
SYS_msync = Constant('SYS_msync',65)
SYS_vfork = Constant('SYS_vfork',66)
SYS_munmap = Constant('SYS_munmap',73)
SYS_mprotect = Constant('SYS_mprotect',74)
SYS_madvise = Constant('SYS_madvise',75)
SYS_mincore = Constant('SYS_mincore',78)
SYS_getgroups = Constant('SYS_getgroups',79)
SYS_setgroups = Constant('SYS_setgroups',80)
SYS_getpgrp = Constant('SYS_getpgrp',81)
SYS_setpgid = Constant('SYS_setpgid',82)
SYS_setitimer = Constant('SYS_setitimer',83)
SYS_swapon = Constant('SYS_swapon',85)
SYS_getitimer = Constant('SYS_getitimer',86)
SYS_getdtablesize = Constant('SYS_getdtablesize',89)
SYS_dup2 = Constant('SYS_dup2',90)
SYS_fcntl = Constant('SYS_fcntl',92)
SYS_select = Constant('SYS_select',93)
SYS_fsync = Constant('SYS_fsync',95)
SYS_setpriority = Constant('SYS_setpriority',96)
SYS_socket = Constant('SYS_socket',97)
SYS_connect = Constant('SYS_connect',98)
SYS_getpriority = Constant('SYS_getpriority',100)
SYS_bind = Constant('SYS_bind',104)
SYS_setsockopt = Constant('SYS_setsockopt',105)
SYS_listen = Constant('SYS_listen',106)
SYS_sigsuspend = Constant('SYS_sigsuspend',111)
SYS_gettimeofday = Constant('SYS_gettimeofday',116)
SYS_getrusage = Constant('SYS_getrusage',117)
SYS_getsockopt = Constant('SYS_getsockopt',118)
SYS_readv = Constant('SYS_readv',120)
SYS_writev = Constant('SYS_writev',121)
SYS_settimeofday = Constant('SYS_settimeofday',122)
SYS_fchown = Constant('SYS_fchown',123)
SYS_fchmod = Constant('SYS_fchmod',124)
SYS_setreuid = Constant('SYS_setreuid',126)
SYS_setregid = Constant('SYS_setregid',127)
SYS_rename = Constant('SYS_rename',128)
SYS_flock = Constant('SYS_flock',131)
SYS_mkfifo = Constant('SYS_mkfifo',132)
SYS_sendto = Constant('SYS_sendto',133)
SYS_shutdown = Constant('SYS_shutdown',134)
SYS_socketpair = Constant('SYS_socketpair',135)
SYS_mkdir = Constant('SYS_mkdir',136)
SYS_rmdir = Constant('SYS_rmdir',137)
SYS_utimes = Constant('SYS_utimes',138)
SYS_futimes = Constant('SYS_futimes',139)
SYS_adjtime = Constant('SYS_adjtime',140)
SYS_gethostuuid = Constant('SYS_gethostuuid',142)
SYS_setsid = Constant('SYS_setsid',147)
SYS_getpgid = Constant('SYS_getpgid',151)
SYS_setprivexec = Constant('SYS_setprivexec',152)
SYS_pread = Constant('SYS_pread',153)
SYS_pwrite = Constant('SYS_pwrite',154)
SYS_nfssvc = Constant('SYS_nfssvc',155)
SYS_statfs = Constant('SYS_statfs',157)
SYS_fstatfs = Constant('SYS_fstatfs',158)
SYS_unmount = Constant('SYS_unmount',159)
SYS_getfh = Constant('SYS_getfh',161)
SYS_quotactl = Constant('SYS_quotactl',165)
SYS_mount = Constant('SYS_mount',167)
SYS_csops = Constant('SYS_csops',169)
SYS_csops_audittoken = Constant('SYS_csops_audittoken',170)
SYS_waitid = Constant('SYS_waitid',173)
SYS_kdebug_typefilter = Constant('SYS_kdebug_typefilter',177)
SYS_kdebug_trace_string = Constant('SYS_kdebug_trace_string',178)
SYS_kdebug_trace64 = Constant('SYS_kdebug_trace64',179)
SYS_kdebug_trace = Constant('SYS_kdebug_trace',180)
SYS_setgid = Constant('SYS_setgid',181)
SYS_setegid = Constant('SYS_setegid',182)
SYS_seteuid = Constant('SYS_seteuid',183)
SYS_sigreturn = Constant('SYS_sigreturn',184)
SYS_panic_with_data = Constant('SYS_panic_with_data',185)
SYS_thread_selfcounts = Constant('SYS_thread_selfcounts',186)
SYS_fdatasync = Constant('SYS_fdatasync',187)
SYS_stat = Constant('SYS_stat',188)
SYS_fstat = Constant('SYS_fstat',189)
SYS_lstat = Constant('SYS_lstat',190)
SYS_pathconf = Constant('SYS_pathconf',191)
SYS_fpathconf = Constant('SYS_fpathconf',192)
SYS_getrlimit = Constant('SYS_getrlimit',194)
SYS_setrlimit = Constant('SYS_setrlimit',195)
SYS_getdirentries = Constant('SYS_getdirentries',196)
SYS_mmap = Constant('SYS_mmap',197)
SYS_lseek = Constant('SYS_lseek',199)
SYS_truncate = Constant('SYS_truncate',200)
SYS_ftruncate = Constant('SYS_ftruncate',201)
SYS_sysctl = Constant('SYS_sysctl',202)
SYS_mlock = Constant('SYS_mlock',203)
SYS_munlock = Constant('SYS_munlock',204)
SYS_undelete = Constant('SYS_undelete',205)
SYS_open_dprotected_np = Constant('SYS_open_dprotected_np',216)
SYS_fsgetpath_ext = Constant('SYS_fsgetpath_ext',217)
SYS_openat_dprotected_np = Constant('SYS_openat_dprotected_np',218)
SYS_getattrlist = Constant('SYS_getattrlist',220)
SYS_setattrlist = Constant('SYS_setattrlist',221)
SYS_getdirentriesattr = Constant('SYS_getdirentriesattr',222)
SYS_exchangedata = Constant('SYS_exchangedata',223)
SYS_searchfs = Constant('SYS_searchfs',225)
SYS_delete = Constant('SYS_delete',226)
SYS_copyfile = Constant('SYS_copyfile',227)
SYS_fgetattrlist = Constant('SYS_fgetattrlist',228)
SYS_fsetattrlist = Constant('SYS_fsetattrlist',229)
SYS_poll = Constant('SYS_poll',230)
SYS_getxattr = Constant('SYS_getxattr',234)
SYS_fgetxattr = Constant('SYS_fgetxattr',235)
SYS_setxattr = Constant('SYS_setxattr',236)
SYS_fsetxattr = Constant('SYS_fsetxattr',237)
SYS_removexattr = Constant('SYS_removexattr',238)
SYS_fremovexattr = Constant('SYS_fremovexattr',239)
SYS_listxattr = Constant('SYS_listxattr',240)
SYS_flistxattr = Constant('SYS_flistxattr',241)
SYS_fsctl = Constant('SYS_fsctl',242)
SYS_initgroups = Constant('SYS_initgroups',243)
SYS_posix_spawn = Constant('SYS_posix_spawn',244)
SYS_ffsctl = Constant('SYS_ffsctl',245)
SYS_fhopen = Constant('SYS_fhopen',248)
SYS_minherit = Constant('SYS_minherit',250)
SYS_semsys = Constant('SYS_semsys',251)
SYS_msgsys = Constant('SYS_msgsys',252)
SYS_shmsys = Constant('SYS_shmsys',253)
SYS_semctl = Constant('SYS_semctl',254)
SYS_semget = Constant('SYS_semget',255)
SYS_semop = Constant('SYS_semop',256)
SYS_msgctl = Constant('SYS_msgctl',258)
SYS_msgget = Constant('SYS_msgget',259)
SYS_msgsnd = Constant('SYS_msgsnd',260)
SYS_msgrcv = Constant('SYS_msgrcv',261)
SYS_shmat = Constant('SYS_shmat',262)
SYS_shmctl = Constant('SYS_shmctl',263)
SYS_shmdt = Constant('SYS_shmdt',264)
SYS_shmget = Constant('SYS_shmget',265)
SYS_shm_open = Constant('SYS_shm_open',266)
SYS_shm_unlink = Constant('SYS_shm_unlink',267)
SYS_sem_open = Constant('SYS_sem_open',268)
SYS_sem_close = Constant('SYS_sem_close',269)
SYS_sem_unlink = Constant('SYS_sem_unlink',270)
SYS_sem_wait = Constant('SYS_sem_wait',271)
SYS_sem_trywait = Constant('SYS_sem_trywait',272)
SYS_sem_post = Constant('SYS_sem_post',273)
SYS_sysctlbyname = Constant('SYS_sysctlbyname',274)
SYS_open_extended = Constant('SYS_open_extended',277)
SYS_umask_extended = Constant('SYS_umask_extended',278)
SYS_stat_extended = Constant('SYS_stat_extended',279)
SYS_lstat_extended = Constant('SYS_lstat_extended',280)
SYS_fstat_extended = Constant('SYS_fstat_extended',281)
SYS_chmod_extended = Constant('SYS_chmod_extended',282)
SYS_fchmod_extended = Constant('SYS_fchmod_extended',283)
SYS_access_extended = Constant('SYS_access_extended',284)
SYS_settid = Constant('SYS_settid',285)
SYS_gettid = Constant('SYS_gettid',286)
SYS_setsgroups = Constant('SYS_setsgroups',287)
SYS_getsgroups = Constant('SYS_getsgroups',288)
SYS_setwgroups = Constant('SYS_setwgroups',289)
SYS_getwgroups = Constant('SYS_getwgroups',290)
SYS_mkfifo_extended = Constant('SYS_mkfifo_extended',291)
SYS_mkdir_extended = Constant('SYS_mkdir_extended',292)
SYS_identitysvc = Constant('SYS_identitysvc',293)
SYS_shared_region_check_np = Constant('SYS_shared_region_check_np',294)
SYS_vm_pressure_monitor = Constant('SYS_vm_pressure_monitor',296)
SYS_psynch_rw_longrdlock = Constant('SYS_psynch_rw_longrdlock',297)
SYS_psynch_rw_yieldwrlock = Constant('SYS_psynch_rw_yieldwrlock',298)
SYS_psynch_rw_downgrade = Constant('SYS_psynch_rw_downgrade',299)
SYS_psynch_rw_upgrade = Constant('SYS_psynch_rw_upgrade',300)
SYS_psynch_mutexwait = Constant('SYS_psynch_mutexwait',301)
SYS_psynch_mutexdrop = Constant('SYS_psynch_mutexdrop',302)
SYS_psynch_cvbroad = Constant('SYS_psynch_cvbroad',303)
SYS_psynch_cvsignal = Constant('SYS_psynch_cvsignal',304)
SYS_psynch_cvwait = Constant('SYS_psynch_cvwait',305)
SYS_psynch_rw_rdlock = Constant('SYS_psynch_rw_rdlock',306)
SYS_psynch_rw_wrlock = Constant('SYS_psynch_rw_wrlock',307)
SYS_psynch_rw_unlock = Constant('SYS_psynch_rw_unlock',308)
SYS_psynch_rw_unlock2 = Constant('SYS_psynch_rw_unlock2',309)
SYS_getsid = Constant('SYS_getsid',310)
SYS_settid_with_pid = Constant('SYS_settid_with_pid',311)
SYS_psynch_cvclrprepost = Constant('SYS_psynch_cvclrprepost',312)
SYS_aio_fsync = Constant('SYS_aio_fsync',313)
SYS_aio_return = Constant('SYS_aio_return',314)
SYS_aio_suspend = Constant('SYS_aio_suspend',315)
SYS_aio_cancel = Constant('SYS_aio_cancel',316)
SYS_aio_error = Constant('SYS_aio_error',317)
SYS_aio_read = Constant('SYS_aio_read',318)
SYS_aio_write = Constant('SYS_aio_write',319)
SYS_lio_listio = Constant('SYS_lio_listio',320)
SYS_iopolicysys = Constant('SYS_iopolicysys',322)
SYS_process_policy = Constant('SYS_process_policy',323)
SYS_mlockall = Constant('SYS_mlockall',324)
SYS_munlockall = Constant('SYS_munlockall',325)
SYS_issetugid = Constant('SYS_issetugid',327)
SYS___pthread_kill = Constant('SYS___pthread_kill',328)
SYS___pthread_sigmask = Constant('SYS___pthread_sigmask',329)
SYS___sigwait = Constant('SYS___sigwait',330)
SYS___disable_threadsignal = Constant('SYS___disable_threadsignal',331)
SYS___pthread_markcancel = Constant('SYS___pthread_markcancel',332)
SYS___pthread_canceled = Constant('SYS___pthread_canceled',333)
SYS___semwait_signal = Constant('SYS___semwait_signal',334)
SYS_proc_info = Constant('SYS_proc_info',336)
SYS_sendfile = Constant('SYS_sendfile',337)
SYS_stat64 = Constant('SYS_stat64',338)
SYS_fstat64 = Constant('SYS_fstat64',339)
SYS_lstat64 = Constant('SYS_lstat64',340)
SYS_stat64_extended = Constant('SYS_stat64_extended',341)
SYS_lstat64_extended = Constant('SYS_lstat64_extended',342)
SYS_fstat64_extended = Constant('SYS_fstat64_extended',343)
SYS_getdirentries64 = Constant('SYS_getdirentries64',344)
SYS_statfs64 = Constant('SYS_statfs64',345)
SYS_fstatfs64 = Constant('SYS_fstatfs64',346)
SYS_getfsstat64 = Constant('SYS_getfsstat64',347)
SYS___pthread_chdir = Constant('SYS___pthread_chdir',348)
SYS___pthread_fchdir = Constant('SYS___pthread_fchdir',349)
SYS_audit = Constant('SYS_audit',350)
SYS_auditon = Constant('SYS_auditon',351)
SYS_getauid = Constant('SYS_getauid',353)
SYS_setauid = Constant('SYS_setauid',354)
SYS_getaudit_addr = Constant('SYS_getaudit_addr',357)
SYS_setaudit_addr = Constant('SYS_setaudit_addr',358)
SYS_auditctl = Constant('SYS_auditctl',359)
SYS_bsdthread_create = Constant('SYS_bsdthread_create',360)
SYS_bsdthread_terminate = Constant('SYS_bsdthread_terminate',361)
SYS_kqueue = Constant('SYS_kqueue',362)
SYS_kevent = Constant('SYS_kevent',363)
SYS_lchown = Constant('SYS_lchown',364)
SYS_bsdthread_register = Constant('SYS_bsdthread_register',366)
SYS_workq_open = Constant('SYS_workq_open',367)
SYS_workq_kernreturn = Constant('SYS_workq_kernreturn',368)
SYS_kevent64 = Constant('SYS_kevent64',369)
SYS_thread_selfid = Constant('SYS_thread_selfid',372)
SYS_ledger = Constant('SYS_ledger',373)
SYS_kevent_qos = Constant('SYS_kevent_qos',374)
SYS_kevent_id = Constant('SYS_kevent_id',375)
SYS___mac_execve = Constant('SYS___mac_execve',380)
SYS___mac_syscall = Constant('SYS___mac_syscall',381)
SYS___mac_get_file = Constant('SYS___mac_get_file',382)
SYS___mac_set_file = Constant('SYS___mac_set_file',383)
SYS___mac_get_link = Constant('SYS___mac_get_link',384)
SYS___mac_set_link = Constant('SYS___mac_set_link',385)
SYS___mac_get_proc = Constant('SYS___mac_get_proc',386)
SYS___mac_set_proc = Constant('SYS___mac_set_proc',387)
SYS___mac_get_fd = Constant('SYS___mac_get_fd',388)
SYS___mac_set_fd = Constant('SYS___mac_set_fd',389)
SYS___mac_get_pid = Constant('SYS___mac_get_pid',390)
SYS_pselect = Constant('SYS_pselect',394)
SYS_pselect_nocancel = Constant('SYS_pselect_nocancel',395)
SYS_read_nocancel = Constant('SYS_read_nocancel',396)
SYS_write_nocancel = Constant('SYS_write_nocancel',397)
SYS_open_nocancel = Constant('SYS_open_nocancel',398)
SYS_close_nocancel = Constant('SYS_close_nocancel',399)
SYS_wait4_nocancel = Constant('SYS_wait4_nocancel',400)
SYS_recvmsg_nocancel = Constant('SYS_recvmsg_nocancel',401)
SYS_sendmsg_nocancel = Constant('SYS_sendmsg_nocancel',402)
SYS_recvfrom_nocancel = Constant('SYS_recvfrom_nocancel',403)
SYS_accept_nocancel = Constant('SYS_accept_nocancel',404)
SYS_msync_nocancel = Constant('SYS_msync_nocancel',405)
SYS_fcntl_nocancel = Constant('SYS_fcntl_nocancel',406)
SYS_select_nocancel = Constant('SYS_select_nocancel',407)
SYS_fsync_nocancel = Constant('SYS_fsync_nocancel',408)
SYS_connect_nocancel = Constant('SYS_connect_nocancel',409)
SYS_sigsuspend_nocancel = Constant('SYS_sigsuspend_nocancel',410)
SYS_readv_nocancel = Constant('SYS_readv_nocancel',411)
SYS_writev_nocancel = Constant('SYS_writev_nocancel',412)
SYS_sendto_nocancel = Constant('SYS_sendto_nocancel',413)
SYS_pread_nocancel = Constant('SYS_pread_nocancel',414)
SYS_pwrite_nocancel = Constant('SYS_pwrite_nocancel',415)
SYS_waitid_nocancel = Constant('SYS_waitid_nocancel',416)
SYS_poll_nocancel = Constant('SYS_poll_nocancel',417)
SYS_msgsnd_nocancel = Constant('SYS_msgsnd_nocancel',418)
SYS_msgrcv_nocancel = Constant('SYS_msgrcv_nocancel',419)
SYS_sem_wait_nocancel = Constant('SYS_sem_wait_nocancel',420)
SYS_aio_suspend_nocancel = Constant('SYS_aio_suspend_nocancel',421)
SYS___sigwait_nocancel = Constant('SYS___sigwait_nocancel',422)
SYS___semwait_signal_nocancel = Constant('SYS___semwait_signal_nocancel',423)
SYS___mac_mount = Constant('SYS___mac_mount',424)
SYS___mac_get_mount = Constant('SYS___mac_get_mount',425)
SYS___mac_getfsstat = Constant('SYS___mac_getfsstat',426)
SYS_fsgetpath = Constant('SYS_fsgetpath',427)
SYS_audit_session_self = Constant('SYS_audit_session_self',428)
SYS_audit_session_join = Constant('SYS_audit_session_join',429)
SYS_fileport_makeport = Constant('SYS_fileport_makeport',430)
SYS_fileport_makefd = Constant('SYS_fileport_makefd',431)
SYS_audit_session_port = Constant('SYS_audit_session_port',432)
SYS_pid_suspend = Constant('SYS_pid_suspend',433)
SYS_pid_resume = Constant('SYS_pid_resume',434)
SYS_pid_hibernate = Constant('SYS_pid_hibernate',435)
SYS_pid_shutdown_sockets = Constant('SYS_pid_shutdown_sockets',436)
SYS_kas_info = Constant('SYS_kas_info',439)
SYS_memorystatus_control = Constant('SYS_memorystatus_control',440)
SYS_guarded_open_np = Constant('SYS_guarded_open_np',441)
SYS_guarded_close_np = Constant('SYS_guarded_close_np',442)
SYS_guarded_kqueue_np = Constant('SYS_guarded_kqueue_np',443)
SYS_change_fdguard_np = Constant('SYS_change_fdguard_np',444)
SYS_usrctl = Constant('SYS_usrctl',445)
SYS_proc_rlimit_control = Constant('SYS_proc_rlimit_control',446)
SYS_connectx = Constant('SYS_connectx',447)
SYS_disconnectx = Constant('SYS_disconnectx',448)
SYS_peeloff = Constant('SYS_peeloff',449)
SYS_socket_delegate = Constant('SYS_socket_delegate',450)
SYS_telemetry = Constant('SYS_telemetry',451)
SYS_proc_uuid_policy = Constant('SYS_proc_uuid_policy',452)
SYS_memorystatus_get_level = Constant('SYS_memorystatus_get_level',453)
SYS_system_override = Constant('SYS_system_override',454)
SYS_vfs_purge = Constant('SYS_vfs_purge',455)
SYS_sfi_ctl = Constant('SYS_sfi_ctl',456)
SYS_sfi_pidctl = Constant('SYS_sfi_pidctl',457)
SYS_coalition = Constant('SYS_coalition',458)
SYS_coalition_info = Constant('SYS_coalition_info',459)
SYS_necp_match_policy = Constant('SYS_necp_match_policy',460)
SYS_getattrlistbulk = Constant('SYS_getattrlistbulk',461)
SYS_clonefileat = Constant('SYS_clonefileat',462)
SYS_openat = Constant('SYS_openat',463)
SYS_openat_nocancel = Constant('SYS_openat_nocancel',464)
SYS_renameat = Constant('SYS_renameat',465)
SYS_faccessat = Constant('SYS_faccessat',466)
SYS_fchmodat = Constant('SYS_fchmodat',467)
SYS_fchownat = Constant('SYS_fchownat',468)
SYS_fstatat = Constant('SYS_fstatat',469)
SYS_fstatat64 = Constant('SYS_fstatat64',470)
SYS_linkat = Constant('SYS_linkat',471)
SYS_unlinkat = Constant('SYS_unlinkat',472)
SYS_readlinkat = Constant('SYS_readlinkat',473)
SYS_symlinkat = Constant('SYS_symlinkat',474)
SYS_mkdirat = Constant('SYS_mkdirat',475)
SYS_getattrlistat = Constant('SYS_getattrlistat',476)
SYS_proc_trace_log = Constant('SYS_proc_trace_log',477)
SYS_bsdthread_ctl = Constant('SYS_bsdthread_ctl',478)
SYS_openbyid_np = Constant('SYS_openbyid_np',479)
SYS_recvmsg_x = Constant('SYS_recvmsg_x',480)
SYS_sendmsg_x = Constant('SYS_sendmsg_x',481)
SYS_thread_selfusage = Constant('SYS_thread_selfusage',482)
SYS_csrctl = Constant('SYS_csrctl',483)
SYS_guarded_open_dprotected_np = Constant('SYS_guarded_open_dprotected_np',484)
SYS_guarded_write_np = Constant('SYS_guarded_write_np',485)
SYS_guarded_pwrite_np = Constant('SYS_guarded_pwrite_np',486)
SYS_guarded_writev_np = Constant('SYS_guarded_writev_np',487)
SYS_renameatx_np = Constant('SYS_renameatx_np',488)
SYS_mremap_encrypted = Constant('SYS_mremap_encrypted',489)
SYS_netagent_trigger = Constant('SYS_netagent_trigger',490)
SYS_stack_snapshot_with_config = Constant('SYS_stack_snapshot_with_config',491)
SYS_microstackshot = Constant('SYS_microstackshot',492)
SYS_grab_pgo_data = Constant('SYS_grab_pgo_data',493)
SYS_persona = Constant('SYS_persona',494)
SYS_mach_eventlink_signal = Constant('SYS_mach_eventlink_signal',496)
SYS_mach_eventlink_wait_until = Constant('SYS_mach_eventlink_wait_until',497)
SYS_mach_eventlink_signal_wait_until = Constant('SYS_mach_eventlink_signal_wait_until',498)
SYS_work_interval_ctl = Constant('SYS_work_interval_ctl',499)
SYS_getentropy = Constant('SYS_getentropy',500)
SYS_necp_open = Constant('SYS_necp_open',501)
SYS_necp_client_action = Constant('SYS_necp_client_action',502)
SYS___nexus_open = Constant('SYS___nexus_open',503)
SYS___nexus_register = Constant('SYS___nexus_register',504)
SYS___nexus_deregister = Constant('SYS___nexus_deregister',505)
SYS___nexus_create = Constant('SYS___nexus_create',506)
SYS___nexus_destroy = Constant('SYS___nexus_destroy',507)
SYS___nexus_get_opt = Constant('SYS___nexus_get_opt',508)
SYS___nexus_set_opt = Constant('SYS___nexus_set_opt',509)
SYS___channel_open = Constant('SYS___channel_open',510)
SYS___channel_get_info = Constant('SYS___channel_get_info',511)
SYS___channel_sync = Constant('SYS___channel_sync',512)
SYS___channel_get_opt = Constant('SYS___channel_get_opt',513)
SYS___channel_set_opt = Constant('SYS___channel_set_opt',514)
SYS_ulock_wait = Constant('SYS_ulock_wait',515)
SYS_ulock_wake = Constant('SYS_ulock_wake',516)
SYS_fclonefileat = Constant('SYS_fclonefileat',517)
SYS_fs_snapshot = Constant('SYS_fs_snapshot',518)
SYS_register_uexc_handler = Constant('SYS_register_uexc_handler',519)
SYS_terminate_with_payload = Constant('SYS_terminate_with_payload',520)
SYS_abort_with_payload = Constant('SYS_abort_with_payload',521)
SYS_necp_session_open = Constant('SYS_necp_session_open',522)
SYS_necp_session_action = Constant('SYS_necp_session_action',523)
SYS_setattrlistat = Constant('SYS_setattrlistat',524)
SYS_net_qos_guideline = Constant('SYS_net_qos_guideline',525)
SYS_fmount = Constant('SYS_fmount',526)
SYS_ntp_adjtime = Constant('SYS_ntp_adjtime',527)
SYS_ntp_gettime = Constant('SYS_ntp_gettime',528)
SYS_os_fault_with_payload = Constant('SYS_os_fault_with_payload',529)
SYS_kqueue_workloop_ctl = Constant('SYS_kqueue_workloop_ctl',530)
SYS___mach_bridge_remote_time = Constant('SYS___mach_bridge_remote_time',531)
SYS_coalition_ledger = Constant('SYS_coalition_ledger',532)
SYS_log_data = Constant('SYS_log_data',533)
SYS_memorystatus_available_memory = Constant('SYS_memorystatus_available_memory',534)
SYS_objc_bp_assist_cfg_np = Constant('SYS_objc_bp_assist_cfg_np',535)
SYS_shared_region_map_and_slide_2_np = Constant('SYS_shared_region_map_and_slide_2_np',536)
SYS_pivot_root = Constant('SYS_pivot_root',537)
SYS_task_inspect_for_pid = Constant('SYS_task_inspect_for_pid',538)
SYS_task_read_for_pid = Constant('SYS_task_read_for_pid',539)
SYS_preadv = Constant('SYS_preadv',540)
SYS_pwritev = Constant('SYS_pwritev',541)
SYS_preadv_nocancel = Constant('SYS_preadv_nocancel',542)
SYS_pwritev_nocancel = Constant('SYS_pwritev_nocancel',543)
SYS_ulock_wait2 = Constant('SYS_ulock_wait2',544)
SYS_proc_info_extended_id = Constant('SYS_proc_info_extended_id',545)
SYS_tracker_action = Constant('SYS_tracker_action',546)
SYS_debug_syscall_reject = Constant('SYS_debug_syscall_reject',547)
SYS_debug_syscall_reject_config = Constant('SYS_debug_syscall_reject_config',548)
SYS_graftdmg = Constant('SYS_graftdmg',549)
SYS_map_with_linking_np = Constant('SYS_map_with_linking_np',550)
SYS_freadlink = Constant('SYS_freadlink',551)
SYS_record_system_event = Constant('SYS_record_system_event',552)
SYS_mkfifoat = Constant('SYS_mkfifoat',553)
SYS_mknodat = Constant('SYS_mknodat',554)
SYS_ungraftdmg = Constant('SYS_ungraftdmg',555)
SYS_coalition_policy_set = Constant('SYS_coalition_policy_set',556)
SYS_coalition_policy_get = Constant('SYS_coalition_policy_get',557)
SYS_MAXSYSCALL = Constant('SYS_MAXSYSCALL',558)
SYS_invalid = Constant('SYS_invalid',63)
SOCK_STREAM = Constant('SOCK_STREAM',1)
SOCK_DGRAM = Constant('SOCK_DGRAM',2)
SOCK_RAW = Constant('SOCK_RAW',3)
SOCK_RDM = Constant('SOCK_RDM',4)
SOCK_SEQPACKET = Constant('SOCK_SEQPACKET',5)
SO_DEBUG = Constant('SO_DEBUG',0x0001)
SO_ACCEPTCONN = Constant('SO_ACCEPTCONN',0x0002)
SO_REUSEADDR = Constant('SO_REUSEADDR',0x0004)
SO_KEEPALIVE = Constant('SO_KEEPALIVE',0x0008)
SO_DONTROUTE = Constant('SO_DONTROUTE',0x0010)
SO_BROADCAST = Constant('SO_BROADCAST',0x0020)
SO_USELOOPBACK = Constant('SO_USELOOPBACK',0x0040)
SO_LINGER = Constant('SO_LINGER',0x1080)
SO_LINGER_SEC = Constant('SO_LINGER_SEC',0x1080)
SO_OOBINLINE = Constant('SO_OOBINLINE',0x0100)
SO_REUSEPORT = Constant('SO_REUSEPORT',0x0200)
SO_TIMESTAMP = Constant('SO_TIMESTAMP',0x0400)
SO_TIMESTAMP_MONOTONIC = Constant('SO_TIMESTAMP_MONOTONIC',0x0800)
SO_ACCEPTFILTER = Constant('SO_ACCEPTFILTER',0x1000)
SO_DONTTRUNC = Constant('SO_DONTTRUNC',0x2000)
SO_WANTMORE = Constant('SO_WANTMORE',0x4000)
SO_WANTOOBFLAG = Constant('SO_WANTOOBFLAG',0x8000)
SO_SNDBUF = Constant('SO_SNDBUF',0x1001)
SO_RCVBUF = Constant('SO_RCVBUF',0x1002)
SO_SNDLOWAT = Constant('SO_SNDLOWAT',0x1003)
SO_RCVLOWAT = Constant('SO_RCVLOWAT',0x1004)
SO_SNDTIMEO = Constant('SO_SNDTIMEO',0x1005)
SO_RCVTIMEO = Constant('SO_RCVTIMEO',0x1006)
SO_ERROR = Constant('SO_ERROR',0x1007)
SO_TYPE = Constant('SO_TYPE',0x1008)
SO_LABEL = Constant('SO_LABEL',0x1010)
SO_PEERLABEL = Constant('SO_PEERLABEL',0x1011)
SO_NREAD = Constant('SO_NREAD',0x1020)
SO_NKE = Constant('SO_NKE',0x1021)
SO_NOSIGPIPE = Constant('SO_NOSIGPIPE',0x1022)
SO_NOADDRERR = Constant('SO_NOADDRERR',0x1023)
SO_NWRITE = Constant('SO_NWRITE',0x1024)
SO_REUSESHAREUID = Constant('SO_REUSESHAREUID',0x1025)
SO_NOTIFYCONFLICT = Constant('SO_NOTIFYCONFLICT',0x1026)
SO_UPCALLCLOSEWAIT = Constant('SO_UPCALLCLOSEWAIT',0x1027)
SO_RANDOMPORT = Constant('SO_RANDOMPORT',0x1082)
SO_NP_EXTENSIONS = Constant('SO_NP_EXTENSIONS',0x1083)
SO_NUMRCVPKT = Constant('SO_NUMRCVPKT',0x1112)
SO_NET_SERVICE_TYPE = Constant('SO_NET_SERVICE_TYPE',0x1116)
SO_NETSVC_MARKING_LEVEL = Constant('SO_NETSVC_MARKING_LEVEL',0x1119)
SO_RESOLVER_SIGNATURE = Constant('SO_RESOLVER_SIGNATURE',0x1131)
SO_BINDTODEVICE = Constant('SO_BINDTODEVICE',0x1134)
NET_SERVICE_TYPE_BE = Constant('NET_SERVICE_TYPE_BE',0)
NET_SERVICE_TYPE_BK = Constant('NET_SERVICE_TYPE_BK',1)
NET_SERVICE_TYPE_SIG = Constant('NET_SERVICE_TYPE_SIG',2)
NET_SERVICE_TYPE_VI = Constant('NET_SERVICE_TYPE_VI',3)
NET_SERVICE_TYPE_VO = Constant('NET_SERVICE_TYPE_VO',4)
NET_SERVICE_TYPE_RV = Constant('NET_SERVICE_TYPE_RV',5)
NET_SERVICE_TYPE_AV = Constant('NET_SERVICE_TYPE_AV',6)
NET_SERVICE_TYPE_OAM = Constant('NET_SERVICE_TYPE_OAM',7)
NET_SERVICE_TYPE_RD = Constant('NET_SERVICE_TYPE_RD',8)
NETSVC_MRKNG_UNKNOWN = Constant('NETSVC_MRKNG_UNKNOWN',0)
NETSVC_MRKNG_LVL_L2 = Constant('NETSVC_MRKNG_LVL_L2',1)
NETSVC_MRKNG_LVL_L3L2_ALL = Constant('NETSVC_MRKNG_LVL_L3L2_ALL',2)
NETSVC_MRKNG_LVL_L3L2_BK = Constant('NETSVC_MRKNG_LVL_L3L2_BK',3)
SAE_ASSOCID_ANY = Constant('SAE_ASSOCID_ANY',0)
SAE_CONNID_ANY = Constant('SAE_CONNID_ANY',0)
CONNECT_RESUME_ON_READ_WRITE = Constant('CONNECT_RESUME_ON_READ_WRITE',0x1)
CONNECT_DATA_IDEMPOTENT = Constant('CONNECT_DATA_IDEMPOTENT',0x2)
CONNECT_DATA_AUTHENTICATED = Constant('CONNECT_DATA_AUTHENTICATED',0x4)
SONPX_SETOPTSHUT = Constant('SONPX_SETOPTSHUT',0x000000001)
SOL_SOCKET = Constant('SOL_SOCKET',0xffff)
AF_UNSPEC = Constant('AF_UNSPEC',0)
AF_UNIX = Constant('AF_UNIX',1)
AF_INET = Constant('AF_INET',2)
AF_IMPLINK = Constant('AF_IMPLINK',3)
AF_PUP = Constant('AF_PUP',4)
AF_CHAOS = Constant('AF_CHAOS',5)
AF_NS = Constant('AF_NS',6)
AF_ISO = Constant('AF_ISO',7)
AF_ECMA = Constant('AF_ECMA',8)
AF_DATAKIT = Constant('AF_DATAKIT',9)
AF_CCITT = Constant('AF_CCITT',10)
AF_SNA = Constant('AF_SNA',11)
AF_DECnet = Constant('AF_DECnet',12)
AF_DLI = Constant('AF_DLI',13)
AF_LAT = Constant('AF_LAT',14)
AF_HYLINK = Constant('AF_HYLINK',15)
AF_APPLETALK = Constant('AF_APPLETALK',16)
AF_ROUTE = Constant('AF_ROUTE',17)
AF_LINK = Constant('AF_LINK',18)
pseudo_AF_XTP = Constant('pseudo_AF_XTP',19)
AF_COIP = Constant('AF_COIP',20)
AF_CNT = Constant('AF_CNT',21)
pseudo_AF_RTIP = Constant('pseudo_AF_RTIP',22)
AF_IPX = Constant('AF_IPX',23)
AF_SIP = Constant('AF_SIP',24)
pseudo_AF_PIP = Constant('pseudo_AF_PIP',25)
AF_NDRV = Constant('AF_NDRV',27)
AF_ISDN = Constant('AF_ISDN',28)
pseudo_AF_KEY = Constant('pseudo_AF_KEY',29)
AF_INET6 = Constant('AF_INET6',30)
AF_NATM = Constant('AF_NATM',31)
AF_SYSTEM = Constant('AF_SYSTEM',32)
AF_NETBIOS = Constant('AF_NETBIOS',33)
AF_PPP = Constant('AF_PPP',34)
pseudo_AF_HDRCMPLT = Constant('pseudo_AF_HDRCMPLT',35)
AF_RESERVED_36 = Constant('AF_RESERVED_36',36)
AF_IEEE80211 = Constant('AF_IEEE80211',37)
AF_UTUN = Constant('AF_UTUN',38)
AF_VSOCK = Constant('AF_VSOCK',40)
AF_MAX = Constant('AF_MAX',41)
SOCK_MAXADDRLEN = Constant('SOCK_MAXADDRLEN',255)
_SS_MAXSIZE = Constant('_SS_MAXSIZE',128)
NET_RT_DUMP = Constant('NET_RT_DUMP',1)
NET_RT_FLAGS = Constant('NET_RT_FLAGS',2)
NET_RT_IFLIST = Constant('NET_RT_IFLIST',3)
NET_RT_STAT = Constant('NET_RT_STAT',4)
NET_RT_TRASH = Constant('NET_RT_TRASH',5)
NET_RT_IFLIST2 = Constant('NET_RT_IFLIST2',6)
NET_RT_DUMP2 = Constant('NET_RT_DUMP2',7)
NET_RT_FLAGS_PRIV = Constant('NET_RT_FLAGS_PRIV',10)
NET_RT_MAXID = Constant('NET_RT_MAXID',11)
SOMAXCONN = Constant('SOMAXCONN',128)
MSG_OOB = Constant('MSG_OOB',0x1)
MSG_PEEK = Constant('MSG_PEEK',0x2)
MSG_DONTROUTE = Constant('MSG_DONTROUTE',0x4)
MSG_EOR = Constant('MSG_EOR',0x8)
MSG_TRUNC = Constant('MSG_TRUNC',0x10)
MSG_CTRUNC = Constant('MSG_CTRUNC',0x20)
MSG_WAITALL = Constant('MSG_WAITALL',0x40)
MSG_DONTWAIT = Constant('MSG_DONTWAIT',0x80)
MSG_EOF = Constant('MSG_EOF',0x100)
MSG_WAITSTREAM = Constant('MSG_WAITSTREAM',0x200)
MSG_FLUSH = Constant('MSG_FLUSH',0x400)
MSG_HOLD = Constant('MSG_HOLD',0x800)
MSG_SEND = Constant('MSG_SEND',0x1000)
MSG_HAVEMORE = Constant('MSG_HAVEMORE',0x2000)
MSG_RCVMORE = Constant('MSG_RCVMORE',0x4000)
MSG_NEEDSA = Constant('MSG_NEEDSA',0x10000)
MSG_NOSIGNAL = Constant('MSG_NOSIGNAL',0x80000)
MSG_USEUPCALL = Constant('MSG_USEUPCALL',0x80000000)
CMGROUP_MAX = Constant('CMGROUP_MAX',16)
SCM_RIGHTS = Constant('SCM_RIGHTS',0x01)
SCM_TIMESTAMP = Constant('SCM_TIMESTAMP',0x02)
SCM_CREDS = Constant('SCM_CREDS',0x03)
SCM_TIMESTAMP_MONOTONIC = Constant('SCM_TIMESTAMP_MONOTONIC',0x04)
SHUT_RD = Constant('SHUT_RD',0)
SHUT_WR = Constant('SHUT_WR',1)
SHUT_RDWR = Constant('SHUT_RDWR',2)
SBUF_FIXEDLEN = Constant('SBUF_FIXEDLEN',0x00000000)
SBUF_AUTOEXTEND = Constant('SBUF_AUTOEXTEND',0x00000001)
SBUF_USRFLAGMSK = Constant('SBUF_USRFLAGMSK',0x0000ffff)
SBUF_DYNAMIC = Constant('SBUF_DYNAMIC',0x00010000)
SBUF_FINISHED = Constant('SBUF_FINISHED',0x00020000)
SBUF_OVERFLOWED = Constant('SBUF_OVERFLOWED',0x00040000)
SBUF_DYNSTRUCT = Constant('SBUF_DYNSTRUCT',0x00080000)
SYSPROTO_EVENT = Constant('SYSPROTO_EVENT',1)
SYSPROTO_CONTROL = Constant('SYSPROTO_CONTROL',2)
AF_SYS_CONTROL = Constant('AF_SYS_CONTROL',2)
SO_TRACKER_ATTRIBUTE_FLAGS_APP_APPROVED = Constant('SO_TRACKER_ATTRIBUTE_FLAGS_APP_APPROVED',0x00000001)
SO_TRACKER_ATTRIBUTE_FLAGS_TRACKER = Constant('SO_TRACKER_ATTRIBUTE_FLAGS_TRACKER',0x00000002)
SO_TRACKER_ATTRIBUTE_FLAGS_DOMAIN_SHORT = Constant('SO_TRACKER_ATTRIBUTE_FLAGS_DOMAIN_SHORT',0x00000004)
NS_GETRAWENCRYPTED = Constant('NS_GETRAWENCRYPTED',0x00000001)
